# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::BG;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144527;

my $formatters = [
                {
                  'format' => '$1',
                  'intl_format' => 'NA',
                  'leading_digits' => '1',
                  'pattern' => '(\\d{6})'
                },
                {
                  'format' => '$1 $2 $3 $4',
                  'leading_digits' => '2',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d)(\\d)(\\d{2})(\\d{2})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            43[1-6]|
            70[1-9]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '2',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d)(\\d{3})(\\d{3,4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            [356]|
            4[124-7]|
            7[1-9]|
            8[1-6]|
            9[1-7]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{3})(\\d{2,3})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            (?:
              70|
              8
            )0
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{2})(\\d{3})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            43[1-7]|
            7
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{2})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            [48]|
            9[08]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{3})(\\d{3,4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '9',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{3})'
                }
              ];

my $validators = {
                'fixed_line' => '
          2\\d{5,7}|
          (?:
            43[1-6]|
            70[1-9]
          )\\d{4,5}|
          (?:
            [36]\\d|
            4[124-7]|
            [57][1-9]|
            8[1-6]|
            9[1-7]
          )\\d{5,6}
        ',
                'geographic' => '
          2\\d{5,7}|
          (?:
            43[1-6]|
            70[1-9]
          )\\d{4,5}|
          (?:
            [36]\\d|
            4[124-7]|
            [57][1-9]|
            8[1-6]|
            9[1-7]
          )\\d{5,6}
        ',
                'mobile' => '
          43[07-9]\\d{5}|
          (?:
            48|
            8[7-9]\\d|
            9(?:
              8\\d|
              9[69]
            )
          )\\d{6}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(700\\d{5})|(90\\d{6})',
                'toll_free' => '800\\d{5}',
                'voip' => ''
              };
my %areanames = ();
$areanames{bg}->{3592} = "София";
$areanames{bg}->{359301} = "Смолян";
$areanames{bg}->{3593019} = "Писаница";
$areanames{bg}->{3593020} = "Давидково";
$areanames{bg}->{35930200} = "Загражден\,\ Смол\.";
$areanames{bg}->{35930205} = "Стърница";
$areanames{bg}->{3593022} = "Виево";
$areanames{bg}->{3593023} = "Момчиловци";
$areanames{bg}->{3593024} = "Търън";
$areanames{bg}->{3593025} = "Баните";
$areanames{bg}->{35930256} = "Гълъбово\,\ Смол\.";
$areanames{bg}->{35930257} = "Вишнево";
$areanames{bg}->{3593026} = "Смилян";
$areanames{bg}->{3593027} = "Славейно";
$areanames{bg}->{3593028} = "Арда";
$areanames{bg}->{3593029} = "Петково\,\ Смол\.";
$areanames{bg}->{3593030} = "Широка\ лъка";
$areanames{bg}->{3593032} = "Средногорци";
$areanames{bg}->{3593034} = "Левочево";
$areanames{bg}->{3593035} = "Върбина";
$areanames{bg}->{3593036} = "Могилица";
$areanames{bg}->{3593037} = "Сивино";
$areanames{bg}->{3593038} = "Чокманово";
$areanames{bg}->{3593039} = "Полковник\ Серафимово";
$areanames{bg}->{3593040} = "Триград";
$areanames{bg}->{35930410} = "Брезе\,\ Смол\.";
$areanames{bg}->{35930411} = "Девин";
$areanames{bg}->{35930412} = "Девин";
$areanames{bg}->{35930413} = "Девин";
$areanames{bg}->{35930414} = "Девин";
$areanames{bg}->{35930415} = "Девин";
$areanames{bg}->{35930416} = "Гьоврен";
$areanames{bg}->{35930417} = "Грохотно";
$areanames{bg}->{35930418} = "Буйново\,\ Смол\.";
$areanames{bg}->{35930419} = "Ягодина";
$areanames{bg}->{3593042} = "Борино";
$areanames{bg}->{3593043} = "Змеица";
$areanames{bg}->{3593044} = "Лясково\,\ Смол\.";
$areanames{bg}->{3593045} = "Доспат";
$areanames{bg}->{35930456} = "Чавдар\,\ Смол\.";
$areanames{bg}->{35930457} = "Късак";
$areanames{bg}->{35930458} = "Любча";
$areanames{bg}->{35930459} = "Бръщен";
$areanames{bg}->{3593046} = "Барутин";
$areanames{bg}->{35930472} = "Михалково";
$areanames{bg}->{35930475} = "Стоманево";
$areanames{bg}->{35930476} = "Селча";
$areanames{bg}->{3593049} = "Беден";
$areanames{bg}->{3593050} = "Букова\ поляна";
$areanames{bg}->{3593051} = "Чепеларе";
$areanames{bg}->{35930517} = "Забърдо";
$areanames{bg}->{3593052} = "Лъки\,\ Пловдив";
$areanames{bg}->{35930528} = "Манастир\,\ Пловдив";
$areanames{bg}->{3593053} = "Хвойна";
$areanames{bg}->{3593054} = "Подвис\,\ Смол\.";
$areanames{bg}->{3593055} = "Елховец";
$areanames{bg}->{3593056} = "Чепинци\,\ Смол\.";
$areanames{bg}->{3593057} = "Пловдивци";
$areanames{bg}->{3593058} = "Мугла";
$areanames{bg}->{3593059} = "Кутела";
$areanames{bg}->{359306} = "Рудозем";
$areanames{bg}->{3593071} = "Златоград";
$areanames{bg}->{3593072} = "Неделино";
$areanames{bg}->{3593073} = "Старцево";
$areanames{bg}->{3593074} = "Ерма\ река";
$areanames{bg}->{3593075} = "Долен\,\ Смол\.";
$areanames{bg}->{3593076} = "Цацаровци";
$areanames{bg}->{3593077} = "Средец\,\ Смол\.";
$areanames{bg}->{3593079} = "Козарка";
$areanames{bg}->{359308} = "Мадан\,\ Смол\.";
$areanames{bg}->{359309} = "Пампорово";
$areanames{bg}->{3593100} = "Белащица";
$areanames{bg}->{3593101} = "Войводиново";
$areanames{bg}->{3593102} = "Караджово";
$areanames{bg}->{3593103} = "Милево";
$areanames{bg}->{3593104} = "Ягодово\,\ Пловдив";
$areanames{bg}->{3593105} = "Манолско\ Конаре";
$areanames{bg}->{3593106} = "Строево";
$areanames{bg}->{3593107} = "Граф\ Игнатиево";
$areanames{bg}->{3593108} = "Бойково";
$areanames{bg}->{3593109} = "Лилково";
$areanames{bg}->{3593110} = "Поповица";
$areanames{bg}->{35931108} = "Богданица";
$areanames{bg}->{3593111} = "Първенец\,\ Пловдив";
$areanames{bg}->{3593112} = "Марково\,\ Пловдив";
$areanames{bg}->{3593113} = "Браниполе";
$areanames{bg}->{3593114} = "Брестник";
$areanames{bg}->{3593115} = "Куклен";
$areanames{bg}->{3593116} = "Крумово\,\ Пловдив";
$areanames{bg}->{3593117} = "Катуница";
$areanames{bg}->{3593118} = "Садово\,\ Пловдив";
$areanames{bg}->{3593119} = "Гълъбово\,\ Пловдив";
$areanames{bg}->{3593120} = "Храбрино";
$areanames{bg}->{3593121} = "Рогош";
$areanames{bg}->{3593122} = "Маноле";
$areanames{bg}->{3593123} = "Калояново\,\ Пловдив";
$areanames{bg}->{3593124} = "Калековец";
$areanames{bg}->{3593125} = "Ръжево\ Конаре";
$areanames{bg}->{35931258} = "Главатар";
$areanames{bg}->{3593126} = "Труд";
$areanames{bg}->{3593127} = "Царацово";
$areanames{bg}->{3593128} = "Златитрап";
$areanames{bg}->{3593129} = "Скутаре";
$areanames{bg}->{3593130} = "Каравелово\,\ Пловдив";
$areanames{bg}->{35931308} = "Богдан\,\ Пловдив";
$areanames{bg}->{35931309} = "Климент\,\ Пловдив";
$areanames{bg}->{3593132} = "Баня\,\ Пловдив";
$areanames{bg}->{35931324} = "Мраченик";
$areanames{bg}->{3593133} = "Калофер";
$areanames{bg}->{3593134} = "Сопот\,\ Пловдив";
$areanames{bg}->{3593135} = "Кърнаре";
$areanames{bg}->{3593136} = "Розино\,\ Пловдив";
$areanames{bg}->{3593137} = "Клисура\,\ Пловдив";
$areanames{bg}->{3593138} = "Ведраре";
$areanames{bg}->{35931387} = "Пролом";
$areanames{bg}->{35931388} = "Бегунци";
$areanames{bg}->{35931390} = "Московец";
$areanames{bg}->{35931392} = "Дъбене";
$areanames{bg}->{35931393} = "Войнягово";
$areanames{bg}->{35931394} = "Васил\ Левски\,\ Пловдив";
$areanames{bg}->{35931395} = "Иганово";
$areanames{bg}->{35931396} = "Домлян";
$areanames{bg}->{35931397} = "Христо\ Даново";
$areanames{bg}->{35931398} = "Слатина\,\ Пловдив";
$areanames{bg}->{35931401} = "Кадиево";
$areanames{bg}->{35931402} = "Скобелево\,\ Пловдив";
$areanames{bg}->{35931403} = "Триводици";
$areanames{bg}->{3593142} = "Брестовица\,\ Пловдив";
$areanames{bg}->{3593143} = "Перущица";
$areanames{bg}->{3593145} = "Кричим";
$areanames{bg}->{3593146} = "Куртово\ Конаре";
$areanames{bg}->{3593147} = "Ново\ село\,\ Пловдив";
$areanames{bg}->{3593148} = "Йоаким\ Груево";
$areanames{bg}->{3593149} = "Цалапица";
$areanames{bg}->{3593151} = "Раковски\,\ Пловдив";
$areanames{bg}->{3593153} = "Стряма";
$areanames{bg}->{3593154} = "Чалъкови";
$areanames{bg}->{3593155} = "Момино\ село";
$areanames{bg}->{3593156} = "Шишманци";
$areanames{bg}->{3593157} = "Болярино";
$areanames{bg}->{3593159} = "Белозем";
$areanames{bg}->{35931602} = "Татарево\,\ Пловдив";
$areanames{bg}->{35931603} = "Виница";
$areanames{bg}->{35931604} = "Драгойново";
$areanames{bg}->{35931605} = "Буково\,\ Пловдив";
$areanames{bg}->{35931606} = "Воден\,\ Пловдив";
$areanames{bg}->{3593162} = "Градина\,\ Пловдив";
$areanames{bg}->{35931620} = "Добри\ дол\,\ Пловдив";
$areanames{bg}->{35931627} = "Крушево\,\ Пловдив";
$areanames{bg}->{3593163} = "Искра\,\ Пловдив";
$areanames{bg}->{3593164} = "Дълбок\ извор";
$areanames{bg}->{3593165} = "Караджалово";
$areanames{bg}->{3593166} = "Бяла\ река\,\ Пловдив";
$areanames{bg}->{3593167} = "Брягово\,\ Пловдив";
$areanames{bg}->{3593168} = "Езерово\,\ Пловдив";
$areanames{bg}->{35931700} = "Беловица";
$areanames{bg}->{35931701} = "Кръстевич";
$areanames{bg}->{35931702} = "Долна\ махала\,\ Пловдив";
$areanames{bg}->{35931703} = "Житница\,\ Пловдив";
$areanames{bg}->{35931704} = "Иван\ Вазово";
$areanames{bg}->{35931705} = "Горна\ махала";
$areanames{bg}->{35931706} = "Сухозем";
$areanames{bg}->{35931707} = "Черноземен";
$areanames{bg}->{35931708} = "Песнопой\,\ Пловдив";
$areanames{bg}->{35931709} = "Михилци";
$areanames{bg}->{3593173} = "Паничери";
$areanames{bg}->{3593174} = "Старо\ Железаре";
$areanames{bg}->{3593175} = "Дълго\ поле\,\ Пловдив";
$areanames{bg}->{3593176} = "Старосел";
$areanames{bg}->{3593177} = "Ново\ Железаре";
$areanames{bg}->{3593178} = "Красново";
$areanames{bg}->{35931791} = "Бегово";
$areanames{bg}->{35931792} = "Черничево\,\ Пловдив";
$areanames{bg}->{359318} = "Съединение\,\ Пловдив";
$areanames{bg}->{3593190} = "Върбен\,\ Пловдив";
$areanames{bg}->{3593191} = "Брезово\,\ Пловдив";
$areanames{bg}->{3593192} = "Бабек";
$areanames{bg}->{3593193} = "Борец";
$areanames{bg}->{3593194} = "Зелениково\,\ Пловдив";
$areanames{bg}->{3593195} = "Розовец";
$areanames{bg}->{3593196} = "Дрангово\,\ Пловдив";
$areanames{bg}->{3593197} = "Тюркмен";
$areanames{bg}->{3593198} = "Чехларе";
$areanames{bg}->{35931992} = "Пъдарско";
$areanames{bg}->{35931993} = "Сърнегор";
$areanames{bg}->{35931995} = "Стрелци\,\ Пловдив";
$areanames{bg}->{35931996} = "Свежен";
$areanames{bg}->{35931997} = "Златосел";
$areanames{bg}->{35931998} = "Чоба";
$areanames{bg}->{35932} = "Пловдив";
$areanames{bg}->{359331} = "Асеновград";
$areanames{bg}->{3593320} = "Орешец\,\ Пловдив";
$areanames{bg}->{3593321} = "Тополово\,\ Пловдив";
$areanames{bg}->{3593322} = "Златовръх";
$areanames{bg}->{3593323} = "Болярци\,\ Пловдив";
$areanames{bg}->{3593324} = "Избеглии";
$areanames{bg}->{3593325} = "Червен\,\ Пловдив";
$areanames{bg}->{3593326} = "Патриарх\ Евтимово";
$areanames{bg}->{3593327} = "Бачково";
$areanames{bg}->{3593328} = "Долнослав";
$areanames{bg}->{3593340} = "Нови\ извор";
$areanames{bg}->{3593341} = "Конуш\,\ Пловдив";
$areanames{bg}->{3593342} = "Нареченски\ бани";
$areanames{bg}->{3593343} = "Козаново";
$areanames{bg}->{3593344} = "Новаково\,\ Пловдив";
$areanames{bg}->{3593345} = "Лясково\,\ Пловдив";
$areanames{bg}->{3593346} = "Мулдава";
$areanames{bg}->{3593347} = "Леново";
$areanames{bg}->{3593348} = "Добралък";
$areanames{bg}->{3593349} = "Боянци";
$areanames{bg}->{359335} = "Карлово";
$areanames{bg}->{359336} = "Първомай\,\ Пловдив";
$areanames{bg}->{359337} = "Хисаря";
$areanames{bg}->{359339} = "Стамболийски\,\ Пловдив";
$areanames{bg}->{35934} = "Пазарджик";
$areanames{bg}->{359350} = "Пещера\,\ Пазарджик";
$areanames{bg}->{3593510} = "Овчеполци";
$areanames{bg}->{3593511} = "Огняново\,\ Пазарджик";
$areanames{bg}->{3593512} = "Хаджиево";
$areanames{bg}->{3593513} = "Мало\ Конаре";
$areanames{bg}->{3593514} = "Черногорово\,\ Пазарджик";
$areanames{bg}->{3593515} = "Калугерово\,\ Пазарджик";
$areanames{bg}->{3593516} = "Црънча\,\ Пазарджик";
$areanames{bg}->{3593517} = "Лесичово";
$areanames{bg}->{3593518} = "Драгор";
$areanames{bg}->{3593519} = "Величково\,\ Пазарджик";
$areanames{bg}->{3593520} = "Мирянци";
$areanames{bg}->{3593521} = "Звъничево";
$areanames{bg}->{3593522} = "Гелеменово";
$areanames{bg}->{3593523} = "Синитево";
$areanames{bg}->{3593524} = "Априлци\,\ Пазарджик";
$areanames{bg}->{35935251} = "Братаница";
$areanames{bg}->{35935252} = "Тополи\ дол";
$areanames{bg}->{35935254} = "Добровница";
$areanames{bg}->{35935255} = "Росен\,\ Пазарджик";
$areanames{bg}->{35935256} = "Сбор\,\ Пазарджик";
$areanames{bg}->{35935257} = "Сарая";
$areanames{bg}->{35935258} = "Цар\ Асен\,\ Пазарджик";
$areanames{bg}->{3593526} = "Динката";
$areanames{bg}->{3593527} = "Алеко\ Константиново";
$areanames{bg}->{3593528} = "Говедаре";
$areanames{bg}->{3593529} = "Мокрище";
$areanames{bg}->{3593530} = "Поибрене";
$areanames{bg}->{3593532} = "Стрелча";
$areanames{bg}->{3593533} = "Бъта";
$areanames{bg}->{3593534} = "Попинци";
$areanames{bg}->{3593535} = "Левски\,\ Пазарджик";
$areanames{bg}->{3593536} = "Баня\,\ Пазарджик";
$areanames{bg}->{3593537} = "Панагюрски\ колонии";
$areanames{bg}->{3593538} = "Елшица";
$areanames{bg}->{35935391} = "Блатница";
$areanames{bg}->{35935392} = "Дюлево\,\ Пазарджик";
$areanames{bg}->{35935393} = "Смилец\,\ Пазарджик";
$areanames{bg}->{35935394} = "Оборище\,\ Пазарджик";
$areanames{bg}->{35935418} = "Кръстава";
$areanames{bg}->{35935419} = "Света\ Петка";
$areanames{bg}->{3593542} = "Ракитово";
$areanames{bg}->{3593543} = "Дорково";
$areanames{bg}->{3593544} = "Костандово";
$areanames{bg}->{3593545} = "Драгиново";
$areanames{bg}->{3593547} = "Сърница\,\ Пазарджик";
$areanames{bg}->{3593548} = "Пашово";
$areanames{bg}->{3593549} = "Грашево";
$areanames{bg}->{35935501} = "Равногор";
$areanames{bg}->{35935502} = "Фотиново\,\ Пазарджик";
$areanames{bg}->{3593552} = "Брацигово";
$areanames{bg}->{3593553} = "Батак\,\ Пазарджик";
$areanames{bg}->{3593554} = "Козарско";
$areanames{bg}->{3593555} = "Нова\ махала\,\ Пазарджик";
$areanames{bg}->{3593556} = "Радилово";
$areanames{bg}->{3593557} = "Бяга";
$areanames{bg}->{3593558} = "Исперихово";
$areanames{bg}->{3593559} = "Капитан\ Димитриево";
$areanames{bg}->{3593561} = "Септември";
$areanames{bg}->{3593562} = "Славовица\,\ Пазарджик";
$areanames{bg}->{3593563} = "Варвара\,\ Пазарджик";
$areanames{bg}->{3593564} = "Семчиново";
$areanames{bg}->{3593566} = "Бошуля";
$areanames{bg}->{3593567} = "Ковачево\,\ Пазарджик";
$areanames{bg}->{3593568} = "Виноградец";
$areanames{bg}->{3593569} = "Карабунар";
$areanames{bg}->{359357} = "Панагюрище";
$areanames{bg}->{3593581} = "Белово";
$areanames{bg}->{3593582} = "Момина\ клисура";
$areanames{bg}->{3593583} = "Габровица";
$areanames{bg}->{3593584} = "Ветрен\,\ Пазарджик";
$areanames{bg}->{3593585} = "Аканджиево";
$areanames{bg}->{3593586} = "Боримечково";
$areanames{bg}->{3593587} = "Сестримо";
$areanames{bg}->{3593588} = "Мененкьово";
$areanames{bg}->{3593589} = "Церово\,\ Пазарджик";
$areanames{bg}->{359359} = "Велинград";
$areanames{bg}->{359361} = "Кърджали";
$areanames{bg}->{3593622} = "Стремци";
$areanames{bg}->{3593623} = "Бойно";
$areanames{bg}->{3593624} = "Чифлик\,\ Кърдж\.";
$areanames{bg}->{3593625} = "Широко\ поле";
$areanames{bg}->{3593626} = "Перперек";
$areanames{bg}->{3593628} = "Миладиново";
$areanames{bg}->{3593629} = "Мост";
$areanames{bg}->{3593631} = "Момчилград";
$areanames{bg}->{3593632} = "Джебел";
$areanames{bg}->{3593633} = "Рогозче";
$areanames{bg}->{3593634} = "Припек\,\ Кърдж\.";
$areanames{bg}->{3593636} = "Равен";
$areanames{bg}->{3593637} = "Груево";
$areanames{bg}->{3593638} = "Звездел";
$areanames{bg}->{3593639} = "Нановица\,\ Кърдж\.";
$areanames{bg}->{35936401} = "Странджево";
$areanames{bg}->{35936402} = "Горна\ кула";
$areanames{bg}->{3593641} = "Крумовград";
$areanames{bg}->{3593642} = "Поточница";
$areanames{bg}->{3593643} = "Голяма\ Чинка";
$areanames{bg}->{3593644} = "Егрек";
$areanames{bg}->{3593645} = "Аврен\,\ Кърдж\.";
$areanames{bg}->{3593646} = "Токачка";
$areanames{bg}->{3593647} = "Черничево\,\ Кърдж\.";
$areanames{bg}->{3593648} = "Голямо\ Каменяне";
$areanames{bg}->{3593651} = "Ардино";
$areanames{bg}->{3593652} = "Бял\ извор\,\ Кърдж\.";
$areanames{bg}->{3593653} = "Млечино";
$areanames{bg}->{3593657} = "Жълтуша";
$areanames{bg}->{3593658} = "Падина\,\ Кърдж\.";
$areanames{bg}->{3593661} = "Ивайловград";
$areanames{bg}->{3593662} = "Железино";
$areanames{bg}->{3593664} = "Плевун";
$areanames{bg}->{3593665} = "Свирачи";
$areanames{bg}->{3593666} = "Попско";
$areanames{bg}->{3593667} = "Покрован";
$areanames{bg}->{35936700} = "Шопци";
$areanames{bg}->{35936702} = "Горски\ извор\,\ Кърдж\.";
$areanames{bg}->{3593671} = "Подкова";
$areanames{bg}->{3593672} = "Чорбаджийско";
$areanames{bg}->{3593673} = "Тихомир";
$areanames{bg}->{3593674} = "Самодива";
$areanames{bg}->{3593675} = "Фотиново\,\ Кърдж\.";
$areanames{bg}->{3593676} = "Бенковски\,\ Кърдж\.";
$areanames{bg}->{3593677} = "Дрангово\,\ Кърдж\.";
$areanames{bg}->{3593678} = "Чакаларово";
$areanames{bg}->{3593679} = "Кирково";
$areanames{bg}->{3593691} = "Черноочeне";
$areanames{bg}->{3593693} = "Лясково\,\ Кърдж\.";
$areanames{bg}->{3593695} = "Комунига";
$areanames{bg}->{3593696} = "Пчеларово\,\ Кърдж\.";
$areanames{bg}->{3593699} = "Габрово\,\ Кърдж\.";
$areanames{bg}->{3593700} = "Тракиец";
$areanames{bg}->{3593701} = "Елена\,\ Хаск\.";
$areanames{bg}->{3593702} = "Царева\ поляна";
$areanames{bg}->{3593703} = "Жълти\ бряг";
$areanames{bg}->{3593704} = "Брягово\,\ Хаск\.";
$areanames{bg}->{3593705} = "Въгларово";
$areanames{bg}->{3593706} = "Тънково\,\ Хаск\.";
$areanames{bg}->{3593707} = "Николово\,\ Хаск\.";
$areanames{bg}->{3593708} = "Орлово\,\ Хаск\.";
$areanames{bg}->{3593709} = "Караманци";
$areanames{bg}->{3593710} = "Узунджово";
$areanames{bg}->{3593711} = "Долно\ Ботево";
$areanames{bg}->{3593712} = "Малево\,\ Хаск\.";
$areanames{bg}->{3593713} = "Динево";
$areanames{bg}->{3593717} = "Конуш\,\ Хаск\.";
$areanames{bg}->{3593718} = "Войводово\,\ Хаск\.";
$areanames{bg}->{3593719} = "Книжовник";
$areanames{bg}->{3593720} = "Маджарово";
$areanames{bg}->{3593721} = "Стамболово\,\ Хаск\.";
$areanames{bg}->{3593722} = "Минерални\ бани\,\ Хаск\.";
$areanames{bg}->{3593724} = "Сусам";
$areanames{bg}->{3593725} = "Стамболийски\,\ Хаск\.";
$areanames{bg}->{3593726} = "Клокотница";
$areanames{bg}->{3593727} = "Нова\ Надежда";
$areanames{bg}->{3593728} = "Славяново\,\ Хаск\.";
$areanames{bg}->{3593729} = "Криво\ поле";
$areanames{bg}->{359373} = "Харманли";
$areanames{bg}->{3593740} = "Пчелари";
$areanames{bg}->{3593741} = "Мандра";
$areanames{bg}->{35937420} = "Подкрепа";
$areanames{bg}->{35937421} = "Долно\ поле";
$areanames{bg}->{35937422} = "Долни\ Главанак";
$areanames{bg}->{35937423} = "Големанци";
$areanames{bg}->{35937424} = "Козлец";
$areanames{bg}->{3593743} = "Силен";
$areanames{bg}->{3593744} = "Сърница\,\ Хаск\.";
$areanames{bg}->{3593745} = "Малък\ извор\,\ Хаск\.";
$areanames{bg}->{3593746} = "Сираково\,\ Хаск\.";
$areanames{bg}->{3593747} = "Татарево\,\ Хаск\.";
$areanames{bg}->{3593748} = "Лясковец\,\ Хаск\.";
$areanames{bg}->{3593749} = "Гарваново";
$areanames{bg}->{3593751} = "Любимец";
$areanames{bg}->{3593752} = "Малко\ градище";
$areanames{bg}->{3593753} = "Оряхово\,\ Хаск\.";
$areanames{bg}->{3593754} = "Лозен\,\ Хаск\.";
$areanames{bg}->{3593755} = "Белица\,\ Хаск\.";
$areanames{bg}->{3593756} = "Вълче\ поле";
$areanames{bg}->{3593757} = "Георги\ Добрево";
$areanames{bg}->{3593758} = "Йерусалимово";
$areanames{bg}->{3593759} = "Бориславци";
$areanames{bg}->{35937602} = "Черна\ могила\,\ Хаск\.";
$areanames{bg}->{35937603} = "Рогозиново";
$areanames{bg}->{35937604} = "Върбово\,\ Хаск\.";
$areanames{bg}->{35937606} = "Шишманово";
$areanames{bg}->{3593762} = "Изворово\,\ Хаск\.";
$areanames{bg}->{3593763} = "Българин";
$areanames{bg}->{3593764} = "Поляново\,\ Хаск\.";
$areanames{bg}->{3593765} = "Иваново\,\ Хаск\.";
$areanames{bg}->{3593766} = "Бисер";
$areanames{bg}->{3593767} = "Браница";
$areanames{bg}->{3593768} = "Доситеево";
$areanames{bg}->{3593769} = "Орешец\,\ Хаск\.";
$areanames{bg}->{35937701} = "Сладун";
$areanames{bg}->{35937702} = "Мустрак";
$areanames{bg}->{35937703} = "Димитровче";
$areanames{bg}->{35937704} = "Младиново";
$areanames{bg}->{35937705} = "Пъстрогор";
$areanames{bg}->{35937706} = "Чернодъб";
$areanames{bg}->{35937707} = "Щит";
$areanames{bg}->{3593772} = "Момково";
$areanames{bg}->{3593773} = "Капитан\ Андреево";
$areanames{bg}->{3593774} = "Левка";
$areanames{bg}->{3593775} = "Генералово";
$areanames{bg}->{3593776} = "Райкова\ могила";
$areanames{bg}->{3593777} = "Мезек";
$areanames{bg}->{3593778} = "Студена\,\ Хаск\.";
$areanames{bg}->{3593779} = "Сива\ река";
$areanames{bg}->{3593781} = "Симеоновград";
$areanames{bg}->{3593782} = "Калугерово\,\ Хаск\.";
$areanames{bg}->{3593783} = "Свирково";
$areanames{bg}->{3593784} = "Константиново\,\ Хаск\.";
$areanames{bg}->{3593785} = "Дряново\,\ Хаск\.";
$areanames{bg}->{3593786} = "Навъсен";
$areanames{bg}->{3593787} = "Тянево\,\ Хаск\.";
$areanames{bg}->{359379} = "Свиленград";
$areanames{bg}->{35938} = "Хасково";
$areanames{bg}->{359391} = "Димитровград";
$areanames{bg}->{3593920} = "Златополе";
$areanames{bg}->{3593921} = "Меричлери";
$areanames{bg}->{3593922} = "Брод";
$areanames{bg}->{3593923} = "Радиево";
$areanames{bg}->{3593924} = "Крепост";
$areanames{bg}->{3593925} = "Крум";
$areanames{bg}->{3593926} = "Добрич\,\ Хаск\.";
$areanames{bg}->{3593927} = "Черногорово\,\ Хаск\.";
$areanames{bg}->{3593928} = "Долно\ Белево";
$areanames{bg}->{3593929} = "Голямо\ Асеново";
$areanames{bg}->{3593931} = "Каснаково";
$areanames{bg}->{3593932} = "Бодрово";
$areanames{bg}->{3593933} = "Странско";
$areanames{bg}->{3593934} = "Скобелево\,\ Хаск\.";
$areanames{bg}->{3593935} = "Върбица\,\ Хаск\.";
$areanames{bg}->{3593936} = "Горски\ извор\,\ Хаск\.";
$areanames{bg}->{3593937} = "Ябълково\,\ Хаск\.";
$areanames{bg}->{3594100} = "Столетово\,\ Ст\.\ Загора";
$areanames{bg}->{3594101} = "Опан";
$areanames{bg}->{35941018} = "Княжевско";
$areanames{bg}->{35941019} = "Венец\,\ Ст\.\ Загора";
$areanames{bg}->{3594102} = "Ястребово\,\ Ст\.\ Загора";
$areanames{bg}->{3594103} = "Бял\ извор\,\ Ст\.\ Загора";
$areanames{bg}->{3594104} = "Кравино";
$areanames{bg}->{3594105} = "Бяло\ поле";
$areanames{bg}->{3594106} = "Пъстрен";
$areanames{bg}->{3594107} = "Средец\,\ Ст\.\ Загора";
$areanames{bg}->{3594108} = "Васил\ Левски\,\ Ст\.\ Загора";
$areanames{bg}->{3594109} = "Тракия";
$areanames{bg}->{35941110} = "Старозагорски\ бани";
$areanames{bg}->{35941111} = "Старозагорски\ бани";
$areanames{bg}->{35941112} = "Старозагорски\ бани";
$areanames{bg}->{35941113} = "Пряпорец\,\ Ст\.\ Загора";
$areanames{bg}->{35941114} = "Лозен\,\ Ст\.\ Загора";
$areanames{bg}->{35941115} = "Борилово";
$areanames{bg}->{35941116} = "Сладък\ Кладенец";
$areanames{bg}->{35941117} = "Казанка";
$areanames{bg}->{35941118} = "Остра\ могила\,\ Ст\.\ Загора";
$areanames{bg}->{35941119} = "Елхово\,\ Ст\.\ Загора";
$areanames{bg}->{3594112} = "Бъдеще";
$areanames{bg}->{3594113} = "Преславен";
$areanames{bg}->{35941144} = "Калояновец";
$areanames{bg}->{35941145} = "Арнаутито";
$areanames{bg}->{35941146} = "Християново";
$areanames{bg}->{35941149} = "Ловец\,\ Ст\.\ Загора";
$areanames{bg}->{3594115} = "Кирилово\,\ Ст\.\ Загора";
$areanames{bg}->{3594116} = "Ракитница\,\ Ст\.\ Загора";
$areanames{bg}->{35941171} = "Дълбоки";
$areanames{bg}->{35941172} = "Горно\ Ботево";
$areanames{bg}->{35941173} = "Братя\ Кунчеви";
$areanames{bg}->{35941174} = "Подслон\,\ Ст\.\ Загора";
$areanames{bg}->{35941175} = "Колена";
$areanames{bg}->{35941178} = "Оряховица\,\ Ст\.\ Загора";
$areanames{bg}->{35941179} = "Хан\ Аспарухово";
$areanames{bg}->{3594118} = "Памукчии\,\ Ст\.\ Загора";
$areanames{bg}->{3594121} = "Люляк";
$areanames{bg}->{3594122} = "Еленино";
$areanames{bg}->{3594123} = "Богомилово";
$areanames{bg}->{3594124} = "Змейово";
$areanames{bg}->{3594125} = "Михайлово\,\ Ст\.\ Загора";
$areanames{bg}->{3594126} = "Хрищени";
$areanames{bg}->{35941270} = "Малка\ Верея";
$areanames{bg}->{35941274} = "Самуилово\,\ Ст\.\ Загора";
$areanames{bg}->{35941275} = "Лясково\,\ Ст\.\ Загора";
$areanames{bg}->{35941276} = "Могила\,\ Ст\.\ Загора";
$areanames{bg}->{35941277} = "Загоре";
$areanames{bg}->{35941279} = "Стрелец\,\ Ст\.\ Загора";
$areanames{bg}->{3594129} = "Маджерито";
$areanames{bg}->{3594130} = "Спасово\,\ Ст\.\ Загора";
$areanames{bg}->{3594132} = "Оризово";
$areanames{bg}->{35941330} = "Ценово\,\ Ст\.\ Загора";
$areanames{bg}->{35941331} = "Гранит";
$areanames{bg}->{35941332} = "Найденово";
$areanames{bg}->{35941333} = "Средно\ градище";
$areanames{bg}->{35941334} = "Съединение\,\ Ст\.\ Загора";
$areanames{bg}->{35941335} = "Могилово";
$areanames{bg}->{35941336} = "Яздач";
$areanames{bg}->{35941337} = "Сърневец";
$areanames{bg}->{35941338} = "Целина";
$areanames{bg}->{35941339} = "Димитриево";
$areanames{bg}->{3594134} = "Братя\ Даскалови";
$areanames{bg}->{35941350} = "Мирово\,\ Ст\.\ Загора";
$areanames{bg}->{35941351} = "Партизанин";
$areanames{bg}->{35941352} = "Винарово\,\ Ст\.\ Загора";
$areanames{bg}->{35941353} = "Плодовитово";
$areanames{bg}->{35941354} = "Малко\ Тръново";
$areanames{bg}->{35941355} = "Яворово";
$areanames{bg}->{35941356} = "Рупките";
$areanames{bg}->{35941357} = "Зетьово\,\ Ст\.\ Загора";
$areanames{bg}->{35941358} = "Опълченец";
$areanames{bg}->{35941359} = "Изворово\,\ Ст\.\ Загора";
$areanames{bg}->{3594136} = "Черна\ гора\,\ Ст\.\ Загора";
$areanames{bg}->{3594137} = "Верен";
$areanames{bg}->{3594138} = "Гита";
$areanames{bg}->{3594139} = "Свобода\,\ Ст\.\ Загора";
$areanames{bg}->{3594140} = "Полски\ Градец";
$areanames{bg}->{3594142} = "Трояново\,\ Ст\.\ Загора";
$areanames{bg}->{3594143} = "Сърнево\,\ Ст\.\ Загора";
$areanames{bg}->{3594144} = "Ковачево\,\ Ст\.\ Загора";
$areanames{bg}->{3594145} = "Знаменосец";
$areanames{bg}->{3594146} = "Диня";
$areanames{bg}->{3594147} = "Любеново\,\ Ст\.\ Загора";
$areanames{bg}->{35941480} = "Коларово\,\ Ст\.\ Загора";
$areanames{bg}->{35941484} = "Землен";
$areanames{bg}->{35941489} = "Боздуганово";
$areanames{bg}->{3594149} = "Трънково\,\ Ст\.\ Загора";
$areanames{bg}->{3594152} = "Обручище";
$areanames{bg}->{3594153} = "Мъдрец\,\ Ст\.\ Загора";
$areanames{bg}->{3594154} = "Медникарово";
$areanames{bg}->{3594155} = "Главан\,\ Ст\.\ Загора";
$areanames{bg}->{3594156} = "Априлово\,\ Ст\.\ Загора";
$areanames{bg}->{3594157} = "Разделна\,\ Ст\.\ Загора";
$areanames{bg}->{3594158} = "Искрица";
$areanames{bg}->{359416} = "Чирпан";
$areanames{bg}->{359417} = "Раднево";
$areanames{bg}->{359418} = "Гълъбово\,\ Ст\.\ Загора";
$areanames{bg}->{35942} = "Стара\ Загора";
$areanames{bg}->{359431} = "Казанлък";
$areanames{bg}->{3594321} = "Мъглиж";
$areanames{bg}->{3594322} = "Ягода";
$areanames{bg}->{3594323} = "Тулово";
$areanames{bg}->{3594324} = "Шипка";
$areanames{bg}->{3594325} = "Кънчево";
$areanames{bg}->{3594326} = "Енина";
$areanames{bg}->{3594327} = "Шейново";
$areanames{bg}->{3594329} = "Долно\ Сахране";
$areanames{bg}->{3594330} = "Николаево\,\ Ст\.\ Загора";
$areanames{bg}->{3594331} = "Гурково\,\ Ст\.\ Загора";
$areanames{bg}->{3594332} = "Ветрен\,\ Ст\.\ Загора";
$areanames{bg}->{3594333} = "Дъбово\,\ Ст\.\ Загора";
$areanames{bg}->{3594334} = "Елхово\,\ Ст\.\ Загора\,\ общ\.\ Николаево";
$areanames{bg}->{3594335} = "Ръжена";
$areanames{bg}->{3594336} = "Долно\ Изворово";
$areanames{bg}->{3594337} = "Ясеново\,\ Ст\.\ Загора";
$areanames{bg}->{3594338} = "Крън";
$areanames{bg}->{3594339} = "Юлиево";
$areanames{bg}->{3594340} = "Паничерево";
$areanames{bg}->{3594341} = "Черганово";
$areanames{bg}->{3594342} = "Овощник";
$areanames{bg}->{3594343} = "Конаре\,\ Ст\.\ Загора";
$areanames{bg}->{3594344} = "Шаново";
$areanames{bg}->{3594345} = "Радунци";
$areanames{bg}->{3594346} = "Голямо\ Дряново";
$areanames{bg}->{3594347} = "Розово\,\ Ст\.\ Загора";
$areanames{bg}->{3594348} = "Дунавци\,\ Ст\.\ Загора";
$areanames{bg}->{3594350} = "Горно\ Изворово";
$areanames{bg}->{3594351} = "Копринка";
$areanames{bg}->{3594352} = "Горно\ Черковище";
$areanames{bg}->{3594353} = "Средногорово";
$areanames{bg}->{3594354} = "Зимница\,\ Ст\.\ Загора";
$areanames{bg}->{3594355} = "Бузовград";
$areanames{bg}->{3594356} = "Хаджидимитрово\,\ Ст\.\ Загора";
$areanames{bg}->{3594357} = "Горно\ Сахране";
$areanames{bg}->{3594358} = "Скобелево\,\ Ст\.\ Загора";
$areanames{bg}->{3594359} = "Асен\,\ Ст\.\ Загора";
$areanames{bg}->{3594361} = "Павел\ баня";
$areanames{bg}->{35943616} = "Турия";
$areanames{bg}->{3594362} = "Манолово";
$areanames{bg}->{3594363} = "Габарево";
$areanames{bg}->{3594364} = "Осетеново";
$areanames{bg}->{3594367} = "Тъжа";
$areanames{bg}->{3594368} = "Търничени";
$areanames{bg}->{3594369} = "Александрово\,\ Ст\.\ Загора";
$areanames{bg}->{35944} = "Сливен";
$areanames{bg}->{3594510} = "Желю\ войвода";
$areanames{bg}->{3594511} = "Сливенски\ минерални\ бани";
$areanames{bg}->{3594512} = "Блатец\,\ Сливен";
$areanames{bg}->{3594513} = "Гавраилово";
$areanames{bg}->{3594514} = "Крушаре";
$areanames{bg}->{3594515} = "Мокрен";
$areanames{bg}->{3594516} = "Кермен";
$areanames{bg}->{3594517} = "Ичера";
$areanames{bg}->{3594518} = "Тополчане";
$areanames{bg}->{3594519} = "Самуилово\,\ Сливен";
$areanames{bg}->{3594520} = "Коньово";
$areanames{bg}->{3594522} = "Кортен";
$areanames{bg}->{3594523} = "Стоил\ войвода";
$areanames{bg}->{3594524} = "Каменово\,\ Сливен";
$areanames{bg}->{3594525} = "Омарчево\,\ Сливен";
$areanames{bg}->{3594526} = "Млекарево";
$areanames{bg}->{3594527} = "Загорци\,\ Сливен";
$areanames{bg}->{3594528} = "Любенова\ махала";
$areanames{bg}->{3594529} = "Съдиево\,\ Сливен";
$areanames{bg}->{359453} = "Котел";
$areanames{bg}->{359454} = "Твърдица\,\ Сливен";
$areanames{bg}->{3594551} = "Бяла\,\ Сливен";
$areanames{bg}->{3594552} = "Стара\ река\,\ Сливен";
$areanames{bg}->{3594553} = "Раково\,\ Сливен";
$areanames{bg}->{3594554} = "Трапоклово";
$areanames{bg}->{3594556} = "Сотиря";
$areanames{bg}->{3594557} = "Биково";
$areanames{bg}->{3594562} = "Крива\ круша";
$areanames{bg}->{3594564} = "Новоселец";
$areanames{bg}->{3594566} = "Питово";
$areanames{bg}->{3594567} = "Баня\,\ Сливен";
$areanames{bg}->{359457} = "Нова\ Загора";
$areanames{bg}->{3594580} = "Боринци";
$areanames{bg}->{3594582} = "Градец\,\ Сливен";
$areanames{bg}->{3594583} = "Кипилово";
$areanames{bg}->{3594584} = "Тича";
$areanames{bg}->{3594585} = "Жеравна";
$areanames{bg}->{3594586} = "Нейково\,\ Сливен";
$areanames{bg}->{3594587} = "Ябланово";
$areanames{bg}->{3594588} = "Филаретово";
$areanames{bg}->{3594592} = "Бяла\ паланка";
$areanames{bg}->{3594593} = "Шивачево";
$areanames{bg}->{3594595} = "Сборище";
$areanames{bg}->{3594597} = "Боров\ дол";
$areanames{bg}->{3594599} = "Червенаково";
$areanames{bg}->{35946} = "Ямбол";
$areanames{bg}->{359470} = "Тополовград";
$areanames{bg}->{3594710} = "Болярско";
$areanames{bg}->{3594711} = "Безмер\,\ Ямбол";
$areanames{bg}->{3594712} = "Кабиле";
$areanames{bg}->{3594713} = "Стара\ река\,\ Ямбол";
$areanames{bg}->{3594714} = "Дражево";
$areanames{bg}->{3594715} = "Калчево";
$areanames{bg}->{3594716} = "Веселиново\,\ Ямбол";
$areanames{bg}->{3594717} = "Чарган";
$areanames{bg}->{3594718} = "Роза";
$areanames{bg}->{35947192} = "Завой";
$areanames{bg}->{35947193} = "Могила\,\ Ямбол";
$areanames{bg}->{35947201} = "Изгрев\,\ Ямбол";
$areanames{bg}->{35947202} = "Жребино";
$areanames{bg}->{35947203} = "Трънково\,\ Ямбол";
$areanames{bg}->{35947204} = "Пчела";
$areanames{bg}->{3594722} = "Гранитово\,\ Ямбол";
$areanames{bg}->{3594723} = "Бояново\,\ Ямбол";
$areanames{bg}->{3594724} = "Раздел\,\ Ямбол";
$areanames{bg}->{3594725} = "Лесово";
$areanames{bg}->{3594726} = "Маломирово";
$areanames{bg}->{3594727} = "Малък\ манастир";
$areanames{bg}->{3594728} = "Мелница";
$areanames{bg}->{3594729} = "Кирилово\,\ Ямбол";
$areanames{bg}->{3594730} = "Княжево";
$areanames{bg}->{3594732} = "Устрем";
$areanames{bg}->{3594733} = "Орлов\ дол";
$areanames{bg}->{3594734} = "Срем";
$areanames{bg}->{35947353} = "Българска\ поляна";
$areanames{bg}->{35947354} = "Каменна\ река";
$areanames{bg}->{35947356} = "Мрамор\,\ Ямбол";
$areanames{bg}->{3594736} = "Светлина";
$areanames{bg}->{3594737} = "Синапово";
$areanames{bg}->{3594738} = "Хлябово";
$areanames{bg}->{3594739} = "Радовец";
$areanames{bg}->{3594741} = "Болярово";
$areanames{bg}->{3594742} = "Стефан\ Караджово";
$areanames{bg}->{3594743} = "Мамарчево";
$areanames{bg}->{3594744} = "Голямо\ Крушево";
$areanames{bg}->{3594745} = "Шарково";
$areanames{bg}->{3594746} = "Попово\,\ Ямбол";
$areanames{bg}->{3594747} = "Денница\,\ Ямбол";
$areanames{bg}->{3594748} = "Воден\,\ Ямбол";
$areanames{bg}->{3594749} = "Ружица\,\ Ямбол";
$areanames{bg}->{3594751} = "Войника";
$areanames{bg}->{3594752} = "Първенец\,\ Ямбол";
$areanames{bg}->{3594753} = "Зорница\,\ Ямбол";
$areanames{bg}->{3594754} = "Каменец\,\ Ямбол";
$areanames{bg}->{3594755} = "Тамарино";
$areanames{bg}->{3594756} = "Поляна\,\ Ямбол";
$areanames{bg}->{3594757} = "Недялско";
$areanames{bg}->{3594761} = "Стралджа";
$areanames{bg}->{3594762} = "Воденичане";
$areanames{bg}->{3594763} = "Иречеково";
$areanames{bg}->{3594764} = "Маленово";
$areanames{bg}->{3594768} = "Зимница\,\ Ямбол";
$areanames{bg}->{3594770} = "Генерал\ Инзово";
$areanames{bg}->{3594771} = "Маломир\,\ Ямбол";
$areanames{bg}->{3594772} = "Симеоново\,\ Ямбол";
$areanames{bg}->{3594773} = "Окоп";
$areanames{bg}->{3594774} = "Крумово\,\ Ямбол";
$areanames{bg}->{3594775} = "Каравелово\,\ Ямбол";
$areanames{bg}->{3594777} = "Тенево";
$areanames{bg}->{3594778} = "Победа\,\ Ямбол";
$areanames{bg}->{3594779} = "Ханово";
$areanames{bg}->{359478} = "Елхово\,\ Ямбол";
$areanames{bg}->{3594792} = "Ботево\,\ Ямбол";
$areanames{bg}->{3594793} = "Бояджик";
$areanames{bg}->{3594794} = "Овчи\ кладенец";
$areanames{bg}->{3594795} = "Скалица";
$areanames{bg}->{3594796} = "Генерал\ Тошево\,\ Ямбол";
$areanames{bg}->{3594797} = "Гълъбинци";
$areanames{bg}->{3594798} = "Савино";
$areanames{bg}->{3594799} = "Голям\ манастир";
$areanames{bg}->{3595100} = "Синдел";
$areanames{bg}->{3595101} = "Дъбравино";
$areanames{bg}->{3595102} = "Падина\,\ Варна";
$areanames{bg}->{3595105} = "Приселци\,\ Варна";
$areanames{bg}->{3595106} = "Аврен\,\ Варна";
$areanames{bg}->{3595108} = "Садово\,\ Варна";
$areanames{bg}->{35951103} = "Любен\ Каравелово";
$areanames{bg}->{35951104} = "Долище\,\ Варна";
$areanames{bg}->{35951106} = "Осеново\,\ Варна";
$areanames{bg}->{35951108} = "Изворско";
$areanames{bg}->{3595112} = "Белослав";
$areanames{bg}->{35951125} = "Константиново\,\ Варна";
$areanames{bg}->{35951127} = "Разделна\,\ Варна";
$areanames{bg}->{3595114} = "Езерово\,\ Варна";
$areanames{bg}->{3595115} = "Генерал\ Кантарджиево";
$areanames{bg}->{3595116} = "Крумово\,\ Варна";
$areanames{bg}->{3595117} = "Ботево\,\ Варна";
$areanames{bg}->{3595118} = "Водица\,\ Варна";
$areanames{bg}->{3595119} = "Игнатиево";
$areanames{bg}->{3595120} = "Бозвелийско";
$areanames{bg}->{3595121} = "Тутраканци";
$areanames{bg}->{3595122} = "Славейково\,\ Варна";
$areanames{bg}->{3595123} = "Равна\,\ Варна";
$areanames{bg}->{3595124} = "Комарево\,\ Варна";
$areanames{bg}->{3595125} = "Градинарово";
$areanames{bg}->{3595126} = "Черковна\,\ Варна";
$areanames{bg}->{3595127} = "Манастир\,\ Варна";
$areanames{bg}->{3595128} = "Житница\,\ Варна";
$areanames{bg}->{3595129} = "Блъсково";
$areanames{bg}->{3595130} = "Генерал\ Киселово";
$areanames{bg}->{3595131} = "Вълчи\ дол";
$areanames{bg}->{35951314} = "Войводино";
$areanames{bg}->{3595132} = "Михалич\,\ Варна";
$areanames{bg}->{3595133} = "Генерал\ Колево\,\ Варна";
$areanames{bg}->{3595134} = "Червенци";
$areanames{bg}->{3595135} = "Стефан\ Караджа\,\ Варна";
$areanames{bg}->{3595136} = "Брестак";
$areanames{bg}->{3595137} = "Калоян";
$areanames{bg}->{3595138} = "Добротич";
$areanames{bg}->{3595139} = "Оборище\,\ Варна";
$areanames{bg}->{3595140} = "Шкорпиловци";
$areanames{bg}->{3595141} = "Старо\ Оряхово";
$areanames{bg}->{3595142} = "Долни\ чифлик";
$areanames{bg}->{35951428} = "Господиново\,\ Варна";
$areanames{bg}->{35951429} = "Солник";
$areanames{bg}->{3595143} = "Бяла\,\ Варна";
$areanames{bg}->{3595144} = "Камчия";
$areanames{bg}->{3595145} = "Гроздьово";
$areanames{bg}->{3595146} = "Горен\ чифлик";
$areanames{bg}->{3595147} = "Пчелник\,\ Варна";
$areanames{bg}->{3595148} = "Рудник\,\ Варна";
$areanames{bg}->{3595149} = "Голица";
$areanames{bg}->{3595153} = "Суворово";
$areanames{bg}->{35951536} = "Николаевка";
$areanames{bg}->{35951537} = "Чернево";
$areanames{bg}->{35951538} = "Изгрев\,\ Варна";
$areanames{bg}->{35951539} = "Левски\,\ Варна";
$areanames{bg}->{3595161} = "Ветрино";
$areanames{bg}->{3595162} = "Белоградец";
$areanames{bg}->{3595163} = "Млада\ гвардия";
$areanames{bg}->{3595164} = "Неофит\ Рилски";
$areanames{bg}->{3595165} = "Невша";
$areanames{bg}->{3595166} = "Доброплодно";
$areanames{bg}->{3595167} = "Венчан";
$areanames{bg}->{3595168} = "Петров\ дол\,\ Варна";
$areanames{bg}->{3595169} = "Момчилово";
$areanames{bg}->{359517} = "Дългопол";
$areanames{bg}->{359518} = "Провадия";
$areanames{bg}->{359519} = "Девня";
$areanames{bg}->{35952} = "Варна";
$areanames{bg}->{3595310} = "Радко\ Димитриево";
$areanames{bg}->{3595311} = "Градище\,\ Шумен";
$areanames{bg}->{3595312} = "Дибич";
$areanames{bg}->{3595313} = "Мадара";
$areanames{bg}->{3595314} = "Белокопитово";
$areanames{bg}->{3595315} = "Царев\ брод";
$areanames{bg}->{3595316} = "Салманово";
$areanames{bg}->{3595317} = "Ивански";
$areanames{bg}->{3595318} = "Средня";
$areanames{bg}->{3595319} = "Друмево";
$areanames{bg}->{3595320} = "Пет\ могили\,\ Шумен";
$areanames{bg}->{3595321} = "Правенци";
$areanames{bg}->{35953220} = "Памукчии\,\ Шумен";
$areanames{bg}->{35953221} = "Стоян\ Михайловски";
$areanames{bg}->{35953222} = "Марково\,\ Шумен";
$areanames{bg}->{35953223} = "Църквица";
$areanames{bg}->{3595323} = "Плиска";
$areanames{bg}->{35953234} = "Златна\ нива";
$areanames{bg}->{3595324} = "Хърсово\,\ Шумен";
$areanames{bg}->{3595325} = "Войвода";
$areanames{bg}->{3595326} = "Върбяне";
$areanames{bg}->{3595327} = "Каспичан\,\ Шумен";
$areanames{bg}->{3595328} = "Никола\ Козлево";
$areanames{bg}->{3595329} = "Мировци";
$areanames{bg}->{3595330} = "Златар";
$areanames{bg}->{3595332} = "Драгоево";
$areanames{bg}->{3595333} = "Хан\ Крум";
$areanames{bg}->{3595334} = "Осмар";
$areanames{bg}->{3595335} = "Миланово\,\ Шумен";
$areanames{bg}->{3595336} = "Имренчево";
$areanames{bg}->{3595337} = "Кочово";
$areanames{bg}->{3595338} = "Троица";
$areanames{bg}->{3595340} = "Висока\ поляна\,\ Шумен";
$areanames{bg}->{3595341} = "Хитрино";
$areanames{bg}->{3595342} = "Капитан\ Петко";
$areanames{bg}->{3595343} = "Венец\,\ Шумен";
$areanames{bg}->{35953434} = "Ясенково";
$areanames{bg}->{35953435} = "Изгрев\,\ Шумен";
$areanames{bg}->{35953436} = "Черноглавци";
$areanames{bg}->{35953437} = "Габрица\,\ Шумен";
$areanames{bg}->{3595344} = "Велино";
$areanames{bg}->{3595345} = "Развигорово";
$areanames{bg}->{3595346} = "Каменяк\,\ Шумен";
$areanames{bg}->{3595347} = "Живково\,\ Шумен";
$areanames{bg}->{3595348} = "Трем";
$areanames{bg}->{3595349} = "Студеница";
$areanames{bg}->{3595351} = "Смядово";
$areanames{bg}->{3595352} = "Янково";
$areanames{bg}->{3595353} = "Веселиново\,\ Шумен";
$areanames{bg}->{3595354} = "Риш";
$areanames{bg}->{3595361} = "Каолиново";
$areanames{bg}->{3595362} = "Климент\,\ Шумен";
$areanames{bg}->{3595363} = "Гусла";
$areanames{bg}->{3595365} = "Лятно";
$areanames{bg}->{3595366} = "Браничево";
$areanames{bg}->{3595367} = "Тодор\ Икономово";
$areanames{bg}->{3595368} = "Тъкач";
$areanames{bg}->{359537} = "Нови\ пазар\,\ Шумен";
$areanames{bg}->{359538} = "Велики\ Преслав";
$areanames{bg}->{3595391} = "Върбица\,\ Шумен";
$areanames{bg}->{3595392} = "Менгишево";
$areanames{bg}->{3595393} = "Иваново\,\ Шумен";
$areanames{bg}->{3595394} = "Бяла\ река\,\ Шумен";
$areanames{bg}->{3595395} = "Чернооково\,\ Шумен";
$areanames{bg}->{3595396} = "Ловец\,\ Шумен";
$areanames{bg}->{3595397} = "Методиево\,\ Шумен";
$areanames{bg}->{35954} = "Шумен";
$areanames{bg}->{359550} = "Созопол";
$areanames{bg}->{3595511} = "Лукойл\ Нефтохим";
$areanames{bg}->{3595513} = "Габър";
$areanames{bg}->{3595515} = "Камено";
$areanames{bg}->{3595516} = "Индже\ войвода";
$areanames{bg}->{3595517} = "Равнец\,\ Бургас";
$areanames{bg}->{3595518} = "Рудник\,\ Бургас";
$areanames{bg}->{3595519} = "Зидарово";
$areanames{bg}->{3595520} = "Черково";
$areanames{bg}->{3595521} = "Венец\,\ Бургас";
$areanames{bg}->{3595522} = "Искра\,\ Бургас";
$areanames{bg}->{3595523} = "Крумово\ градище";
$areanames{bg}->{3595524} = "Екзарх\ Антимово";
$areanames{bg}->{3595525} = "Деветак";
$areanames{bg}->{3595526} = "Кликач";
$areanames{bg}->{3595527} = "Соколово\,\ Бургас";
$areanames{bg}->{3595528} = "Невестино\,\ Бургас";
$areanames{bg}->{3595529} = "Крушово\,\ Бургас";
$areanames{bg}->{3595530} = "Пещерско";
$areanames{bg}->{3595532} = "Тополица";
$areanames{bg}->{3595533} = "Пирне";
$areanames{bg}->{3595534} = "Карагеоргиево";
$areanames{bg}->{3595535} = "Лясково\,\ Бургас";
$areanames{bg}->{3595536} = "Мъглен";
$areanames{bg}->{3595537} = "Съдиево\,\ Бургас";
$areanames{bg}->{3595538} = "Караново\,\ Бургас";
$areanames{bg}->{3595539} = "Черноград";
$areanames{bg}->{359554} = "Слънчев\ бряг";
$areanames{bg}->{35955502} = "Суходол\,\ Бургас";
$areanames{bg}->{35955504} = "Богданово\,\ Бургас";
$areanames{bg}->{35955505} = "Драчево";
$areanames{bg}->{3595551} = "Средец\,\ Бургас";
$areanames{bg}->{3595552} = "Дюлево\,\ Бургас";
$areanames{bg}->{3595553} = "Орлинци";
$areanames{bg}->{3595554} = "Момина\ църква";
$areanames{bg}->{3595555} = "Факия";
$areanames{bg}->{3595556} = "Голямо\ Буково";
$areanames{bg}->{3595557} = "Бистрец\,\ Бургас";
$areanames{bg}->{3595558} = "Дебелт";
$areanames{bg}->{3595559} = "Кубадин";
$areanames{bg}->{359556} = "Обзор";
$areanames{bg}->{3595570} = "Манолич";
$areanames{bg}->{3595571} = "Сунгурларе";
$areanames{bg}->{3595572} = "Бероново";
$areanames{bg}->{3595573} = "Везенково";
$areanames{bg}->{3595574} = "Съединение\,\ Бургас";
$areanames{bg}->{3595575} = "Прилеп\,\ Бургас";
$areanames{bg}->{3595576} = "Лозарево";
$areanames{bg}->{3595577} = "Подвис\,\ Бургас";
$areanames{bg}->{3595578} = "Терзийско\,\ Бургас";
$areanames{bg}->{3595579} = "Ведрово";
$areanames{bg}->{359558} = "Айтос";
$areanames{bg}->{3595580} = "Трояново\,\ Бургас";
$areanames{bg}->{3595589} = "Винарско";
$areanames{bg}->{359559} = "Карнобат";
$areanames{bg}->{3595590} = "Житосвят";
$areanames{bg}->{3595599} = "Хаджиите";
$areanames{bg}->{35956} = "Бургас";
$areanames{bg}->{359570} = "Каварна";
$areanames{bg}->{3595710} = "Победа\,\ Добр\.";
$areanames{bg}->{3595711} = "Овчарово\,\ Добр\.";
$areanames{bg}->{3595712} = "Стожер";
$areanames{bg}->{3595713} = "Стефаново\,\ Добр\.";
$areanames{bg}->{3595714} = "Карапелит";
$areanames{bg}->{3595715} = "Попгригорово";
$areanames{bg}->{3595716} = "Паскалево";
$areanames{bg}->{3595717} = "Ведрина";
$areanames{bg}->{3595718} = "Смолница";
$areanames{bg}->{3595719} = "Дончево";
$areanames{bg}->{3595723} = "Гурково\,\ Добр\.";
$areanames{bg}->{3595724} = "Дропла\,\ Добр\.";
$areanames{bg}->{3595726} = "Царичино";
$areanames{bg}->{3595727} = "Сенокос\,\ Добр\.";
$areanames{bg}->{35957304} = "Дъбовик";
$areanames{bg}->{35957305} = "Росица\,\ Добр\.";
$areanames{bg}->{35957306} = "Изворово\,\ Добр\.";
$areanames{bg}->{35957307} = "Житен\,\ Добр\.";
$areanames{bg}->{35957308} = "Чернооково\,\ Добр\.";
$areanames{bg}->{3595731} = "Генерал\ Тошево\,\ Добр\.";
$areanames{bg}->{3595732} = "Петлешково";
$areanames{bg}->{3595733} = "Кардам\,\ Добр\.";
$areanames{bg}->{3595734} = "Преселенци";
$areanames{bg}->{3595735} = "Красен\,\ Добр\.";
$areanames{bg}->{3595736} = "Василево";
$areanames{bg}->{3595737} = "Люляково\,\ Добр\.";
$areanames{bg}->{3595738} = "Спасово\,\ Добр\.";
$areanames{bg}->{3595739} = "Пчеларово\,\ Добр\.";
$areanames{bg}->{3595740} = "Горичане";
$areanames{bg}->{3595742} = "Раковски\,\ Добр\.";
$areanames{bg}->{3595743} = "Шабла";
$areanames{bg}->{3595745} = "Вранино";
$areanames{bg}->{3595746} = "Белгун";
$areanames{bg}->{3595747} = "Ваклино";
$areanames{bg}->{3595748} = "Дуранкулак";
$areanames{bg}->{3595749} = "Крапец\,\ Добр\.";
$areanames{bg}->{3595750} = "Каблешково\,\ Добр\.";
$areanames{bg}->{3595751} = "Тервел\,\ Добр\.";
$areanames{bg}->{3595752} = "Нова\ Камена";
$areanames{bg}->{3595753} = "Орляк";
$areanames{bg}->{3595754} = "Зърнево";
$areanames{bg}->{3595755} = "Коларци";
$areanames{bg}->{3595756} = "Божан";
$areanames{bg}->{3595757} = "Безмер\,\ Добр\.";
$areanames{bg}->{3595758} = "Кладенци";
$areanames{bg}->{3595759} = "Кочмар";
$areanames{bg}->{3595760} = "Божурово\,\ Добр\.";
$areanames{bg}->{3595761} = "Батово";
$areanames{bg}->{3595762} = "Стефан\ Караджа\,\ Добр\.";
$areanames{bg}->{3595763} = "Плачидол";
$areanames{bg}->{3595764} = "Владимирово\,\ Добр\.";
$areanames{bg}->{3595765} = "Ловчанци";
$areanames{bg}->{3595766} = "Методиево\,\ Добр\.";
$areanames{bg}->{3595767} = "Житница\,\ Добр\.";
$areanames{bg}->{3595768} = "Одринци\,\ Добр\.";
$areanames{bg}->{3595769} = "Хитово";
$areanames{bg}->{3595771} = "Крушари";
$areanames{bg}->{3595772} = "Телериг";
$areanames{bg}->{3595773} = "Лозенец\,\ Добр\.";
$areanames{bg}->{3595774} = "Коритен";
$areanames{bg}->{3595775} = "Полковник\ Дяково";
$areanames{bg}->{3595776} = "Черна\,\ Добр\.";
$areanames{bg}->{3595781} = "Свобода\,\ Добр\.";
$areanames{bg}->{3595782} = "Бенковски\,\ Добр\.";
$areanames{bg}->{3595783} = "Котленци";
$areanames{bg}->{3595784} = "Врачанци";
$areanames{bg}->{359579} = "Албена";
$areanames{bg}->{35958} = "Добрич";
$areanames{bg}->{359590} = "Царево";
$areanames{bg}->{3595910} = "Черни\ връх\,\ Бургас";
$areanames{bg}->{3595912} = "Полски\ извор";
$areanames{bg}->{3595913} = "Крушевец";
$areanames{bg}->{3595914} = "Атия";
$areanames{bg}->{3595915} = "Българово";
$areanames{bg}->{3595916} = "Росен\,\ Бургас";
$areanames{bg}->{3595917} = "Извор\,\ Бургас";
$areanames{bg}->{3595918} = "Русокастро";
$areanames{bg}->{3595919} = "Маринка";
$areanames{bg}->{35959400} = "Дъскотна";
$areanames{bg}->{35959403} = "Речица";
$areanames{bg}->{35959404} = "Ясеново\,\ Бургас";
$areanames{bg}->{35959405} = "Зайчар";
$areanames{bg}->{35959406} = "Разбойна\,\ Бургас";
$areanames{bg}->{35959407} = "Сини\ рид";
$areanames{bg}->{35959408} = "Ръжица";
$areanames{bg}->{35959409} = "Череша";
$areanames{bg}->{3595941} = "Скалак\,\ Бургас";
$areanames{bg}->{3595942} = "Люляково\,\ Бургас";
$areanames{bg}->{3595943} = "Вресово";
$areanames{bg}->{3595944} = "Руен\,\ Бургас";
$areanames{bg}->{3595945} = "Добромир";
$areanames{bg}->{3595946} = "Трънак";
$areanames{bg}->{3595947} = "Просеник";
$areanames{bg}->{3595948} = "Снягово\,\ Бургас";
$areanames{bg}->{3595949} = "Планиница\,\ Бургас";
$areanames{bg}->{3595952} = "Малко\ Търново";
$areanames{bg}->{3595958} = "Граматиково";
$areanames{bg}->{3595959} = "Звездец";
$areanames{bg}->{359596} = "Поморие";
$areanames{bg}->{3595967} = "Бата";
$areanames{bg}->{3595968} = "Каблешково\,\ Бургас";
$areanames{bg}->{3595969} = "Гълъбец\,\ Бургас";
$areanames{bg}->{35959694} = "Габерово";
$areanames{bg}->{3596001} = "Черковна\,\ Търг\.";
$areanames{bg}->{3596002} = "Съединение\,\ Търг\.";
$areanames{bg}->{3596003} = "Преселец";
$areanames{bg}->{3596004} = "Маково";
$areanames{bg}->{3596006} = "Пресиян";
$areanames{bg}->{3596007} = "Ралица";
$areanames{bg}->{359601} = "Търговище";
$areanames{bg}->{3596020} = "Лиляк";
$areanames{bg}->{3596021} = "Буховци";
$areanames{bg}->{3596022} = "Пробуда\,\ Търг\.";
$areanames{bg}->{3596023} = "Подгорица";
$areanames{bg}->{3596024} = "Руец";
$areanames{bg}->{3596025} = "Алваново";
$areanames{bg}->{3596026} = "Макариополско";
$areanames{bg}->{3596027} = "Дралфа";
$areanames{bg}->{3596028} = "Вардун";
$areanames{bg}->{3596029} = "Надарево";
$areanames{bg}->{3596030} = "Светлен\,\ Търг\.";
$areanames{bg}->{3596032} = "Зараево";
$areanames{bg}->{3596033} = "Медовина";
$areanames{bg}->{3596034} = "Славяново\,\ Търг\.";
$areanames{bg}->{3596035} = "Паламарца";
$areanames{bg}->{3596036} = "Садина";
$areanames{bg}->{35960370} = "Голямо\ градище";
$areanames{bg}->{35960372} = "Крепча";
$areanames{bg}->{35960373} = "Посабина";
$areanames{bg}->{35960374} = "Горско\ Абланово";
$areanames{bg}->{35960375} = "Гърчиново";
$areanames{bg}->{35960376} = "Люблен";
$areanames{bg}->{35960377} = "Априлово\,\ Търг\.";
$areanames{bg}->{35960378} = "Цар\ Асен\,\ Търг\.";
$areanames{bg}->{35960380} = "Дриново";
$areanames{bg}->{35960382} = "Ковачевец";
$areanames{bg}->{35960383} = "Берковски";
$areanames{bg}->{35960384} = "Гагово";
$areanames{bg}->{35960385} = "Ломци";
$areanames{bg}->{35960386} = "Водица\,\ Търг\.";
$areanames{bg}->{35960387} = "Глогинка";
$areanames{bg}->{35960388} = "Горица\,\ Търг\.";
$areanames{bg}->{35960389} = "Кардам\,\ Търг\.";
$areanames{bg}->{3596039} = "Опака";
$areanames{bg}->{3596042} = "Илийно";
$areanames{bg}->{3596043} = "Долно\ Новково";
$areanames{bg}->{3596044} = "Долно\ Козарево";
$areanames{bg}->{35960450} = "Долна\ Хубавка";
$areanames{bg}->{35960451} = "Обител";
$areanames{bg}->{35960453} = "Моравка";
$areanames{bg}->{35960454} = "Змейно";
$areanames{bg}->{35960458} = "Веренци";
$areanames{bg}->{3596046} = "Врани\ кон";
$areanames{bg}->{3596047} = "Зелена\ морава";
$areanames{bg}->{3596048} = "Изворово\,\ Търг\.";
$areanames{bg}->{3596049} = "Камбурово";
$areanames{bg}->{359605} = "Омуртаг";
$areanames{bg}->{3596060} = "Овчарово\,\ Търг\.";
$areanames{bg}->{3596061} = "Голямо\ Соколово";
$areanames{bg}->{3596062} = "Стража\,\ Търг\.";
$areanames{bg}->{3596063} = "Баячево";
$areanames{bg}->{3596064} = "Голямо\ Ново";
$areanames{bg}->{3596065} = "Бистра\,\ Търг\.";
$areanames{bg}->{3596066} = "Буйново\,\ Търг\.";
$areanames{bg}->{3596067} = "Кралево\,\ Търг\.";
$areanames{bg}->{3596068} = "Божурка";
$areanames{bg}->{3596069} = "Васил\ Левски\,\ Търг\.";
$areanames{bg}->{3596071} = "Антоново";
$areanames{bg}->{3596072} = "Добротица\,\ Търг\.";
$areanames{bg}->{3596074} = "Любичево";
$areanames{bg}->{3596076} = "Таймище";
$areanames{bg}->{3596077} = "Стеврек";
$areanames{bg}->{359608} = "Попово\,\ Търг\.";
$areanames{bg}->{359610} = "Павликени\,\ В\.\ Търново";
$areanames{bg}->{35961101} = "Велчево\,\ В\.\ Търново";
$areanames{bg}->{35961102} = "Пчелище";
$areanames{bg}->{35961103} = "Русаля";
$areanames{bg}->{35961104} = "Водолей";
$areanames{bg}->{35961105} = "Присово";
$areanames{bg}->{35961106} = "Ново\ село\,\ В\.\ Търново";
$areanames{bg}->{35961107} = "Момин\ сбор";
$areanames{bg}->{35961108} = "Плаково";
$areanames{bg}->{35961109} = "Въглевци";
$areanames{bg}->{3596111} = "Къпиново\,\ В\.\ Търново";
$areanames{bg}->{3596112} = "Самоводене";
$areanames{bg}->{3596113} = "Балван";
$areanames{bg}->{3596114} = "Килифарево";
$areanames{bg}->{3596115} = "Ресен";
$areanames{bg}->{3596116} = "Големаните";
$areanames{bg}->{3596117} = "Дебелец\,\ В\.\ Търново";
$areanames{bg}->{3596118} = "Вонеща\ вода";
$areanames{bg}->{3596119} = "Дичин";
$areanames{bg}->{35961203} = "Емен";
$areanames{bg}->{3596121} = "Никюп";
$areanames{bg}->{3596122} = "Беляковец";
$areanames{bg}->{3596123} = "Буковец\,\ В\.\ Търново";
$areanames{bg}->{3596124} = "Леденик";
$areanames{bg}->{3596125} = "Пушево";
$areanames{bg}->{3596126} = "Церова\ кория";
$areanames{bg}->{3596128} = "Хотница";
$areanames{bg}->{3596129} = "Габровци";
$areanames{bg}->{35961301} = "Бяла\ река\,\ В\.\ Търново";
$areanames{bg}->{35961302} = "Батак\,\ В\.\ Търново";
$areanames{bg}->{35961303} = "Горна\ Липница";
$areanames{bg}->{35961304} = "Димча";
$areanames{bg}->{35961305} = "Лесичери";
$areanames{bg}->{35961306} = "Патреш";
$areanames{bg}->{35961307} = "Стамболово\,\ В\.\ Търново";
$areanames{bg}->{35961308} = "Вишовград";
$areanames{bg}->{35961309} = "Горско\ Калугерово";
$areanames{bg}->{3596132} = "Караисен";
$areanames{bg}->{3596133} = "Михалци";
$areanames{bg}->{3596134} = "Бяла\ черква\,\ В\.\ Търново";
$areanames{bg}->{3596135} = "Върбовка";
$areanames{bg}->{3596136} = "Сухиндол";
$areanames{bg}->{3596137} = "Бутово";
$areanames{bg}->{3596138} = "Недан";
$areanames{bg}->{35961391} = "Сломер";
$areanames{bg}->{35961393} = "Горско\ Косово";
$areanames{bg}->{35961394} = "Дъскот";
$areanames{bg}->{35961395} = "Паскалевец";
$areanames{bg}->{35961397} = "Мусина";
$areanames{bg}->{35961402} = "Стефан\ Стамболово";
$areanames{bg}->{35961403} = "Орловец";
$areanames{bg}->{35961405} = "Петко\ Каравелово";
$areanames{bg}->{35961406} = "Каранци";
$areanames{bg}->{3596141} = "Полски\ Тръмбеш";
$areanames{bg}->{3596142} = "Обединение";
$areanames{bg}->{3596143} = "Масларево";
$areanames{bg}->{3596144} = "Долна\ Липница";
$areanames{bg}->{3596145} = "Страхилово";
$areanames{bg}->{3596146} = "Полски\ Сеновец";
$areanames{bg}->{3596147} = "Иванча\,\ В\.\ Търново";
$areanames{bg}->{3596148} = "Павел";
$areanames{bg}->{3596149} = "Куцина";
$areanames{bg}->{3596150} = "Златарица";
$areanames{bg}->{35961502} = "Горско\ Ново\ Село";
$areanames{bg}->{35961503} = "Чакали";
$areanames{bg}->{3596151} = "Елена\,\ В\.\ Търново";
$areanames{bg}->{3596152} = "Беброво";
$areanames{bg}->{3596153} = "Златарица";
$areanames{bg}->{3596154} = "Буйновци";
$areanames{bg}->{3596155} = "Константин";
$areanames{bg}->{3596156} = "Родина";
$areanames{bg}->{3596157} = "Сливовица";
$areanames{bg}->{3596158} = "Средни\ колиби";
$areanames{bg}->{3596159} = "Златарица";
$areanames{bg}->{35961602} = "Царски\ извор";
$areanames{bg}->{35961603} = "Лозен\,\ В\.\ Търново";
$areanames{bg}->{35961604} = "Мирово\,\ В\.\ Търново";
$areanames{bg}->{35961605} = "Ново\ градище";
$areanames{bg}->{35961606} = "Владислав";
$areanames{bg}->{35961607} = "Балканци\,\ В\.\ Търново";
$areanames{bg}->{35961608} = "Горски\ Сеновец";
$areanames{bg}->{3596161} = "Стражица\,\ В\.\ Търново";
$areanames{bg}->{3596163} = "Камен\,\ В\.\ Търново";
$areanames{bg}->{3596164} = "Бряговица";
$areanames{bg}->{3596165} = "Асеново\,\ В\.\ Търново";
$areanames{bg}->{3596166} = "Виноград";
$areanames{bg}->{3596167} = "Кесарево";
$areanames{bg}->{3596168} = "Сушица\,\ В\.\ Търново";
$areanames{bg}->{3596169} = "Благоево\,\ В\.\ Търново";
$areanames{bg}->{35961703} = "Върбица\,\ В\.\ Търново";
$areanames{bg}->{35961704} = "Правда\,\ В\.\ Търново";
$areanames{bg}->{35961705} = "Горски\ долен\ Тръмбеш";
$areanames{bg}->{35961706} = "Писарево\,\ В\.\ Търново";
$areanames{bg}->{3596173} = "Долна\ Оряховица";
$areanames{bg}->{3596174} = "Драганово\,\ В\.\ Търново";
$areanames{bg}->{3596175} = "Първомайци";
$areanames{bg}->{3596176} = "Поликраище";
$areanames{bg}->{3596177} = "Янтра\,\ В\.\ Търново";
$areanames{bg}->{3596178} = "Стрелец\,\ В\.\ Търново";
$areanames{bg}->{3596179} = "Крушето";
$areanames{bg}->{359618} = "Горна\ Оряховица";
$areanames{bg}->{359619} = "Лясковец\,\ В\.\ Търново";
$areanames{bg}->{35962} = "Велико\ Търново";
$areanames{bg}->{359631} = "Свищов";
$areanames{bg}->{35963202} = "Драгомирово\,\ В\.\ Търново";
$areanames{bg}->{35963203} = "Хаджидимитрово\,\ В\.\ Търново";
$areanames{bg}->{35963204} = "Деляновци";
$areanames{bg}->{35963205} = "Червена";
$areanames{bg}->{3596321} = "Горна\ Студена";
$areanames{bg}->{3596322} = "Алеково\,\ В\.\ Търново";
$areanames{bg}->{3596323} = "Българско\ сливово";
$areanames{bg}->{3596324} = "Вардим";
$areanames{bg}->{3596325} = "Козловец";
$areanames{bg}->{3596326} = "Морава";
$areanames{bg}->{3596327} = "Овча\ могила";
$areanames{bg}->{3596328} = "Ореш";
$areanames{bg}->{3596329} = "Царевец\,\ В\.\ Търново";
$areanames{bg}->{3596352} = "Долни\ Луковит";
$areanames{bg}->{35963560} = "Радишево";
$areanames{bg}->{35963561} = "Гривица";
$areanames{bg}->{35963562} = "Комарево\,\ Плевен";
$areanames{bg}->{35963563} = "Борислав";
$areanames{bg}->{35963564} = "Биволаре";
$areanames{bg}->{35963565} = "Мечка\,\ Плевен";
$areanames{bg}->{35963566} = "Бръшляница";
$areanames{bg}->{35963567} = "Градина\,\ Плевен";
$areanames{bg}->{35963568} = "Буковлък";
$areanames{bg}->{35963569} = "Каменец\,\ Плевен";
$areanames{bg}->{35963570} = "Староселци";
$areanames{bg}->{35963571} = "Брестовец";
$areanames{bg}->{35963572} = "Ясен\,\ Плевен";
$areanames{bg}->{35963573} = "Дисевица";
$areanames{bg}->{35963574} = "Тодорово\,\ Плевен";
$areanames{bg}->{35963575} = "Бохот";
$areanames{bg}->{35963576} = "Тученица";
$areanames{bg}->{35963577} = "Пелишат";
$areanames{bg}->{35963578} = "Опанец\,\ Плевен";
$areanames{bg}->{35963579} = "Ралево";
$areanames{bg}->{3596359} = "Глава";
$areanames{bg}->{35964} = "Плевен";
$areanames{bg}->{359650} = "Левски\,\ Плевен";
$areanames{bg}->{3596510} = "Тотлебен";
$areanames{bg}->{3596511} = "Победа\,\ Плевен";
$areanames{bg}->{3596512} = "Горни\ Дъбник";
$areanames{bg}->{3596513} = "Пордим";
$areanames{bg}->{3596514} = "Долни\ Дъбник";
$areanames{bg}->{3596515} = "Славяново\,\ Плевен";
$areanames{bg}->{3596516} = "Искър\,\ Плевен";
$areanames{bg}->{35965165} = "Писарово\,\ Плевен";
$areanames{bg}->{3596517} = "Подем";
$areanames{bg}->{3596518} = "Рибен";
$areanames{bg}->{3596519} = "Беглеж";
$areanames{bg}->{3596520} = "Николаево\,\ Плевен";
$areanames{bg}->{3596521} = "Садовец";
$areanames{bg}->{3596522} = "Згалево";
$areanames{bg}->{3596523} = "Крушовица\,\ Плевен";
$areanames{bg}->{3596524} = "Петърница";
$areanames{bg}->{3596525} = "Бъркач";
$areanames{bg}->{3596526} = "Върбица\,\ Плевен";
$areanames{bg}->{3596527} = "Одърне";
$areanames{bg}->{3596528} = "Вълчитрън";
$areanames{bg}->{3596529} = "Коиловци";
$areanames{bg}->{3596530} = "Трънчовица";
$areanames{bg}->{3596531} = "Изгрев\,\ Плевен";
$areanames{bg}->{3596532} = "Българене\,\ Плевен";
$areanames{bg}->{3596533} = "Стежерово";
$areanames{bg}->{3596534} = "Малчика";
$areanames{bg}->{3596535} = "Козар\ Белене";
$areanames{bg}->{3596536} = "Аспарухово\,\ Плевен";
$areanames{bg}->{3596537} = "Асеновци";
$areanames{bg}->{3596538} = "Обнова";
$areanames{bg}->{3596539} = "Градище\,\ Плевен";
$areanames{bg}->{3596540} = "Асеново\,\ Плевен";
$areanames{bg}->{3596541} = "Никопол";
$areanames{bg}->{3596542} = "Въбел\,\ Плевен";
$areanames{bg}->{3596543} = "Муселиево";
$areanames{bg}->{3596544} = "Новачене\,\ Плевен";
$areanames{bg}->{3596545} = "Любеново\,\ Плевен";
$areanames{bg}->{3596546} = "Лозица\,\ Плевен";
$areanames{bg}->{3596547} = "Драгаш\ войвода";
$areanames{bg}->{3596548} = "Дебово";
$areanames{bg}->{3596549} = "Санадиново";
$areanames{bg}->{3596550} = "Ставерци";
$areanames{bg}->{3596551} = "Тръстеник\,\ Плевен";
$areanames{bg}->{3596552} = "Долна\ Митрополия";
$areanames{bg}->{3596553} = "Оряховица\,\ Плевен";
$areanames{bg}->{3596554} = "Крушовене";
$areanames{bg}->{3596555} = "Байкал";
$areanames{bg}->{3596556} = "Горна\ Митрополия";
$areanames{bg}->{3596557} = "Брегаре";
$areanames{bg}->{3596558} = "Славовица\,\ Плевен";
$areanames{bg}->{3596559} = "Гостиля";
$areanames{bg}->{3596560} = "Крета\,\ Плевен";
$areanames{bg}->{3596561} = "Гулянци";
$areanames{bg}->{35965617} = "Искър\,\ Плевен";
$areanames{bg}->{3596562} = "Гиген";
$areanames{bg}->{3596563} = "Брест\,\ Плевен";
$areanames{bg}->{3596564} = "Загражден\,\ Плевен";
$areanames{bg}->{3596565} = "Милковица";
$areanames{bg}->{3596566} = "Долни\ Вит";
$areanames{bg}->{3596567} = "Сомовит";
$areanames{bg}->{3596568} = "Дъбован";
$areanames{bg}->{3596569} = "Ленково";
$areanames{bg}->{3596570} = "Девенци";
$areanames{bg}->{3596571} = "Лепица";
$areanames{bg}->{3596572} = "Сухаче";
$areanames{bg}->{3596573} = "Койнаре";
$areanames{bg}->{3596574} = "Чомаковци";
$areanames{bg}->{3596575} = "Телиш";
$areanames{bg}->{3596576} = "Радомирци";
$areanames{bg}->{3596577} = "Бресте";
$areanames{bg}->{3596578} = "Реселец";
$areanames{bg}->{3596579} = "Рупци\,\ Плевен";
$areanames{bg}->{3596580} = "Татари";
$areanames{bg}->{3596581} = "Бяла\ вода\,\ Плевен";
$areanames{bg}->{3596582} = "Белене";
$areanames{bg}->{3596583} = "Белене";
$areanames{bg}->{3596584} = "Белене";
$areanames{bg}->{3596585} = "Белене";
$areanames{bg}->{3596586} = "Белене";
$areanames{bg}->{3596587} = "Петокладенци";
$areanames{bg}->{3596588} = "Деков";
$areanames{bg}->{3596589} = "Кулина\ вода";
$areanames{bg}->{359659} = "Червен\ бряг";
$areanames{bg}->{3596590} = "Ракита\,\ Плевен";
$areanames{bg}->{3596591} = "Горник";
$areanames{bg}->{35966} = "Габрово";
$areanames{bg}->{359670} = "Троян\,\ Ловеч";
$areanames{bg}->{3596710} = "Донино";
$areanames{bg}->{3596711} = "Кози\ рог";
$areanames{bg}->{3596712} = "Гъбене";
$areanames{bg}->{3596713} = "Враниловци";
$areanames{bg}->{3596714} = "Поповци";
$areanames{bg}->{3596716} = "Жълтеш";
$areanames{bg}->{3596717} = "Лесичарка";
$areanames{bg}->{3596718} = "Драгановци";
$areanames{bg}->{35967193} = "Кметовци";
$areanames{bg}->{35967194} = "Гръблевци";
$areanames{bg}->{3596720} = "Керека";
$areanames{bg}->{3596722} = "Соколово\,\ Габр\.";
$areanames{bg}->{3596723} = "Царева\ ливада";
$areanames{bg}->{3596724} = "Янтра\,\ Габр\.";
$areanames{bg}->{3596725} = "Гостилица";
$areanames{bg}->{3596726} = "Скалско";
$areanames{bg}->{3596727} = "Ганчовец";
$areanames{bg}->{3596728} = "Буря";
$areanames{bg}->{35967301} = "Идилево";
$areanames{bg}->{35967302} = "Кръвеник";
$areanames{bg}->{35967303} = "Батошево";
$areanames{bg}->{35967304} = "Крамолин";
$areanames{bg}->{35967305} = "Стоките";
$areanames{bg}->{35967306} = "Градище\,\ Габр\.";
$areanames{bg}->{35967307} = "Млечево";
$areanames{bg}->{35967308} = "Ловнидол";
$areanames{bg}->{35967309} = "Агатово";
$areanames{bg}->{3596732} = "Сенник";
$areanames{bg}->{3596733} = "Кормянско";
$areanames{bg}->{3596734} = "Петко\ Славейков";
$areanames{bg}->{3596736} = "Градница\,\ Габр\.";
$areanames{bg}->{3596737} = "Крушево\,\ Габр\.";
$areanames{bg}->{3596738} = "Добромирка";
$areanames{bg}->{35967390} = "Шумата";
$areanames{bg}->{35967391} = "Столът";
$areanames{bg}->{35967392} = "Яворец";
$areanames{bg}->{35967393} = "Душево";
$areanames{bg}->{35967394} = "Богатово";
$areanames{bg}->{35967395} = "Горна\ Росица";
$areanames{bg}->{35967396} = "Бериево";
$areanames{bg}->{35967397} = "Ряховците";
$areanames{bg}->{35967398} = "Дамяново";
$areanames{bg}->{35967399} = "Малки\ Вършец";
$areanames{bg}->{359675} = "Севлиево";
$areanames{bg}->{359676} = "Дряново\,\ Габр\.";
$areanames{bg}->{359677} = "Трявна";
$areanames{bg}->{3596770} = "Плачковци";
$areanames{bg}->{35967774} = "Белица\,\ Габр\.";
$areanames{bg}->{359678} = "Тетевен";
$areanames{bg}->{35968} = "Ловеч";
$areanames{bg}->{3596900} = "Васильово";
$areanames{bg}->{3596901} = "Гложене\,\ Ловеч";
$areanames{bg}->{3596902} = "Рибарица\,\ Ловеч";
$areanames{bg}->{35969031} = "Галата";
$areanames{bg}->{35969032} = "Български\ извор";
$areanames{bg}->{3596905} = "Дивчовото";
$areanames{bg}->{3596906} = "Черни\ Вит";
$areanames{bg}->{3596907} = "Градежница";
$areanames{bg}->{3596908} = "Глогово";
$areanames{bg}->{3596909} = "Малка\ Желязна";
$areanames{bg}->{3596910} = "Малиново";
$areanames{bg}->{3596911} = "Лисец\,\ Ловеч";
$areanames{bg}->{3596912} = "Баховица";
$areanames{bg}->{3596913} = "Славяни";
$areanames{bg}->{3596914} = "Сливек";
$areanames{bg}->{3596915} = "Смочан";
$areanames{bg}->{3596916} = "Брестово\,\ Ловеч";
$areanames{bg}->{3596917} = "Българене\,\ Ловеч";
$areanames{bg}->{3596918} = "Дренов";
$areanames{bg}->{3596919} = "Слатина\,\ Ловеч";
$areanames{bg}->{3596920} = "Лесидрен";
$areanames{bg}->{3596921} = "Абланица\,\ Ловеч";
$areanames{bg}->{3596922} = "Лешница\,\ Ловеч";
$areanames{bg}->{3596923} = "Горан";
$areanames{bg}->{35969240} = "Хлевене";
$areanames{bg}->{35969241} = "Йоглав";
$areanames{bg}->{35969242} = "Пресяка";
$areanames{bg}->{35969243} = "Казачево";
$areanames{bg}->{35969244} = "Тепава";
$areanames{bg}->{35969245} = "Деветаки";
$areanames{bg}->{35969247} = "Гостиня";
$areanames{bg}->{35969248} = "Скобелево\,\ Ловеч";
$areanames{bg}->{35969249} = "Дойренци";
$areanames{bg}->{3596925} = "Владиня";
$areanames{bg}->{3596926} = "Горно\ Павликене";
$areanames{bg}->{3596927} = "Умаревци";
$areanames{bg}->{3596928} = "Къкрина";
$areanames{bg}->{3596929} = "Радювене";
$areanames{bg}->{3596930} = "Славщица";
$areanames{bg}->{3596931} = "Угърчин";
$areanames{bg}->{3596932} = "Микре";
$areanames{bg}->{3596933} = "Голец";
$areanames{bg}->{3596934} = "Катунец";
$areanames{bg}->{3596935} = "Сопот\,\ Ловеч";
$areanames{bg}->{3596937} = "Соколово\,\ Ловеч";
$areanames{bg}->{3596938} = "Каленик\,\ Ловеч";
$areanames{bg}->{3596939} = "Драгана";
$areanames{bg}->{3596941} = "Летница";
$areanames{bg}->{3596942} = "Александрово\,\ Ловеч";
$areanames{bg}->{3596943} = "Горско\ Сливово";
$areanames{bg}->{3596944} = "Крушуна";
$areanames{bg}->{3596946} = "Чавдарци";
$areanames{bg}->{3596948} = "Кърпачево";
$areanames{bg}->{3596950} = "Гумощник";
$areanames{bg}->{3596952} = "Орешак\,\ Ловеч";
$areanames{bg}->{3596953} = "Борима";
$areanames{bg}->{3596954} = "Врабево";
$areanames{bg}->{3596955} = "Дълбок\ дол";
$areanames{bg}->{3596956} = "Ломец\,\ Ловеч";
$areanames{bg}->{3596957} = "Голяма\ Желязна";
$areanames{bg}->{3596958} = "Априлци\,\ Ловеч";
$areanames{bg}->{3596959} = "Дебнево";
$areanames{bg}->{3596960} = "Белиш";
$areanames{bg}->{35969612} = "Терзийско\,\ Ловеч";
$areanames{bg}->{35969613} = "Чифлик\,\ Ловеч";
$areanames{bg}->{35969614} = "Горно\ трапе";
$areanames{bg}->{35969615} = "Балабанско";
$areanames{bg}->{35969616} = "Старо\ село\,\ Ловеч";
$areanames{bg}->{3596962} = "Черни\ Осъм";
$areanames{bg}->{3596963} = "Балканец";
$areanames{bg}->{3596964} = "Велчево\,\ Ловеч";
$areanames{bg}->{3596965} = "Бели\ Осъм";
$areanames{bg}->{3596966} = "Шипково";
$areanames{bg}->{3596967} = "Калейца";
$areanames{bg}->{3596968} = "Добродан";
$areanames{bg}->{3596969} = "Беклемето";
$areanames{bg}->{359697} = "Луковит";
$areanames{bg}->{3596980} = "Беленци";
$areanames{bg}->{3596981} = "Петревене";
$areanames{bg}->{3596982} = "Ъглен";
$areanames{bg}->{3596983} = "Дерманци";
$areanames{bg}->{3596984} = "Бежаново\,\ Ловеч";
$areanames{bg}->{3596985} = "Румянцево";
$areanames{bg}->{3596986} = "Дъбен";
$areanames{bg}->{3596987} = "Карлуково";
$areanames{bg}->{3596988} = "Пещерна";
$areanames{bg}->{3596989} = "Торос";
$areanames{bg}->{3596990} = "Малък\ извор\,\ Ловеч";
$areanames{bg}->{3596991} = "Ябланица";
$areanames{bg}->{3596992} = "Златна\ Панега";
$areanames{bg}->{3596994} = "Брестница\,\ Ловеч";
$areanames{bg}->{3596997} = "Добревци\,\ Ловеч";
$areanames{bg}->{3596998} = "Голям\ извор\,\ Ловеч";
$areanames{bg}->{359701} = "Дупница";
$areanames{bg}->{359702} = "Бобов\ дол";
$areanames{bg}->{3597030} = "Ресилово";
$areanames{bg}->{3597031} = "Горна\ Козница";
$areanames{bg}->{3597032} = "Яхиново";
$areanames{bg}->{3597033} = "Крайници";
$areanames{bg}->{3597034} = "Джерман";
$areanames{bg}->{3597035} = "Червен\ брег";
$areanames{bg}->{3597036} = "Баланово";
$areanames{bg}->{3597039} = "Самораново";
$areanames{bg}->{3597041} = "Шатрово";
$areanames{bg}->{3597042} = "Коркина";
$areanames{bg}->{3597043} = "Големо\ село";
$areanames{bg}->{3597044} = "Бабино";
$areanames{bg}->{3597045} = "Голем\ Върбовник";
$areanames{bg}->{3597046} = "Бобошево";
$areanames{bg}->{3597047} = "Усойка";
$areanames{bg}->{3597048} = "Блажиево";
$areanames{bg}->{3597052} = "Пастра";
$areanames{bg}->{3597053} = "Кочериново";
$areanames{bg}->{3597054} = "Рила";
$areanames{bg}->{3597056} = "Мурсалево";
$areanames{bg}->{3597057} = "Мало\ село";
$areanames{bg}->{3597058} = "Стоб";
$areanames{bg}->{359707} = "Сапарева\ баня";
$areanames{bg}->{3597102} = "Лопян";
$areanames{bg}->{3597103} = "Брусен\,\ София";
$areanames{bg}->{3597104} = "Лъга";
$areanames{bg}->{3597105} = "Малки\ Искър";
$areanames{bg}->{3597106} = "Ямна";
$areanames{bg}->{3597110} = "Опицвет";
$areanames{bg}->{3597116} = "Петърч";
$areanames{bg}->{3597117} = "Градец\,\ София";
$areanames{bg}->{3597118} = "Драговищица\,\ София";
$areanames{bg}->{3597119} = "Дръмша";
$areanames{bg}->{3597120} = "Долна\ баня";
$areanames{bg}->{35971220} = "Гуцал";
$areanames{bg}->{35971221} = "Ярлово";
$areanames{bg}->{35971224} = "Шипочане";
$areanames{bg}->{35971225} = "Ново\ село\,\ София";
$areanames{bg}->{35971227} = "Бели\ Искър";
$areanames{bg}->{35971228} = "Марица";
$areanames{bg}->{3597123} = "Ковачевци\,\ София";
$areanames{bg}->{3597124} = "Белчински\ бани";
$areanames{bg}->{3597125} = "Говедарци";
$areanames{bg}->{3597126} = "Горни\ Окол";
$areanames{bg}->{3597127} = "Широки\ дол";
$areanames{bg}->{3597129} = "Радуил";
$areanames{bg}->{35971302} = "Боженица";
$areanames{bg}->{35971304} = "Липница\,\ София";
$areanames{bg}->{35971306} = "Рашково";
$areanames{bg}->{3597132} = "Радотина";
$areanames{bg}->{3597133} = "Правец";
$areanames{bg}->{35971337} = "Калугерово\,\ София";
$areanames{bg}->{35971338} = "Осиковска\ Лакавица";
$areanames{bg}->{3597134} = "Врачеш";
$areanames{bg}->{3597135} = "Трудовец";
$areanames{bg}->{3597136} = "Новачене\,\ София";
$areanames{bg}->{3597137} = "Скравена";
$areanames{bg}->{3597138} = "Литаково";
$areanames{bg}->{3597139} = "Джурово";
$areanames{bg}->{35971398} = "Осиковица";
$areanames{bg}->{3597142} = "Костенец";
$areanames{bg}->{3597143} = "Вакарел";
$areanames{bg}->{3597144} = "Костенец";
$areanames{bg}->{3597145} = "Мирово\,\ София";
$areanames{bg}->{3597146} = "Черньово";
$areanames{bg}->{3597147} = "Пчелин\,\ София";
$areanames{bg}->{35971471} = "Очуша";
$areanames{bg}->{3597148} = "Мухово";
$areanames{bg}->{3597149} = "Живково\,\ София";
$areanames{bg}->{35971502} = "Елешница\,\ София";
$areanames{bg}->{35971503} = "Долно\ Камарци";
$areanames{bg}->{35971504} = "Белопопци";
$areanames{bg}->{35971505} = "Чурек";
$areanames{bg}->{35971506} = "Габра";
$areanames{bg}->{3597152} = "Горна\ Малина";
$areanames{bg}->{3597154} = "Столник";
$areanames{bg}->{3597155} = "Лесново";
$areanames{bg}->{3597156} = "Равно\ поле";
$areanames{bg}->{3597157} = "Саранци";
$areanames{bg}->{3597158} = "Доганово";
$areanames{bg}->{35971587} = "Голема\ Раковица";
$areanames{bg}->{3597159} = "Априлово\,\ София";
$areanames{bg}->{3597162} = "Лакатник";
$areanames{bg}->{3597163} = "Искрец";
$areanames{bg}->{3597164} = "Реброво";
$areanames{bg}->{3597165} = "Миланово\,\ София";
$areanames{bg}->{3597166} = "Владо\ Тричков";
$areanames{bg}->{3597167} = "Церово\,\ София";
$areanames{bg}->{3597168} = "Бов";
$areanames{bg}->{3597169} = "Томпсън";
$areanames{bg}->{3597172} = "Драгоман";
$areanames{bg}->{3597174} = "Калотина";
$areanames{bg}->{3597175} = "Габер";
$areanames{bg}->{3597176} = "Храбърско";
$areanames{bg}->{3597177} = "Алдомировци";
$areanames{bg}->{3597178} = "Пролеша";
$areanames{bg}->{3597179} = "Големо\ Малово";
$areanames{bg}->{35971798} = "Василовци\,Соф\.";
$areanames{bg}->{3597181} = "Пирдоп";
$areanames{bg}->{3597182} = "Мирково";
$areanames{bg}->{3597183} = "Душанци";
$areanames{bg}->{3597184} = "Копривщица";
$areanames{bg}->{3597185} = "Челопеч";
$areanames{bg}->{3597186} = "Антон";
$areanames{bg}->{3597187} = "Буново\,\ София";
$areanames{bg}->{3597188} = "Петрич\,\ София";
$areanames{bg}->{3597189} = "Чавдар\,\ София";
$areanames{bg}->{3597192} = "Гинци";
$areanames{bg}->{3597193} = "Голеш\,\ София";
$areanames{bg}->{359720} = "Етрополе";
$areanames{bg}->{359721} = "Костинброд";
$areanames{bg}->{359722} = "Самоков";
$areanames{bg}->{359723} = "Ботевград";
$areanames{bg}->{359724} = "Ихтиман";
$areanames{bg}->{359725} = "Елин\ Пелин";
$areanames{bg}->{359726} = "Своге";
$areanames{bg}->{359727} = "Сливница\,\ София";
$areanames{bg}->{359728} = "Златица";
$areanames{bg}->{359729} = "Годеч";
$areanames{bg}->{35973} = "Благоевград";
$areanames{bg}->{3597415} = "Селище\,\ Благ\.";
$areanames{bg}->{35974201} = "Капатово";
$areanames{bg}->{35974202} = "Ключ";
$areanames{bg}->{35974203} = "Рупите";
$areanames{bg}->{35974204} = "Гега";
$areanames{bg}->{35974207} = "Генерал\ Тодоров";
$areanames{bg}->{3597422} = "Тополница\,\ Благ\.";
$areanames{bg}->{3597423} = "Коларово\,\ Благ\.";
$areanames{bg}->{3597424} = "Кърналово";
$areanames{bg}->{3597425} = "Кулата";
$areanames{bg}->{3597426} = "Марикостиново";
$areanames{bg}->{3597427} = "Първомай\,\ Благ\.";
$areanames{bg}->{3597428} = "Габрене";
$areanames{bg}->{3597430} = "Дамяница";
$areanames{bg}->{35974321} = "Хърсово\,\ Благ\.";
$areanames{bg}->{35974322} = "Петрово\,\ Благ\.";
$areanames{bg}->{35974323} = "Лозеница";
$areanames{bg}->{35974324} = "Струма";
$areanames{bg}->{35974325} = "Лиляново";
$areanames{bg}->{35974327} = "Ново\ Делчево";
$areanames{bg}->{3597433} = "Кресна";
$areanames{bg}->{3597434} = "Струмяни";
$areanames{bg}->{35974346} = "Цапарево";
$areanames{bg}->{35974347} = "Раздол";
$areanames{bg}->{35974348} = "Игралище";
$areanames{bg}->{3597435} = "Склаве";
$areanames{bg}->{3597436} = "Левуново";
$areanames{bg}->{3597437} = "Мелник";
$areanames{bg}->{3597438} = "Катунци";
$areanames{bg}->{35974386} = "Пирин";
$areanames{bg}->{35974388} = "Горно\ Спанчево";
$areanames{bg}->{3597439} = "Плоски";
$areanames{bg}->{35974401} = "Горно\ Драглище";
$areanames{bg}->{35974402} = "Годлево";
$areanames{bg}->{35974403} = "Долно\ Драглище";
$areanames{bg}->{35974404} = "Бабяк";
$areanames{bg}->{35974405} = "Краище\,\ Благ\.";
$areanames{bg}->{35974406} = "Добърско";
$areanames{bg}->{35974407} = "Кремен\,\ Благ\.";
$areanames{bg}->{35974408} = "Обидим";
$areanames{bg}->{35974409} = "Места";
$areanames{bg}->{3597442} = "Якоруда";
$areanames{bg}->{3597444} = "Белица\,\ Благ\.";
$areanames{bg}->{3597445} = "Баня\,\ Благ\.";
$areanames{bg}->{3597446} = "Елешница\,\ Благ\.";
$areanames{bg}->{3597447} = "Добринище";
$areanames{bg}->{3597448} = "Бачево";
$areanames{bg}->{35974495} = "Юруково";
$areanames{bg}->{35974496} = "Филипово\,\ Благ\.";
$areanames{bg}->{359745} = "Петрич\,\ Благ\.";
$areanames{bg}->{359746} = "Сандански";
$areanames{bg}->{359747} = "Разлог";
$areanames{bg}->{359748} = "Симитли";
$areanames{bg}->{359749} = "Банско";
$areanames{bg}->{359750} = "Боровец\,\ София";
$areanames{bg}->{359751} = "Гоце\ Делчев";
$areanames{bg}->{3597520} = "Корница";
$areanames{bg}->{3597521} = "Копривлен";
$areanames{bg}->{35975214} = "Гайтаниново";
$areanames{bg}->{35975215} = "Тешово";
$areanames{bg}->{3597522} = "Дъбница";
$areanames{bg}->{3597523} = "Гърмен";
$areanames{bg}->{3597524} = "Абланица\,\ Благ\.";
$areanames{bg}->{3597525} = "Баничан";
$areanames{bg}->{3597526} = "Рибново";
$areanames{bg}->{3597527} = "Горно\ Дряново";
$areanames{bg}->{3597528} = "Хаджидимово";
$areanames{bg}->{3597529} = "Брезница";
$areanames{bg}->{3597531} = "Долно\ Дряново";
$areanames{bg}->{3597532} = "Буково\,\ Благ\.";
$areanames{bg}->{3597533} = "Осиково\,\ Благ\.";
$areanames{bg}->{3597541} = "Сатовча";
$areanames{bg}->{3597544} = "Осина";
$areanames{bg}->{3597545} = "Кочан";
$areanames{bg}->{3597546} = "Слащен";
$areanames{bg}->{3597547} = "Вълкосел";
$areanames{bg}->{3597548} = "Годешево";
$areanames{bg}->{3597549} = "Долен\,\ Благ\.";
$areanames{bg}->{35976} = "Перник";
$areanames{bg}->{3597711} = "Кладница";
$areanames{bg}->{3597712} = "Батановци";
$areanames{bg}->{3597713} = "Рударци";
$areanames{bg}->{3597714} = "Мещица";
$areanames{bg}->{3597715} = "Студена\,\ Перник";
$areanames{bg}->{3597717} = "Дивотино";
$areanames{bg}->{3597718} = "Драгичево";
$areanames{bg}->{3597719} = "Ярджиловци";
$areanames{bg}->{3597720} = "Прибой";
$areanames{bg}->{35977221} = "Кондофрей";
$areanames{bg}->{35977222} = "Горна\ Диканя";
$areanames{bg}->{35977226} = "Дебели\ лаг";
$areanames{bg}->{35977229} = "Гълъбник";
$areanames{bg}->{3597723} = "Долни\ Раковец";
$areanames{bg}->{3597724} = "Извор\,\ Перник";
$areanames{bg}->{3597725} = "Кленовик";
$areanames{bg}->{3597726} = "Дрен";
$areanames{bg}->{3597727} = "Ковачевци\,\ Перник";
$areanames{bg}->{3597728} = "Друган";
$areanames{bg}->{3597729} = "Долна\ Диканя";
$areanames{bg}->{3597731} = "Трън";
$areanames{bg}->{3597732} = "Вукан";
$areanames{bg}->{3597733} = "Филиповци";
$areanames{bg}->{3597734} = "Главановци\,\ Перник";
$areanames{bg}->{3597735} = "Лева\ река";
$areanames{bg}->{3597741} = "Земен";
$areanames{bg}->{3597742} = "Калище";
$areanames{bg}->{3597743} = "Дивля";
$areanames{bg}->{3597744} = "Еловдол\,\ Перник";
$areanames{bg}->{3597745} = "Егълница";
$areanames{bg}->{3597751} = "Брезник";
$areanames{bg}->{3597752} = "Режанци";
$areanames{bg}->{3597753} = "Ноевци";
$areanames{bg}->{3597754} = "Кошарево";
$areanames{bg}->{3597755} = "Велковци\,\ Перник";
$areanames{bg}->{359777} = "Радомир";
$areanames{bg}->{35978} = "Кюстендил";
$areanames{bg}->{3597910} = "Берсин";
$areanames{bg}->{3597911} = "Граница";
$areanames{bg}->{3597912} = "Горна\ Гращица";
$areanames{bg}->{3597913} = "Рашка\ Гращица";
$areanames{bg}->{3597914} = "Ваксево";
$areanames{bg}->{3597915} = "Невестино\,\ Кюст\.";
$areanames{bg}->{3597916} = "Багренци";
$areanames{bg}->{3597917} = "Таваличево";
$areanames{bg}->{3597918} = "Ябълково\,\ Кюст\.";
$areanames{bg}->{3597920} = "Скриняно";
$areanames{bg}->{3597921} = "Жиленци";
$areanames{bg}->{3597922} = "Драговищица\,\ Кюст\.";
$areanames{bg}->{3597923} = "Вратца";
$areanames{bg}->{3597924} = "Шишковци";
$areanames{bg}->{3597925} = "Гюешево";
$areanames{bg}->{3597926} = "Коняво";
$areanames{bg}->{3597927} = "Трекляно";
$areanames{bg}->{3597928} = "Гърляно";
$areanames{bg}->{3597929} = "Соволяно";
$areanames{bg}->{3597930} = "Еремия";
$areanames{bg}->{3597932} = "Шипочано";
$areanames{bg}->{3597933} = "Грамаждано";
$areanames{bg}->{3597934} = "Буново\,\ Кюст\.";
$areanames{bg}->{3597935} = "Долно\ село";
$areanames{bg}->{3597936} = "Слокощица";
$areanames{bg}->{3597937} = "Ръждавица";
$areanames{bg}->{3597938} = "Долно\ Уйно";
$areanames{bg}->{3597939} = "Църварица";
$areanames{bg}->{3598111} = "Щръклево";
$areanames{bg}->{3598113} = "Ново\ село\,\ Русе";
$areanames{bg}->{3598114} = "Пиргово";
$areanames{bg}->{3598115} = "Червена\ вода";
$areanames{bg}->{3598116} = "Иваново\,\ Русе";
$areanames{bg}->{3598117} = "Мартен";
$areanames{bg}->{3598118} = "Николово\,\ Русе";
$areanames{bg}->{3598122} = "Ценово\,\ Русе";
$areanames{bg}->{3598123} = "Босилковци";
$areanames{bg}->{3598124} = "Новград";
$areanames{bg}->{3598125} = "Копривец";
$areanames{bg}->{35981262} = "Бистренци";
$areanames{bg}->{35981264} = "Пиперково";
$areanames{bg}->{35981266} = "Стърмен\,\ Русе";
$areanames{bg}->{35981268} = "Кривина\,\ Русе";
$areanames{bg}->{3598127} = "Караманово";
$areanames{bg}->{3598128} = "Полско\ Косово";
$areanames{bg}->{3598129} = "Лом\ Черковна";
$areanames{bg}->{3598131} = "Борисово\,\ Русе";
$areanames{bg}->{3598132} = "Юделник";
$areanames{bg}->{3598133} = "Ряхово";
$areanames{bg}->{3598134} = "Малко\ Враново";
$areanames{bg}->{3598135} = "Бабово";
$areanames{bg}->{3598136} = "Стамболово\,\ Русе";
$areanames{bg}->{3598137} = "Голямо\ Враново";
$areanames{bg}->{3598138} = "Бръшлен";
$areanames{bg}->{3598140} = "Борово\,\ Русе";
$areanames{bg}->{3598141} = "Две\ могили";
$areanames{bg}->{3598142} = "Бъзовец\,\ Русе";
$areanames{bg}->{3598143} = "Обретеник";
$areanames{bg}->{3598144} = "Батишница";
$areanames{bg}->{3598145} = "Тръстеник\,\ Русе";
$areanames{bg}->{35981461} = "Каран\ Върбовка";
$areanames{bg}->{35981462} = "Волово";
$areanames{bg}->{35981463} = "Могилино";
$areanames{bg}->{35981464} = "Острица\,\ Русе";
$areanames{bg}->{35981465} = "Батин";
$areanames{bg}->{35981466} = "Помен";
$areanames{bg}->{3598147} = "Баниска";
$areanames{bg}->{3598148} = "Горно\ Абланово";
$areanames{bg}->{3598149} = "Кацелово";
$areanames{bg}->{3598150} = "Семерджиево";
$areanames{bg}->{3598151} = "Просена";
$areanames{bg}->{3598152} = "Красен\,\ Русе";
$areanames{bg}->{3598156} = "Червен\,\ Русе";
$areanames{bg}->{3598158} = "Мечка\,\ Русе";
$areanames{bg}->{3598159} = "Кошов";
$areanames{bg}->{3598161} = "Ветово";
$areanames{bg}->{3598163} = "Бъзън";
$areanames{bg}->{3598164} = "Писанец";
$areanames{bg}->{3598165} = "Смирненски\,\ Русе";
$areanames{bg}->{3598166} = "Сваленик";
$areanames{bg}->{3598167} = "Церовец";
$areanames{bg}->{359817} = "Бяла\,\ Русе";
$areanames{bg}->{3598184} = "Глоджево";
$areanames{bg}->{3598185} = "Сеново";
$areanames{bg}->{3598187} = "Тетово";
$areanames{bg}->{35981886} = "Черешово\,\ Русе";
$areanames{bg}->{3598192} = "Хотанца";
$areanames{bg}->{3598194} = "Сандрово";
$areanames{bg}->{3598196} = "Нисово";
$areanames{bg}->{35982} = "Русе";
$areanames{bg}->{35984} = "Разград";
$areanames{bg}->{3598424} = "Цар\ Калоян\,\ Разград";
$areanames{bg}->{35984266} = "Просторно";
$areanames{bg}->{35984269} = "Недоклан";
$areanames{bg}->{3598431} = "Исперих";
$areanames{bg}->{35984392} = "Белинци";
$areanames{bg}->{35984393} = "Вазово";
$areanames{bg}->{35984394} = "Духовец";
$areanames{bg}->{3598442} = "Завет\,\ Разград";
$areanames{bg}->{3598445} = "Юпер";
$areanames{bg}->{35984462} = "Острово";
$areanames{bg}->{35984463} = "Прелез";
$areanames{bg}->{35984464} = "Веселец\,\ Разград";
$areanames{bg}->{35984465} = "Савин";
$areanames{bg}->{35984466} = "Звънарци";
$areanames{bg}->{35984467} = "Сеслав";
$areanames{bg}->{35984469} = "Божурово\,\ Разград";
$areanames{bg}->{3598448} = "Тертер";
$areanames{bg}->{35984710} = "Осенец";
$areanames{bg}->{35984711} = "Мортагоново";
$areanames{bg}->{35984712} = "Костанденец";
$areanames{bg}->{35984713} = "Благоево\,\ Разград";
$areanames{bg}->{35984717} = "Побит\ камък\,\ Разград";
$areanames{bg}->{35984718} = "Дряновец\,\ Разград";
$areanames{bg}->{35984719} = "Балкански";
$areanames{bg}->{35984720} = "Топчии";
$areanames{bg}->{35984721} = "Липник";
$areanames{bg}->{35984722} = "Ясеновец";
$areanames{bg}->{35984723} = "Дянково";
$areanames{bg}->{35984725} = "Киченица";
$areanames{bg}->{35984726} = "Ушинци";
$areanames{bg}->{35984727} = "Каменово\,\ Разград";
$areanames{bg}->{35984728} = "Раковски\,\ Разград";
$areanames{bg}->{35984729} = "Езерче";
$areanames{bg}->{35984730} = "Голям\ Поровец";
$areanames{bg}->{35984732} = "Йонково";
$areanames{bg}->{35984733} = "Лудогорци";
$areanames{bg}->{35984734} = "Тодорово\,\ Разград";
$areanames{bg}->{35984735} = "Свещари";
$areanames{bg}->{35984736} = "Подайва";
$areanames{bg}->{35984737} = "Райнино";
$areanames{bg}->{35984738} = "Китанчево";
$areanames{bg}->{35984740} = "Бисерци";
$areanames{bg}->{35984743} = "Брестовене";
$areanames{bg}->{35984744} = "Беловец";
$areanames{bg}->{35984745} = "Владимировци";
$areanames{bg}->{35984749} = "Севар";
$areanames{bg}->{3598475} = "Лозница\,\ Разград";
$areanames{bg}->{35984760} = "Трапище";
$areanames{bg}->{35984761} = "Градина\,\ Разград";
$areanames{bg}->{35984763} = "Бели\ Лом";
$areanames{bg}->{35984764} = "Сейдол";
$areanames{bg}->{35984765} = "Веселина";
$areanames{bg}->{35984766} = "Каменар\,\ Разград";
$areanames{bg}->{35984768} = "Синя\ вода";
$areanames{bg}->{35984769} = "Гороцвет";
$areanames{bg}->{3598477} = "Самуил";
$areanames{bg}->{35984774} = "Голям\ извор\,\ Разград";
$areanames{bg}->{35984776} = "Хърсово\,\ Разград";
$areanames{bg}->{35984778} = "Богданци\,\ Разград";
$areanames{bg}->{35984779} = "Здравец\,\ Разград";
$areanames{bg}->{359848} = "Кубрат";
$areanames{bg}->{359860} = "Силистра";
$areanames{bg}->{359861} = "Силистра";
$areanames{bg}->{3598620} = "Силистра";
$areanames{bg}->{3598621} = "Силистра";
$areanames{bg}->{3598622} = "Алеково\,\ Силистра";
$areanames{bg}->{3598623} = "Голеш\,\ Силистра";
$areanames{bg}->{3598624} = "Калипетрово";
$areanames{bg}->{3598625} = "Овен";
$areanames{bg}->{3598626} = "Средище\,\ Силистра";
$areanames{bg}->{3598627} = "Бабук";
$areanames{bg}->{3598628} = "Цар\ Асен\,\ Силистра";
$areanames{bg}->{3598629} = "Смилец\,\ Силистра";
$areanames{bg}->{3598630} = "Силистра";
$areanames{bg}->{3598631} = "Силистра";
$areanames{bg}->{3598632} = "Зафирово";
$areanames{bg}->{3598633} = "Старо\ село\,\ Силистра";
$areanames{bg}->{3598634} = "Нова\ Черна";
$areanames{bg}->{3598635} = "Цар\ Самуил";
$areanames{bg}->{3598636} = "Главиница\,\ Силистра";
$areanames{bg}->{3598637} = "Малък\ Преславец";
$areanames{bg}->{3598638} = "Богданци\,\ Силистра";
$areanames{bg}->{3598639} = "Коларово\,\ Силистра";
$areanames{bg}->{3598640} = "Правда\,\ Силистра";
$areanames{bg}->{3598641} = "Окорш";
$areanames{bg}->{3598642} = "Дулово";
$areanames{bg}->{3598643} = "Златоклас";
$areanames{bg}->{3598644} = "Чернолик";
$areanames{bg}->{3598645} = "Межден";
$areanames{bg}->{3598646} = "Вокил";
$areanames{bg}->{3598647} = "Паисиево";
$areanames{bg}->{3598648} = "Секулово";
$areanames{bg}->{3598649} = "Яребица";
$areanames{bg}->{359865} = "Силистра";
$areanames{bg}->{3598660} = "Тутракан";
$areanames{bg}->{3598661} = "Тутракан";
$areanames{bg}->{3598662} = "Добротица\,\ Силистра";
$areanames{bg}->{3598663} = "Ситово\,\ Силистра";
$areanames{bg}->{3598664} = "Поляна\,\ Силистра";
$areanames{bg}->{3598665} = "Искра\,\ Силистра";
$areanames{bg}->{3598666} = "Тутракан";
$areanames{bg}->{3598667} = "Белица\,\ Силистра";
$areanames{bg}->{3598668} = "Попина";
$areanames{bg}->{3598669} = "Гарван\,\ Силистра";
$areanames{bg}->{3598670} = "Силистра";
$areanames{bg}->{3598671} = "Силистра";
$areanames{bg}->{3598672} = "Брадвари";
$areanames{bg}->{3598673} = "Алфатар";
$areanames{bg}->{3598674} = "Професор\ Иширково";
$areanames{bg}->{3598675} = "Айдемир";
$areanames{bg}->{3598676} = "Ветрен\,\ Силистра";
$areanames{bg}->{3598677} = "Сребърна";
$areanames{bg}->{3598678} = "Срацимир\,\ Силистра";
$areanames{bg}->{3598679} = "Кайнарджа";
$areanames{bg}->{359868} = "Силистра";
$areanames{bg}->{3598690} = "Силистра";
$areanames{bg}->{3598691} = "Силистра";
$areanames{bg}->{3598692} = "Стефан\ Караджа\,\ Силистра";
$areanames{bg}->{3598693} = "Звенимир";
$areanames{bg}->{3598694} = "Зебил";
$areanames{bg}->{3598695} = "Ножарево";
$areanames{bg}->{3598696} = "Суходол\,\ Силистра";
$areanames{bg}->{3598697} = "Сокол\,\ Силистра";
$areanames{bg}->{3598698} = "Шуменци";
$areanames{bg}->{3598699} = "Търновци\,\ Силистра";
$areanames{bg}->{359910} = "Мездра";
$areanames{bg}->{3599110} = "Вировско";
$areanames{bg}->{3599111} = "Челопек";
$areanames{bg}->{3599112} = "Баница";
$areanames{bg}->{3599113} = "Мраморен";
$areanames{bg}->{3599115} = "Чирен";
$areanames{bg}->{3599116} = "Костелево";
$areanames{bg}->{3599117} = "Криводол";
$areanames{bg}->{35991180} = "Лесура";
$areanames{bg}->{35991182} = "Осен\,\ Враца";
$areanames{bg}->{35991183} = "Фурен";
$areanames{bg}->{35991184} = "Ракево";
$areanames{bg}->{35991185} = "Пудрия";
$areanames{bg}->{35991186} = "Баурене";
$areanames{bg}->{35991188} = "Галатин";
$areanames{bg}->{35991189} = "Три\ кладенци";
$areanames{bg}->{3599119} = "Тишевица";
$areanames{bg}->{35991201} = "Люти\ брод";
$areanames{bg}->{35991202} = "Кунино";
$areanames{bg}->{35991203} = "Лик";
$areanames{bg}->{3599121} = "Царевец\,\ Враца";
$areanames{bg}->{3599122} = "Зверино";
$areanames{bg}->{3599123} = "Роман";
$areanames{bg}->{3599124} = "Типченица";
$areanames{bg}->{3599125} = "Горна\ Бешовица";
$areanames{bg}->{3599126} = "Камено\ поле";
$areanames{bg}->{3599127} = "Лютидол";
$areanames{bg}->{3599128} = "Елисейна";
$areanames{bg}->{3599129} = "Синьо\ бърдо";
$areanames{bg}->{3599130} = "Тлачене";
$areanames{bg}->{3599131} = "Добролево";
$areanames{bg}->{3599132} = "Кнежа";
$areanames{bg}->{3599133} = "Комарево\,\ Враца";
$areanames{bg}->{3599134} = "Търнак";
$areanames{bg}->{3599135} = "Бърдарски\ геран";
$areanames{bg}->{3599136} = "Галиче";
$areanames{bg}->{3599137} = "Попица";
$areanames{bg}->{3599138} = "Алтимир";
$areanames{bg}->{3599139} = "Търнава\,\ Враца";
$areanames{bg}->{3599140} = "Габаре";
$areanames{bg}->{35991401} = "Враняк";
$areanames{bg}->{3599141} = "Малорад";
$areanames{bg}->{3599142} = "Лазарово";
$areanames{bg}->{3599143} = "Еница";
$areanames{bg}->{3599144} = "Нивянин";
$areanames{bg}->{3599145} = "Бреница\,\ Враца";
$areanames{bg}->{3599146} = "Соколаре";
$areanames{bg}->{3599147} = "Борован";
$areanames{bg}->{3599148} = "Бъркачево";
$areanames{bg}->{3599149} = "Буковец\,\ Враца";
$areanames{bg}->{359915} = "Бяла\ Слатина";
$areanames{bg}->{3599160} = "Гложене\,\ Враца";
$areanames{bg}->{3599161} = "Мизия";
$areanames{bg}->{3599162} = "Михайлово\,\ Враца";
$areanames{bg}->{3599163} = "Хърлец";
$areanames{bg}->{3599164} = "Крушовица\,\ Враца";
$areanames{bg}->{3599165} = "Софрониево";
$areanames{bg}->{3599166} = "Хайредин";
$areanames{bg}->{35991668} = "Манастирище";
$areanames{bg}->{3599167} = "Липница\,\ Враца";
$areanames{bg}->{3599168} = "Бутан";
$areanames{bg}->{3599169} = "Рогозен";
$areanames{bg}->{3599171} = "Оряхово\,\ Враца";
$areanames{bg}->{3599172} = "Селановци";
$areanames{bg}->{3599173} = "Галово";
$areanames{bg}->{3599174} = "Горни\ Вадин";
$areanames{bg}->{3599175} = "Остров";
$areanames{bg}->{3599176} = "Лесковец\,\ Враца";
$areanames{bg}->{3599180} = "Голямо\ Пещене";
$areanames{bg}->{3599181} = "Краводер";
$areanames{bg}->{3599182} = "Девене";
$areanames{bg}->{3599183} = "Лиляче";
$areanames{bg}->{3599184} = "Оходен";
$areanames{bg}->{3599185} = "Бели\ Извор";
$areanames{bg}->{3599186} = "Згориград";
$areanames{bg}->{3599187} = "Лютаджик";
$areanames{bg}->{3599188} = "Горно\ Пещене";
$areanames{bg}->{35991888} = "Веслец\,\ Враца";
$areanames{bg}->{3599189} = "Паволче";
$areanames{bg}->{35992} = "Враца";
$areanames{bg}->{3599311} = "Кутово";
$areanames{bg}->{3599312} = "Брегово\,\ Видин";
$areanames{bg}->{3599313} = "Капитановци";
$areanames{bg}->{3599314} = "Дунавци\,\ Видин";
$areanames{bg}->{3599315} = "Градец\,\ Видин";
$areanames{bg}->{3599316} = "Ново\ село\,\ Видин";
$areanames{bg}->{3599317} = "Арчар";
$areanames{bg}->{3599318} = "Буковец\,\ Видин";
$areanames{bg}->{3599319} = "Гъмзово";
$areanames{bg}->{3599320} = "Стакевци";
$areanames{bg}->{35993212} = "Карбинци";
$areanames{bg}->{3599322} = "Орешец\,\ Видин";
$areanames{bg}->{3599323} = "Дреновец";
$areanames{bg}->{3599324} = "Ружинци";
$areanames{bg}->{3599325} = "Бело\ поле\,\ Видин";
$areanames{bg}->{3599326} = "Горни\ Лом";
$areanames{bg}->{3599327} = "Чупрене";
$areanames{bg}->{3599328} = "Долни\ Лом";
$areanames{bg}->{3599329} = "Рабиша";
$areanames{bg}->{3599330} = "Раброво";
$areanames{bg}->{3599332} = "Раковица";
$areanames{bg}->{3599333} = "Бойница";
$areanames{bg}->{35993342} = "Киреево";
$areanames{bg}->{3599335} = "Цар\ Петрово";
$areanames{bg}->{3599336} = "Старопатица";
$areanames{bg}->{3599337} = "Грамада";
$areanames{bg}->{3599338} = "Шишенци";
$areanames{bg}->{3599339} = "Макреш";
$areanames{bg}->{3599340} = "Септемврийци\,\ Видин";
$areanames{bg}->{3599341} = "Димово\,\ Видин";
$areanames{bg}->{3599342} = "Иново";
$areanames{bg}->{3599343} = "Гомотарци";
$areanames{bg}->{3599344} = "Връв";
$areanames{bg}->{3599345} = "Винарово\,\ Видин";
$areanames{bg}->{3599346} = "Синаговци";
$areanames{bg}->{3599347} = "Бела\ Рада";
$areanames{bg}->{3599348} = "Неговановци";
$areanames{bg}->{3599349} = "Сланотрън";
$areanames{bg}->{3599351} = "Извор\,\ Видин";
$areanames{bg}->{3599352} = "Дружба";
$areanames{bg}->{3599353} = "Кошава";
$areanames{bg}->{3599354} = "Антимово\,\ Видин";
$areanames{bg}->{3599355} = "Косово\,\ Видин";
$areanames{bg}->{3599356} = "Каленик\,\ Видин";
$areanames{bg}->{359936} = "Белоградчик";
$areanames{bg}->{359938} = "Кула";
$areanames{bg}->{35994} = "Видин";
$areanames{bg}->{3599512} = "Бели\ брег";
$areanames{bg}->{3599513} = "Бойчиновци";
$areanames{bg}->{3599514} = "Владимирово\,\ Монт\.";
$areanames{bg}->{3599515} = "Мадан\,\ Монт\.";
$areanames{bg}->{3599516} = "Лехчево";
$areanames{bg}->{3599517} = "Кобиляк";
$areanames{bg}->{3599518} = "Мърчево";
$areanames{bg}->{3599520} = "Горно\ Озирово";
$areanames{bg}->{3599521} = "Замфирово";
$areanames{bg}->{3599522} = "Котеновци";
$areanames{bg}->{3599523} = "Бързия";
$areanames{bg}->{3599524} = "Ягодово\,\ Монт\.";
$areanames{bg}->{3599525} = "Долно\ Озирово";
$areanames{bg}->{3599526} = "Слатина\,\ Монт\.";
$areanames{bg}->{3599527} = "Вършец";
$areanames{bg}->{35995276} = "Драганица";
$areanames{bg}->{35995277} = "Черкаски";
$areanames{bg}->{3599528} = "Гаганица";
$areanames{bg}->{3599529} = "Боровци";
$areanames{bg}->{359953} = "Берковица";
$areanames{bg}->{3599540} = "Белотинци";
$areanames{bg}->{3599541} = "Доктор\ Йосифово";
$areanames{bg}->{3599542} = "Смоляновци";
$areanames{bg}->{3599544} = "Студено\ буче";
$areanames{bg}->{3599545} = "Габровница";
$areanames{bg}->{3599546} = "Славотин";
$areanames{bg}->{3599547} = "Винище";
$areanames{bg}->{3599548} = "Крапчене";
$areanames{bg}->{3599549} = "Долна\ Рикса";
$areanames{bg}->{3599550} = "Митровци";
$areanames{bg}->{3599551} = "Георги\ Дамяново";
$areanames{bg}->{3599552} = "Белимел";
$areanames{bg}->{3599553} = "Превала";
$areanames{bg}->{3599554} = "Чипровци";
$areanames{bg}->{3599555} = "Копиловци\,\ Монт\.";
$areanames{bg}->{3599556} = "Говежда";
$areanames{bg}->{3599557} = "Горно\ Церовене";
$areanames{bg}->{3599558} = "Гаврил\ Геново";
$areanames{bg}->{3599559} = "Горна\ Ковачица";
$areanames{bg}->{3599560} = "Безденица";
$areanames{bg}->{3599561} = "Сумер";
$areanames{bg}->{3599564} = "Стубел";
$areanames{bg}->{3599567} = "Долна\ Вереница";
$areanames{bg}->{3599568} = "Благово\,\ Монт\.";
$areanames{bg}->{3599569} = "Липен";
$areanames{bg}->{35996} = "Монтана";
$areanames{bg}->{359971} = "Лом";
$areanames{bg}->{3599719} = "Аспарухово\,\ Монт\.";
$areanames{bg}->{3599720} = "Ковачица";
$areanames{bg}->{3599721} = "Долно\ Церовене";
$areanames{bg}->{3599722} = "Сталийска\ махала";
$areanames{bg}->{3599723} = "Трайково";
$areanames{bg}->{3599724} = "Станево";
$areanames{bg}->{3599725} = "Комощица";
$areanames{bg}->{3599726} = "Замфир";
$areanames{bg}->{3599727} = "Медковец";
$areanames{bg}->{3599728} = "Сливата";
$areanames{bg}->{3599729} = "Расово";
$areanames{bg}->{359973} = "Козлодуй";
$areanames{bg}->{3599740} = "Септемврийци\,\ Монт\.";
$areanames{bg}->{3599741} = "Долни\ Цибър";
$areanames{bg}->{3599742} = "Якимово";
$areanames{bg}->{3599744} = "Вълчедръм";
$areanames{bg}->{3599745} = "Златия\,\ Монт\.";
$areanames{bg}->{3599746} = "Разград\,\ Монт\.";
$areanames{bg}->{3599747} = "Мокреш\,\ Монт\.";
$areanames{bg}->{3599748} = "Дългоделци";
$areanames{bg}->{3599749} = "Черни\ връх\,\ Монт\.";
$areanames{bg}->{3599782} = "Буковец\,\ Монт\.";
$areanames{bg}->{3599783} = "Брусарци";
$areanames{bg}->{3599784} = "Киселево";
$areanames{bg}->{3599785} = "Василовци\,\ Монт\.";
$areanames{bg}->{3599787} = "Смирненски\,\ Монт\.";
$areanames{en}->{3592} = "Sofia";
$areanames{en}->{359301} = "Smolyan";
$areanames{en}->{3593019} = "Pisanitsa";
$areanames{en}->{3593020} = "Davidkovo";
$areanames{en}->{35930200} = "Zagrazhden\,\ Smol\.";
$areanames{en}->{35930205} = "Starnitsa";
$areanames{en}->{3593022} = "Vievo";
$areanames{en}->{3593023} = "Momchilovtsi";
$areanames{en}->{3593024} = "Taran";
$areanames{en}->{3593025} = "Banite";
$areanames{en}->{35930256} = "Galabovo\,\ Smol\.";
$areanames{en}->{35930257} = "Vishnevo";
$areanames{en}->{3593026} = "Smilyan";
$areanames{en}->{3593027} = "Slaveyno";
$areanames{en}->{3593028} = "Arda";
$areanames{en}->{3593029} = "Petkovo\,\ Smol\.";
$areanames{en}->{3593030} = "Shiroka\ laka";
$areanames{en}->{3593032} = "Srednogortsi";
$areanames{en}->{3593034} = "Levochevo";
$areanames{en}->{3593035} = "Varbina";
$areanames{en}->{3593036} = "Mogilitsa";
$areanames{en}->{3593037} = "Sivino";
$areanames{en}->{3593038} = "Chokmanovo";
$areanames{en}->{3593039} = "Polkovnik\ Serafimovo";
$areanames{en}->{3593040} = "Trigrad";
$areanames{en}->{35930410} = "Breze\,\ Smol\.";
$areanames{en}->{35930411} = "Devin";
$areanames{en}->{35930412} = "Devin";
$areanames{en}->{35930413} = "Devin";
$areanames{en}->{35930414} = "Devin";
$areanames{en}->{35930415} = "Devin";
$areanames{en}->{35930416} = "Gyovren";
$areanames{en}->{35930417} = "Grohotno";
$areanames{en}->{35930418} = "Buynovo\,\ Smol\.";
$areanames{en}->{35930419} = "Yagodina";
$areanames{en}->{3593042} = "Borino";
$areanames{en}->{3593043} = "Zmeitsa";
$areanames{en}->{3593044} = "Lyaskovo\,\ Smol\.";
$areanames{en}->{3593045} = "Dospat";
$areanames{en}->{35930456} = "Chavdar\,\ Smol\.";
$areanames{en}->{35930457} = "Kasak";
$areanames{en}->{35930458} = "Lyubcha";
$areanames{en}->{35930459} = "Brashten";
$areanames{en}->{3593046} = "Barutin";
$areanames{en}->{35930472} = "Mihalkovo";
$areanames{en}->{35930475} = "Stomanevo";
$areanames{en}->{35930476} = "Selcha";
$areanames{en}->{3593049} = "Beden";
$areanames{en}->{3593050} = "Bukova\ polyana";
$areanames{en}->{3593051} = "Chepelare";
$areanames{en}->{35930517} = "Zabardo";
$areanames{en}->{3593052} = "Laki\,\ Plovdiv";
$areanames{en}->{35930528} = "Manastir\,\ Plovdiv";
$areanames{en}->{3593053} = "Hvoyna";
$areanames{en}->{3593054} = "Podvis\,\ Smol\.";
$areanames{en}->{3593055} = "Elhovets";
$areanames{en}->{3593056} = "Chepintsi\,\ Smol\.";
$areanames{en}->{3593057} = "Plovdivtsi";
$areanames{en}->{3593058} = "Mugla";
$areanames{en}->{3593059} = "Kutela";
$areanames{en}->{359306} = "Rudozem";
$areanames{en}->{3593071} = "Zlatograd";
$areanames{en}->{3593072} = "Nedelino";
$areanames{en}->{3593073} = "Startsevo";
$areanames{en}->{3593074} = "Erma\ reka";
$areanames{en}->{3593075} = "Dolen\,\ Smol\.";
$areanames{en}->{3593076} = "Tsatsarovtsi";
$areanames{en}->{3593077} = "Sredets\,\ Smol\.";
$areanames{en}->{3593079} = "Kozarka";
$areanames{en}->{359308} = "Madan\,\ Smol\.";
$areanames{en}->{359309} = "Pamporovo";
$areanames{en}->{3593100} = "Belashtitsa";
$areanames{en}->{3593101} = "Voyvodinovo";
$areanames{en}->{3593102} = "Karadzhovo";
$areanames{en}->{3593103} = "Milevo";
$areanames{en}->{3593104} = "Yagodovo\,\ Plovdiv";
$areanames{en}->{3593105} = "Manolsko\ Konare";
$areanames{en}->{3593106} = "Stroevo";
$areanames{en}->{3593107} = "Graf\ Ignatievo";
$areanames{en}->{3593108} = "Boykovo";
$areanames{en}->{3593109} = "Lilkovo";
$areanames{en}->{3593110} = "Popovitsa";
$areanames{en}->{35931108} = "Bogdanitsa";
$areanames{en}->{3593111} = "Parvenets\,\ Plovdiv";
$areanames{en}->{3593112} = "Markovo\,\ Plovdiv";
$areanames{en}->{3593113} = "Branipole";
$areanames{en}->{3593114} = "Brestnik";
$areanames{en}->{3593115} = "Kuklen";
$areanames{en}->{3593116} = "Krumovo\,\ Plovdiv";
$areanames{en}->{3593117} = "Katunitsa";
$areanames{en}->{3593118} = "Sadovo\,\ Plovdiv";
$areanames{en}->{3593119} = "Galabovo\,\ Plovdiv";
$areanames{en}->{3593120} = "Hrabrino";
$areanames{en}->{3593121} = "Rogosh";
$areanames{en}->{3593122} = "Manole";
$areanames{en}->{3593123} = "Kaloyanovo\,\ Plovdiv";
$areanames{en}->{3593124} = "Kalekovets";
$areanames{en}->{3593125} = "Razhevo\ Konare";
$areanames{en}->{35931258} = "Glavatar";
$areanames{en}->{3593126} = "Trud";
$areanames{en}->{3593127} = "Tsaratsovo";
$areanames{en}->{3593128} = "Zlatitrap";
$areanames{en}->{3593129} = "Skutare";
$areanames{en}->{3593130} = "Karavelovo\,\ Plovdiv";
$areanames{en}->{35931308} = "Bogdan\,\ Plovdiv";
$areanames{en}->{35931309} = "Kliment\,\ Plovdiv";
$areanames{en}->{3593132} = "Banya\,\ Plovdiv";
$areanames{en}->{35931324} = "Mrachenik";
$areanames{en}->{3593133} = "Kalofer";
$areanames{en}->{3593134} = "Sopot\,\ Plovdiv";
$areanames{en}->{3593135} = "Karnare";
$areanames{en}->{3593136} = "Rozino\,\ Plovdiv";
$areanames{en}->{3593137} = "Klisura\,\ Plovdiv";
$areanames{en}->{3593138} = "Vedrare";
$areanames{en}->{35931387} = "Prolom";
$areanames{en}->{35931388} = "Beguntsi";
$areanames{en}->{35931390} = "Moskovets";
$areanames{en}->{35931392} = "Dabene";
$areanames{en}->{35931393} = "Voynyagovo";
$areanames{en}->{35931394} = "Vasil\ Levski\,\ Plovdiv";
$areanames{en}->{35931395} = "Iganovo";
$areanames{en}->{35931396} = "Domlyan";
$areanames{en}->{35931397} = "Hristo\ Danovo";
$areanames{en}->{35931398} = "Slatina\,\ Plovdiv";
$areanames{en}->{35931401} = "Kadievo";
$areanames{en}->{35931402} = "Skobelevo\,\ Plovdiv";
$areanames{en}->{35931403} = "Trivoditsi";
$areanames{en}->{3593142} = "Brestovitsa\,\ Plovdiv";
$areanames{en}->{3593143} = "Perushtitsa";
$areanames{en}->{3593145} = "Krichim";
$areanames{en}->{3593146} = "Kurtovo\ Konare";
$areanames{en}->{3593147} = "Novo\ selo\,\ Plovdiv";
$areanames{en}->{3593148} = "Yoakim\ Gruevo";
$areanames{en}->{3593149} = "Tsalapitsa";
$areanames{en}->{3593151} = "Rakovski\,\ Plovdiv";
$areanames{en}->{3593153} = "Stryama";
$areanames{en}->{3593154} = "Chalakovi";
$areanames{en}->{3593155} = "Momino\ selo";
$areanames{en}->{3593156} = "Shishmantsi";
$areanames{en}->{3593157} = "Bolyarino";
$areanames{en}->{3593159} = "Belozem";
$areanames{en}->{35931602} = "Tatarevo\,\ Plovdiv";
$areanames{en}->{35931603} = "Vinitsa";
$areanames{en}->{35931604} = "Dragoynovo";
$areanames{en}->{35931605} = "Bukovo\,\ Plovdiv";
$areanames{en}->{35931606} = "Voden\,\ Plovdiv";
$areanames{en}->{3593162} = "Gradina\,\ Plovdiv";
$areanames{en}->{35931620} = "Dobri\ dol\,\ Plovdiv";
$areanames{en}->{35931627} = "Krushevo\,\ Plovdiv";
$areanames{en}->{3593163} = "Iskra\,\ Plovdiv";
$areanames{en}->{3593164} = "Dalbok\ izvor";
$areanames{en}->{3593165} = "Karadzhalovo";
$areanames{en}->{3593166} = "Byala\ reka\,\ Plovdiv";
$areanames{en}->{3593167} = "Bryagovo\,\ Plovdiv";
$areanames{en}->{3593168} = "Ezerovo\,\ Plovdiv";
$areanames{en}->{35931700} = "Belovitsa";
$areanames{en}->{35931701} = "Krastevich";
$areanames{en}->{35931702} = "Dolna\ mahala\,\ Plovdiv";
$areanames{en}->{35931703} = "Zhitnitsa\,\ Plovdiv";
$areanames{en}->{35931704} = "Ivan\ Vazovo";
$areanames{en}->{35931705} = "Gorna\ mahala";
$areanames{en}->{35931706} = "Suhozem";
$areanames{en}->{35931707} = "Chernozemen";
$areanames{en}->{35931708} = "Pesnopoy\,\ Plovdiv";
$areanames{en}->{35931709} = "Mihiltsi";
$areanames{en}->{3593173} = "Panicheri";
$areanames{en}->{3593174} = "Staro\ Zhelezare";
$areanames{en}->{3593175} = "Dalgo\ pole\,\ Plovdiv";
$areanames{en}->{3593176} = "Starosel";
$areanames{en}->{3593177} = "Novo\ Zhelezare";
$areanames{en}->{3593178} = "Krasnovo";
$areanames{en}->{35931791} = "Begovo";
$areanames{en}->{35931792} = "Chernichevo\,\ Plovdiv";
$areanames{en}->{359318} = "Saedinenie\,\ Plovdiv";
$areanames{en}->{3593190} = "Varben\,\ Plovdiv";
$areanames{en}->{3593191} = "Brezovo\,\ Plovdiv";
$areanames{en}->{3593192} = "Babek";
$areanames{en}->{3593193} = "Borets";
$areanames{en}->{3593194} = "Zelenikovo\,\ Plovdiv";
$areanames{en}->{3593195} = "Rozovets";
$areanames{en}->{3593196} = "Drangovo\,\ Plovdiv";
$areanames{en}->{3593197} = "Tyurkmen";
$areanames{en}->{3593198} = "Chehlare";
$areanames{en}->{35931992} = "Padarsko";
$areanames{en}->{35931993} = "Sarnegor";
$areanames{en}->{35931995} = "Streltsi\,\ Plovdiv";
$areanames{en}->{35931996} = "Svezhen";
$areanames{en}->{35931997} = "Zlatosel";
$areanames{en}->{35931998} = "Choba";
$areanames{en}->{35932} = "Plovdiv";
$areanames{en}->{359331} = "Asenovgrad";
$areanames{en}->{3593320} = "Oreshets\,\ Plovdiv";
$areanames{en}->{3593321} = "Topolovo\,\ Plovdiv";
$areanames{en}->{3593322} = "Zlatovrah";
$areanames{en}->{3593323} = "Bolyartsi\,\ Plovdiv";
$areanames{en}->{3593324} = "Izbeglii";
$areanames{en}->{3593325} = "Cherven\,\ Plovdiv";
$areanames{en}->{3593326} = "Patriarh\ Evtimovo";
$areanames{en}->{3593327} = "Bachkovo";
$areanames{en}->{3593328} = "Dolnoslav";
$areanames{en}->{3593340} = "Novi\ izvor";
$areanames{en}->{3593341} = "Konush\,\ Plovdiv";
$areanames{en}->{3593342} = "Narechenski\ bani";
$areanames{en}->{3593343} = "Kozanovo";
$areanames{en}->{3593344} = "Novakovo\,\ Plovdiv";
$areanames{en}->{3593345} = "Lyaskovo\,\ Plovdiv";
$areanames{en}->{3593346} = "Muldava";
$areanames{en}->{3593347} = "Lenovo";
$areanames{en}->{3593348} = "Dobralak";
$areanames{en}->{3593349} = "Boyantsi";
$areanames{en}->{359335} = "Karlovo";
$areanames{en}->{359336} = "Parvomay\,\ Plovdiv";
$areanames{en}->{359337} = "Hisarya";
$areanames{en}->{359339} = "Stamboliyski\,\ Plovdiv";
$areanames{en}->{35934} = "Pazardzhik";
$areanames{en}->{359350} = "Peshtera\,\ Pazardzhik";
$areanames{en}->{3593510} = "Ovchepoltsi";
$areanames{en}->{3593511} = "Ognyanovo\,\ Pazardzhik";
$areanames{en}->{3593512} = "Hadzhievo";
$areanames{en}->{3593513} = "Malo\ Konare";
$areanames{en}->{3593514} = "Chernogorovo\,\ Pazardzhik";
$areanames{en}->{3593515} = "Kalugerovo\,\ Pazardzhik";
$areanames{en}->{3593516} = "Tsrancha\,\ Pazardzhik";
$areanames{en}->{3593517} = "Lesichovo";
$areanames{en}->{3593518} = "Dragor";
$areanames{en}->{3593519} = "Velichkovo\,\ Pazardzhik";
$areanames{en}->{3593520} = "Miryantsi";
$areanames{en}->{3593521} = "Zvanichevo";
$areanames{en}->{3593522} = "Gelemenovo";
$areanames{en}->{3593523} = "Sinitevo";
$areanames{en}->{3593524} = "Apriltsi\,\ Pazardzhik";
$areanames{en}->{35935251} = "Bratanitsa";
$areanames{en}->{35935252} = "Topoli\ dol";
$areanames{en}->{35935254} = "Dobrovnitsa";
$areanames{en}->{35935255} = "Rosen\,\ Pazardzhik";
$areanames{en}->{35935256} = "Sbor\,\ Pazardzhik";
$areanames{en}->{35935257} = "Saraya";
$areanames{en}->{35935258} = "Tsar\ Asen\,\ Pazardzhik";
$areanames{en}->{3593526} = "Dinkata";
$areanames{en}->{3593527} = "Aleko\ Konstantinovo";
$areanames{en}->{3593528} = "Govedare";
$areanames{en}->{3593529} = "Mokrishte";
$areanames{en}->{3593530} = "Poibrene";
$areanames{en}->{3593532} = "Strelcha";
$areanames{en}->{3593533} = "Bata";
$areanames{en}->{3593534} = "Popintsi";
$areanames{en}->{3593535} = "Levski\,\ Pazardzhik";
$areanames{en}->{3593536} = "Banya\,\ Pazardzhik";
$areanames{en}->{3593537} = "Panagyurski\ kolonii";
$areanames{en}->{3593538} = "Elshitsa";
$areanames{en}->{35935391} = "Blatnitsa";
$areanames{en}->{35935392} = "Dyulevo\,\ Pazardzhik";
$areanames{en}->{35935393} = "Smilets\,\ Pazardzhik";
$areanames{en}->{35935394} = "Oborishte\,\ Pazardzhik";
$areanames{en}->{35935418} = "Krastava";
$areanames{en}->{35935419} = "Sveta\ Petka";
$areanames{en}->{3593542} = "Rakitovo";
$areanames{en}->{3593543} = "Dorkovo";
$areanames{en}->{3593544} = "Kostandovo";
$areanames{en}->{3593545} = "Draginovo";
$areanames{en}->{3593547} = "Sarnitsa\,\ Pazardzhik";
$areanames{en}->{3593548} = "Pashovo";
$areanames{en}->{3593549} = "Grashevo";
$areanames{en}->{35935501} = "Ravnogor";
$areanames{en}->{35935502} = "Fotinovo\,\ Pazardzhik";
$areanames{en}->{3593552} = "Bratsigovo";
$areanames{en}->{3593553} = "Batak\,\ Pazardzhik";
$areanames{en}->{3593554} = "Kozarsko";
$areanames{en}->{3593555} = "Nova\ mahala\,\ Pazardzhik";
$areanames{en}->{3593556} = "Radilovo";
$areanames{en}->{3593557} = "Byaga";
$areanames{en}->{3593558} = "Isperihovo";
$areanames{en}->{3593559} = "Kapitan\ Dimitrievo";
$areanames{en}->{3593561} = "Septemvri";
$areanames{en}->{3593562} = "Slavovitsa\,\ Pazardzhik";
$areanames{en}->{3593563} = "Varvara\,\ Pazardzhik";
$areanames{en}->{3593564} = "Semchinovo";
$areanames{en}->{3593566} = "Boshulya";
$areanames{en}->{3593567} = "Kovachevo\,\ Pazardzhik";
$areanames{en}->{3593568} = "Vinogradets";
$areanames{en}->{3593569} = "Karabunar";
$areanames{en}->{359357} = "Panagyurishte";
$areanames{en}->{3593581} = "Belovo";
$areanames{en}->{3593582} = "Momina\ klisura";
$areanames{en}->{3593583} = "Gabrovitsa";
$areanames{en}->{3593584} = "Vetren\,\ Pazardzhik";
$areanames{en}->{3593585} = "Akandzhievo";
$areanames{en}->{3593586} = "Borimechkovo";
$areanames{en}->{3593587} = "Sestrimo";
$areanames{en}->{3593588} = "Menenkyovo";
$areanames{en}->{3593589} = "Tserovo\,\ Pazardzhik";
$areanames{en}->{359359} = "Velingrad";
$areanames{en}->{359361} = "Kardzhali";
$areanames{en}->{3593622} = "Stremtsi";
$areanames{en}->{3593623} = "Boyno";
$areanames{en}->{3593624} = "Chiflik\,\ Kardzh\.";
$areanames{en}->{3593625} = "Shiroko\ pole";
$areanames{en}->{3593626} = "Perperek";
$areanames{en}->{3593628} = "Miladinovo";
$areanames{en}->{3593629} = "Most";
$areanames{en}->{3593631} = "Momchilgrad";
$areanames{en}->{3593632} = "Dzhebel";
$areanames{en}->{3593633} = "Rogozche";
$areanames{en}->{3593634} = "Pripek\,\ Kardzh\.";
$areanames{en}->{3593636} = "Raven";
$areanames{en}->{3593637} = "Gruevo";
$areanames{en}->{3593638} = "Zvezdel";
$areanames{en}->{3593639} = "Nanovitsa\,\ Kardzh\.";
$areanames{en}->{35936401} = "Strandzhevo";
$areanames{en}->{35936402} = "Gorna\ kula";
$areanames{en}->{3593641} = "Krumovgrad";
$areanames{en}->{3593642} = "Potochnitsa";
$areanames{en}->{3593643} = "Golyama\ Chinka";
$areanames{en}->{3593644} = "Egrek";
$areanames{en}->{3593645} = "Avren\,\ Kardzh\.";
$areanames{en}->{3593646} = "Tokachka";
$areanames{en}->{3593647} = "Chernichevo\,\ Kardzh\.";
$areanames{en}->{3593648} = "Golyamo\ Kamenyane";
$areanames{en}->{3593651} = "Ardino";
$areanames{en}->{3593652} = "Byal\ izvor\,\ Kardzh\.";
$areanames{en}->{3593653} = "Mlechino";
$areanames{en}->{3593657} = "Zhaltusha";
$areanames{en}->{3593658} = "Padina\,\ Kardzh\.";
$areanames{en}->{3593661} = "Ivaylovgrad";
$areanames{en}->{3593662} = "Zhelezino";
$areanames{en}->{3593664} = "Plevun";
$areanames{en}->{3593665} = "Svirachi";
$areanames{en}->{3593666} = "Popsko";
$areanames{en}->{3593667} = "Pokrovan";
$areanames{en}->{35936700} = "Shoptsi";
$areanames{en}->{35936702} = "Gorski\ izvor\,\ Kardzh\.";
$areanames{en}->{3593671} = "Podkova";
$areanames{en}->{3593672} = "Chorbadzhiysko";
$areanames{en}->{3593673} = "Tihomir";
$areanames{en}->{3593674} = "Samodiva";
$areanames{en}->{3593675} = "Fotinovo\,\ Kardzh\.";
$areanames{en}->{3593676} = "Benkovski\,\ Kardzh\.";
$areanames{en}->{3593677} = "Drangovo\,\ Kardzh\.";
$areanames{en}->{3593678} = "Chakalarovo";
$areanames{en}->{3593679} = "Kirkovo";
$areanames{en}->{3593691} = "Chernoochene";
$areanames{en}->{3593693} = "Lyaskovo\,\ Kardzh\.";
$areanames{en}->{3593695} = "Komuniga";
$areanames{en}->{3593696} = "Pchelarovo\,\ Kardzh\.";
$areanames{en}->{3593699} = "Gabrovo\,\ Kardzh\.";
$areanames{en}->{3593700} = "Trakiets";
$areanames{en}->{3593701} = "Elena\,\ Hask\.";
$areanames{en}->{3593702} = "Tsareva\ polyana";
$areanames{en}->{3593703} = "Zhalti\ bryag";
$areanames{en}->{3593704} = "Bryagovo\,\ Hask\.";
$areanames{en}->{3593705} = "Vaglarovo";
$areanames{en}->{3593706} = "Tankovo\,\ Hask\.";
$areanames{en}->{3593707} = "Nikolovo\,\ Hask\.";
$areanames{en}->{3593708} = "Orlovo\,\ Hask\.";
$areanames{en}->{3593709} = "Karamantsi";
$areanames{en}->{3593710} = "Uzundzhovo";
$areanames{en}->{3593711} = "Dolno\ Botevo";
$areanames{en}->{3593712} = "Malevo\,\ Hask\.";
$areanames{en}->{3593713} = "Dinevo";
$areanames{en}->{3593717} = "Konush\,\ Hask\.";
$areanames{en}->{3593718} = "Voyvodovo\,\ Hask\.";
$areanames{en}->{3593719} = "Knizhovnik";
$areanames{en}->{3593720} = "Madzharovo";
$areanames{en}->{3593721} = "Stambolovo\,\ Hask\.";
$areanames{en}->{3593722} = "Mineralni\ bani\,\ Hask\.";
$areanames{en}->{3593724} = "Susam";
$areanames{en}->{3593725} = "Stamboliyski\,\ Hask\.";
$areanames{en}->{3593726} = "Klokotnitsa";
$areanames{en}->{3593727} = "Nova\ Nadezhda";
$areanames{en}->{3593728} = "Slavyanovo\,\ Hask\.";
$areanames{en}->{3593729} = "Krivo\ pole";
$areanames{en}->{359373} = "Harmanli";
$areanames{en}->{3593740} = "Pchelari";
$areanames{en}->{3593741} = "Mandra";
$areanames{en}->{35937420} = "Podkrepa";
$areanames{en}->{35937421} = "Dolno\ pole";
$areanames{en}->{35937422} = "Dolni\ Glavanak";
$areanames{en}->{35937423} = "Golemantsi";
$areanames{en}->{35937424} = "Kozlets";
$areanames{en}->{3593743} = "Silen";
$areanames{en}->{3593744} = "Sarnitsa\,\ Hask\.";
$areanames{en}->{3593745} = "Malak\ izvor\,\ Hask\.";
$areanames{en}->{3593746} = "Sirakovo\,\ Hask\.";
$areanames{en}->{3593747} = "Tatarevo\,\ Hask\.";
$areanames{en}->{3593748} = "Lyaskovets\,\ Hask\.";
$areanames{en}->{3593749} = "Garvanovo";
$areanames{en}->{3593751} = "Lyubimets";
$areanames{en}->{3593752} = "Malko\ gradishte";
$areanames{en}->{3593753} = "Oryahovo\,\ Hask\.";
$areanames{en}->{3593754} = "Lozen\,\ Hask\.";
$areanames{en}->{3593755} = "Belitsa\,\ Hask\.";
$areanames{en}->{3593756} = "Valche\ pole";
$areanames{en}->{3593757} = "Georgi\ Dobrevo";
$areanames{en}->{3593758} = "Yerusalimovo";
$areanames{en}->{3593759} = "Borislavtsi";
$areanames{en}->{35937602} = "Cherna\ mogila\,\ Hask\.";
$areanames{en}->{35937603} = "Rogozinovo";
$areanames{en}->{35937604} = "Varbovo\,\ Hask\.";
$areanames{en}->{35937606} = "Shishmanovo";
$areanames{en}->{3593762} = "Izvorovo\,\ Hask\.";
$areanames{en}->{3593763} = "Balgarin";
$areanames{en}->{3593764} = "Polyanovo\,\ Hask\.";
$areanames{en}->{3593765} = "Ivanovo\,\ Hask\.";
$areanames{en}->{3593766} = "Biser";
$areanames{en}->{3593767} = "Branitsa";
$areanames{en}->{3593768} = "Dositeevo";
$areanames{en}->{3593769} = "Oreshets\,\ Hask\.";
$areanames{en}->{35937701} = "Sladun";
$areanames{en}->{35937702} = "Mustrak";
$areanames{en}->{35937703} = "Dimitrovche";
$areanames{en}->{35937704} = "Mladinovo";
$areanames{en}->{35937705} = "Pastrogor";
$areanames{en}->{35937706} = "Chernodab";
$areanames{en}->{35937707} = "Shtit";
$areanames{en}->{3593772} = "Momkovo";
$areanames{en}->{3593773} = "Kapitan\ Andreevo";
$areanames{en}->{3593774} = "Levka";
$areanames{en}->{3593775} = "Generalovo";
$areanames{en}->{3593776} = "Raykova\ mogila";
$areanames{en}->{3593777} = "Mezek";
$areanames{en}->{3593778} = "Studena\,\ Hask\.";
$areanames{en}->{3593779} = "Siva\ reka";
$areanames{en}->{3593781} = "Simeonovgrad";
$areanames{en}->{3593782} = "Kalugerovo\,\ Hask\.";
$areanames{en}->{3593783} = "Svirkovo";
$areanames{en}->{3593784} = "Konstantinovo\,\ Hask\.";
$areanames{en}->{3593785} = "Dryanovo\,\ Hask\.";
$areanames{en}->{3593786} = "Navasen";
$areanames{en}->{3593787} = "Tyanevo\,\ Hask\.";
$areanames{en}->{359379} = "Svilengrad";
$areanames{en}->{35938} = "Haskovo";
$areanames{en}->{359391} = "Dimitrovgrad";
$areanames{en}->{3593920} = "Zlatopole";
$areanames{en}->{3593921} = "Merichleri";
$areanames{en}->{3593922} = "Brod";
$areanames{en}->{3593923} = "Radievo";
$areanames{en}->{3593924} = "Krepost";
$areanames{en}->{3593925} = "Krum";
$areanames{en}->{3593926} = "Dobrich\,\ Hask\.";
$areanames{en}->{3593927} = "Chernogorovo\,\ Hask\.";
$areanames{en}->{3593928} = "Dolno\ Belevo";
$areanames{en}->{3593929} = "Golyamo\ Asenovo";
$areanames{en}->{3593931} = "Kasnakovo";
$areanames{en}->{3593932} = "Bodrovo";
$areanames{en}->{3593933} = "Stransko";
$areanames{en}->{3593934} = "Skobelevo\,\ Hask\.";
$areanames{en}->{3593935} = "Varbitsa\,\ Hask\.";
$areanames{en}->{3593936} = "Gorski\ izvor\,\ Hask\.";
$areanames{en}->{3593937} = "Yabalkovo\,\ Hask\.";
$areanames{en}->{3594100} = "Stoletovo\,\ St\.\ Zagora";
$areanames{en}->{3594101} = "Opan";
$areanames{en}->{35941018} = "Knyazhevsko";
$areanames{en}->{35941019} = "Venets\,\ St\.\ Zagora";
$areanames{en}->{3594102} = "Yastrebovo\,\ St\.\ Zagora";
$areanames{en}->{3594103} = "Byal\ izvor\,\ St\.\ Zagora";
$areanames{en}->{3594104} = "Kravino";
$areanames{en}->{3594105} = "Byalo\ pole";
$areanames{en}->{3594106} = "Pastren";
$areanames{en}->{3594107} = "Sredets\,\ St\.\ Zagora";
$areanames{en}->{3594108} = "Vasil\ Levski\,\ St\.\ Zagora";
$areanames{en}->{3594109} = "Trakia";
$areanames{en}->{35941110} = "Starozagorski\ bani";
$areanames{en}->{35941111} = "Starozagorski\ bani";
$areanames{en}->{35941112} = "Starozagorski\ bani";
$areanames{en}->{35941113} = "Pryaporets\,\ St\.\ Zagora";
$areanames{en}->{35941114} = "Lozen\,\ St\.\ Zagora";
$areanames{en}->{35941115} = "Borilovo";
$areanames{en}->{35941116} = "Sladak\ Kladenets";
$areanames{en}->{35941117} = "Kazanka";
$areanames{en}->{35941118} = "Ostra\ mogila\,\ St\.\ Zagora";
$areanames{en}->{35941119} = "Elhovo\,\ St\.\ Zagora";
$areanames{en}->{3594112} = "Badeshte";
$areanames{en}->{3594113} = "Preslaven";
$areanames{en}->{35941144} = "Kaloyanovets";
$areanames{en}->{35941145} = "Arnautito";
$areanames{en}->{35941146} = "Hristianovo";
$areanames{en}->{35941149} = "Lovets\,\ St\.\ Zagora";
$areanames{en}->{3594115} = "Kirilovo\,\ St\.\ Zagora";
$areanames{en}->{3594116} = "Rakitnitsa\,\ St\.\ Zagora";
$areanames{en}->{35941171} = "Dalboki";
$areanames{en}->{35941172} = "Gorno\ Botevo";
$areanames{en}->{35941173} = "Bratya\ Kunchevi";
$areanames{en}->{35941174} = "Podslon\,\ St\.\ Zagora";
$areanames{en}->{35941175} = "Kolena";
$areanames{en}->{35941178} = "Oryahovitsa\,\ St\.\ Zagora";
$areanames{en}->{35941179} = "Han\ Asparuhovo";
$areanames{en}->{3594118} = "Pamukchii\,\ St\.\ Zagora";
$areanames{en}->{3594121} = "Lyulyak";
$areanames{en}->{3594122} = "Elenino";
$areanames{en}->{3594123} = "Bogomilovo";
$areanames{en}->{3594124} = "Zmeyovo";
$areanames{en}->{3594125} = "Mihaylovo\,\ St\.\ Zagora";
$areanames{en}->{3594126} = "Hrishteni";
$areanames{en}->{35941270} = "Malka\ Vereya";
$areanames{en}->{35941274} = "Samuilovo\,\ St\.\ Zagora";
$areanames{en}->{35941275} = "Lyaskovo\,\ St\.\ Zagora";
$areanames{en}->{35941276} = "Mogila\,\ St\.\ Zagora";
$areanames{en}->{35941277} = "Zagore";
$areanames{en}->{35941279} = "Strelets\,\ St\.\ Zagora";
$areanames{en}->{3594129} = "Madzherito";
$areanames{en}->{3594130} = "Spasovo\,\ St\.\ Zagora";
$areanames{en}->{3594132} = "Orizovo";
$areanames{en}->{35941330} = "Tsenovo\,\ St\.\ Zagora";
$areanames{en}->{35941331} = "Granit";
$areanames{en}->{35941332} = "Naydenovo";
$areanames{en}->{35941333} = "Sredno\ gradishte";
$areanames{en}->{35941334} = "Saedinenie\,\ St\.\ Zagora";
$areanames{en}->{35941335} = "Mogilovo";
$areanames{en}->{35941336} = "Yazdach";
$areanames{en}->{35941337} = "Sarnevets";
$areanames{en}->{35941338} = "Tselina";
$areanames{en}->{35941339} = "Dimitrievo";
$areanames{en}->{3594134} = "Bratya\ Daskalovi";
$areanames{en}->{35941350} = "Mirovo\,\ St\.\ Zagora";
$areanames{en}->{35941351} = "Partizanin";
$areanames{en}->{35941352} = "Vinarovo\,\ St\.\ Zagora";
$areanames{en}->{35941353} = "Plodovitovo";
$areanames{en}->{35941354} = "Malko\ Tranovo";
$areanames{en}->{35941355} = "Yavorovo";
$areanames{en}->{35941356} = "Rupkite";
$areanames{en}->{35941357} = "Zetyovo\,\ St\.\ Zagora";
$areanames{en}->{35941358} = "Opalchenets";
$areanames{en}->{35941359} = "Izvorovo\,\ St\.\ Zagora";
$areanames{en}->{3594136} = "Cherna\ gora\,\ St\.\ Zagora";
$areanames{en}->{3594137} = "Veren";
$areanames{en}->{3594138} = "Gita";
$areanames{en}->{3594139} = "Svoboda\,\ St\.\ Zagora";
$areanames{en}->{3594140} = "Polski\ Gradets";
$areanames{en}->{3594142} = "Troyanovo\,\ St\.\ Zagora";
$areanames{en}->{3594143} = "Sarnevo\,\ St\.\ Zagora";
$areanames{en}->{3594144} = "Kovachevo\,\ St\.\ Zagora";
$areanames{en}->{3594145} = "Znamenosets";
$areanames{en}->{3594146} = "Dinya";
$areanames{en}->{3594147} = "Lyubenovo\,\ St\.\ Zagora";
$areanames{en}->{35941480} = "Kolarovo\,\ St\.\ Zagora";
$areanames{en}->{35941484} = "Zemlen";
$areanames{en}->{35941489} = "Bozduganovo";
$areanames{en}->{3594149} = "Trankovo\,\ St\.\ Zagora";
$areanames{en}->{3594152} = "Obruchishte";
$areanames{en}->{3594153} = "Madrets\,\ St\.\ Zagora";
$areanames{en}->{3594154} = "Mednikarovo";
$areanames{en}->{3594155} = "Glavan\,\ St\.\ Zagora";
$areanames{en}->{3594156} = "Aprilovo\,\ St\.\ Zagora";
$areanames{en}->{3594157} = "Razdelna\,\ St\.\ Zagora";
$areanames{en}->{3594158} = "Iskritsa";
$areanames{en}->{359416} = "Chirpan";
$areanames{en}->{359417} = "Radnevo";
$areanames{en}->{359418} = "Galabovo\,\ St\.\ Zagora";
$areanames{en}->{35942} = "Stara\ Zagora";
$areanames{en}->{359431} = "Kazanlak";
$areanames{en}->{3594321} = "Maglizh";
$areanames{en}->{3594322} = "Yagoda";
$areanames{en}->{3594323} = "Tulovo";
$areanames{en}->{3594324} = "Shipka";
$areanames{en}->{3594325} = "Kanchevo";
$areanames{en}->{3594326} = "Enina";
$areanames{en}->{3594327} = "Sheynovo";
$areanames{en}->{3594329} = "Dolno\ Sahrane";
$areanames{en}->{3594330} = "Nikolaevo\,\ St\.\ Zagora";
$areanames{en}->{3594331} = "Gurkovo\,\ St\.\ Zagora";
$areanames{en}->{3594332} = "Vetren\,\ St\.\ Zagora";
$areanames{en}->{3594333} = "Dabovo\,\ St\.\ Zagora";
$areanames{en}->{3594334} = "Elhovo\,\ St\.\ Zagora\,\ mun\.\ Nikolaevo";
$areanames{en}->{3594335} = "Razhena";
$areanames{en}->{3594336} = "Dolno\ Izvorovo";
$areanames{en}->{3594337} = "Yasenovo\,\ St\.\ Zagora";
$areanames{en}->{3594338} = "Kran";
$areanames{en}->{3594339} = "Yulievo";
$areanames{en}->{3594340} = "Panicherevo";
$areanames{en}->{3594341} = "Cherganovo";
$areanames{en}->{3594342} = "Ovoshtnik";
$areanames{en}->{3594343} = "Konare\,\ St\.\ Zagora";
$areanames{en}->{3594344} = "Shanovo";
$areanames{en}->{3594345} = "Raduntsi";
$areanames{en}->{3594346} = "Golyamo\ Dryanovo";
$areanames{en}->{3594347} = "Rozovo\,\ St\.\ Zagora";
$areanames{en}->{3594348} = "Dunavtsi\,\ St\.\ Zagora";
$areanames{en}->{3594350} = "Gorno\ Izvorovo";
$areanames{en}->{3594351} = "Koprinka";
$areanames{en}->{3594352} = "Gorno\ Cherkovishte";
$areanames{en}->{3594353} = "Srednogorovo";
$areanames{en}->{3594354} = "Zimnitsa\,\ St\.\ Zagora";
$areanames{en}->{3594355} = "Buzovgrad";
$areanames{en}->{3594356} = "Hadzhidimitrovo\,\ St\.\ Zagora";
$areanames{en}->{3594357} = "Gorno\ Sahrane";
$areanames{en}->{3594358} = "Skobelevo\,\ St\.\ Zagora";
$areanames{en}->{3594359} = "Asen\,\ St\.\ Zagora";
$areanames{en}->{3594361} = "Pavel\ banya";
$areanames{en}->{35943616} = "Turia";
$areanames{en}->{3594362} = "Manolovo";
$areanames{en}->{3594363} = "Gabarevo";
$areanames{en}->{3594364} = "Osetenovo";
$areanames{en}->{3594367} = "Tazha";
$areanames{en}->{3594368} = "Tarnicheni";
$areanames{en}->{3594369} = "Aleksandrovo\,\ St\.\ Zagora";
$areanames{en}->{35944} = "Sliven";
$areanames{en}->{3594510} = "Zhelyu\ voyvoda";
$areanames{en}->{3594511} = "Slivenski\ mineralni\ bani";
$areanames{en}->{3594512} = "Blatets\,\ Sliven";
$areanames{en}->{3594513} = "Gavrailovoc";
$areanames{en}->{3594514} = "Krushare";
$areanames{en}->{3594515} = "Mokren";
$areanames{en}->{3594516} = "Kermen";
$areanames{en}->{3594517} = "Ichera";
$areanames{en}->{3594518} = "Topolchane";
$areanames{en}->{3594519} = "Samuilovo\,\ Sliven";
$areanames{en}->{3594520} = "Konyovo";
$areanames{en}->{3594522} = "Korten";
$areanames{en}->{3594523} = "Stoil\ voyvoda";
$areanames{en}->{3594524} = "Kamenovo\,\ Sliven";
$areanames{en}->{3594525} = "Omarchevo\,\ Sliven";
$areanames{en}->{3594526} = "Mlekarevo";
$areanames{en}->{3594527} = "Zagortsi\,\ Sliven";
$areanames{en}->{3594528} = "Lyubenova\ mahala";
$areanames{en}->{3594529} = "Sadievo\,\ Sliven";
$areanames{en}->{359453} = "Kotel";
$areanames{en}->{359454} = "Tvarditsa\,\ Sliven";
$areanames{en}->{3594551} = "Byala\,\ Sliven";
$areanames{en}->{3594552} = "Stara\ reka\,\ Sliven";
$areanames{en}->{3594553} = "Rakovo\,\ Sliven";
$areanames{en}->{3594554} = "Trapoklovo";
$areanames{en}->{3594556} = "Sotirya";
$areanames{en}->{3594557} = "Bikovo";
$areanames{en}->{3594562} = "Kriva\ krusha";
$areanames{en}->{3594564} = "Novoselets";
$areanames{en}->{3594566} = "Pitovo";
$areanames{en}->{3594567} = "Banya\,\ Sliven";
$areanames{en}->{359457} = "Nova\ Zagora";
$areanames{en}->{3594580} = "Borintsi";
$areanames{en}->{3594582} = "Gradets\,\ Sliven";
$areanames{en}->{3594583} = "Kipilovo";
$areanames{en}->{3594584} = "Ticha";
$areanames{en}->{3594585} = "Zheravna";
$areanames{en}->{3594586} = "Neykovo\,\ Sliven";
$areanames{en}->{3594587} = "Yablanovo";
$areanames{en}->{3594588} = "Filaretovo";
$areanames{en}->{3594592} = "Byala\ palanka";
$areanames{en}->{3594593} = "Shivachevo";
$areanames{en}->{3594595} = "Sborishte";
$areanames{en}->{3594597} = "Borov\ dol";
$areanames{en}->{3594599} = "Chervenakovo";
$areanames{en}->{35946} = "Yambol";
$areanames{en}->{359470} = "Topolovgrad";
$areanames{en}->{3594710} = "Bolyarsko";
$areanames{en}->{3594711} = "Bezmer\,\ Yambol";
$areanames{en}->{3594712} = "Kabile";
$areanames{en}->{3594713} = "Stara\ reka\,\ Yambol";
$areanames{en}->{3594714} = "Drazhevo";
$areanames{en}->{3594715} = "Kalchevo";
$areanames{en}->{3594716} = "Veselinovo\,\ Yambol";
$areanames{en}->{3594717} = "Chargan";
$areanames{en}->{3594718} = "Roza";
$areanames{en}->{35947192} = "Zavoy";
$areanames{en}->{35947193} = "Mogila\,\ Yambol";
$areanames{en}->{35947201} = "Izgrev\,\ Yambol";
$areanames{en}->{35947202} = "Zhrebino";
$areanames{en}->{35947203} = "Trankovo\,\ Yambol";
$areanames{en}->{35947204} = "Pchela";
$areanames{en}->{3594722} = "Granitovo\,\ Yambol";
$areanames{en}->{3594723} = "Boyanovo\,\ Yambol";
$areanames{en}->{3594724} = "Razdel\,\ Yambol";
$areanames{en}->{3594725} = "Lesovo";
$areanames{en}->{3594726} = "Malomirovo";
$areanames{en}->{3594727} = "Malak\ manastir";
$areanames{en}->{3594728} = "Melnitsa";
$areanames{en}->{3594729} = "Kirilovo\,\ Yambol";
$areanames{en}->{3594730} = "Knyazhevo";
$areanames{en}->{3594732} = "Ustrem";
$areanames{en}->{3594733} = "Orlov\ dol";
$areanames{en}->{3594734} = "Srem";
$areanames{en}->{35947353} = "Balgarska\ polyana";
$areanames{en}->{35947354} = "Kamenna\ reka";
$areanames{en}->{35947356} = "Mramor\,\ Yambol";
$areanames{en}->{3594736} = "Svetlina";
$areanames{en}->{3594737} = "Sinapovo";
$areanames{en}->{3594738} = "Hlyabovo";
$areanames{en}->{3594739} = "Radovets";
$areanames{en}->{3594741} = "Bolyarovo";
$areanames{en}->{3594742} = "Stefan\ Karadzhovo";
$areanames{en}->{3594743} = "Mamarchevo";
$areanames{en}->{3594744} = "Golyamo\ Krushevo";
$areanames{en}->{3594745} = "Sharkovo";
$areanames{en}->{3594746} = "Popovo\,\ Yambol";
$areanames{en}->{3594747} = "Dennitsa\,\ Yambol";
$areanames{en}->{3594748} = "Voden\,\ Yambol";
$areanames{en}->{3594749} = "Ruzhitsa\,\ Yambol";
$areanames{en}->{3594751} = "Voynika";
$areanames{en}->{3594752} = "Parvenets\,\ Yambol";
$areanames{en}->{3594753} = "Zornitsa\,\ Yambol";
$areanames{en}->{3594754} = "Kamenets\,\ Yambol";
$areanames{en}->{3594755} = "Tamarino";
$areanames{en}->{3594756} = "Polyana\,\ Yambol";
$areanames{en}->{3594757} = "Nedyalsko";
$areanames{en}->{3594761} = "Straldzha";
$areanames{en}->{3594762} = "Vodenichane";
$areanames{en}->{3594763} = "Irechekovo";
$areanames{en}->{3594764} = "Malenovo";
$areanames{en}->{3594768} = "Zimnitsa\,\ Yambol";
$areanames{en}->{3594770} = "General\ Inzovo";
$areanames{en}->{3594771} = "Malomir\,\ Yambol";
$areanames{en}->{3594772} = "Simeonovo\,\ Yambol";
$areanames{en}->{3594773} = "Okop";
$areanames{en}->{3594774} = "Krumovo\,\ Yambol";
$areanames{en}->{3594775} = "Karavelovo\,\ Yambol";
$areanames{en}->{3594777} = "Tenevo";
$areanames{en}->{3594778} = "Pobeda\,\ Yambol";
$areanames{en}->{3594779} = "Hanovo";
$areanames{en}->{359478} = "Elhovo\,\ Yambol";
$areanames{en}->{3594792} = "Botevo\,\ Yambol";
$areanames{en}->{3594793} = "Boyadzhik";
$areanames{en}->{3594794} = "Ovchi\ kladenets";
$areanames{en}->{3594795} = "Skalitsa";
$areanames{en}->{3594796} = "General\ Toshevo\,\ Yambol";
$areanames{en}->{3594797} = "Galabintsi";
$areanames{en}->{3594798} = "Savino";
$areanames{en}->{3594799} = "Golyam\ manastir";
$areanames{en}->{3595100} = "Sindel";
$areanames{en}->{3595101} = "Dabravino";
$areanames{en}->{3595102} = "Padina\,\ Varna";
$areanames{en}->{3595105} = "Priseltsi\,\ Varna";
$areanames{en}->{3595106} = "Avren\,\ Varna";
$areanames{en}->{3595108} = "Sadovo\,\ Varna";
$areanames{en}->{35951103} = "Lyuben\ Karavelovo";
$areanames{en}->{35951104} = "Dolishte\,\ Varna";
$areanames{en}->{35951106} = "Osenovo\,\ Varna";
$areanames{en}->{35951108} = "Izvorsko";
$areanames{en}->{3595112} = "Beloslav";
$areanames{en}->{35951125} = "Konstantinovo\,\ Varna";
$areanames{en}->{35951127} = "Razdelna\,\ Varna";
$areanames{en}->{3595114} = "Ezerovo\,\ Varna";
$areanames{en}->{3595115} = "General\ Kantardzhievo";
$areanames{en}->{3595116} = "Krumovo\,\ Varna";
$areanames{en}->{3595117} = "Botevo\,\ Varna";
$areanames{en}->{3595118} = "Voditsa\,\ Varna";
$areanames{en}->{3595119} = "Ignatievo";
$areanames{en}->{3595120} = "Bozveliysko";
$areanames{en}->{3595121} = "Tutrakantsi";
$areanames{en}->{3595122} = "Slaveykovo\,\ Varna";
$areanames{en}->{3595123} = "Ravna\,\ Varna";
$areanames{en}->{3595124} = "Komarevo\,\ Varna";
$areanames{en}->{3595125} = "Gradinarovo";
$areanames{en}->{3595126} = "Cherkovna\,\ Varna";
$areanames{en}->{3595127} = "Manastir\,\ Varna";
$areanames{en}->{3595128} = "Zhitnitsa\,\ Varna";
$areanames{en}->{3595129} = "Blaskovo";
$areanames{en}->{3595130} = "General\ Kiselovo";
$areanames{en}->{3595131} = "Valchi\ dol";
$areanames{en}->{35951314} = "Voyvodino";
$areanames{en}->{3595132} = "Mihalich\,\ Varna";
$areanames{en}->{3595133} = "General\ Kolevo\,\ Varna";
$areanames{en}->{3595134} = "Cherventsi";
$areanames{en}->{3595135} = "Stefan\ Karadzha\,\ Varna";
$areanames{en}->{3595136} = "Brestak";
$areanames{en}->{3595137} = "Kaloyan";
$areanames{en}->{3595138} = "Dobrotich";
$areanames{en}->{3595139} = "Oborishte\,\ Varna";
$areanames{en}->{3595140} = "Shkorpilovtsi";
$areanames{en}->{3595141} = "Staro\ Oryahovo";
$areanames{en}->{3595142} = "Dolni\ chiflik";
$areanames{en}->{35951428} = "Gospodinovo\,\ Varna";
$areanames{en}->{35951429} = "Solnik";
$areanames{en}->{3595143} = "Byala\,\ Varna";
$areanames{en}->{3595144} = "Kamchia";
$areanames{en}->{3595145} = "Grozdyovo";
$areanames{en}->{3595146} = "Goren\ chiflik";
$areanames{en}->{3595147} = "Pchelnik\,\ Varna";
$areanames{en}->{3595148} = "Rudnik\,\ Varna";
$areanames{en}->{3595149} = "Golitsa";
$areanames{en}->{3595153} = "Suvorovo";
$areanames{en}->{35951536} = "Nikolaevka";
$areanames{en}->{35951537} = "Chernevo";
$areanames{en}->{35951538} = "Izgrev\,\ Varna";
$areanames{en}->{35951539} = "Levski\,\ Varna";
$areanames{en}->{3595161} = "Vetrino";
$areanames{en}->{3595162} = "Belogradets";
$areanames{en}->{3595163} = "Mlada\ gvardia";
$areanames{en}->{3595164} = "Neofit\ Rilski";
$areanames{en}->{3595165} = "Nevsha";
$areanames{en}->{3595166} = "Dobroplodno";
$areanames{en}->{3595167} = "Venchan";
$areanames{en}->{3595168} = "Petrov\ dol\,\ Varna";
$areanames{en}->{3595169} = "Momchilovo";
$areanames{en}->{359517} = "Dalgopol";
$areanames{en}->{359518} = "Provadia";
$areanames{en}->{359519} = "Devnya";
$areanames{en}->{35952} = "Varna";
$areanames{en}->{3595310} = "Radko\ Dimitrievo";
$areanames{en}->{3595311} = "Gradishte\,\ Shumen";
$areanames{en}->{3595312} = "Dibich";
$areanames{en}->{3595313} = "Madara";
$areanames{en}->{3595314} = "Belokopitovo";
$areanames{en}->{3595315} = "Tsarev\ brod";
$areanames{en}->{3595316} = "Salmanovo";
$areanames{en}->{3595317} = "Ivanski";
$areanames{en}->{3595318} = "Srednya";
$areanames{en}->{3595319} = "Drumevo";
$areanames{en}->{3595320} = "Pet\ mogili\,\ Shumen";
$areanames{en}->{3595321} = "Praventsi";
$areanames{en}->{35953220} = "Pamukchii\,\ Shumen";
$areanames{en}->{35953221} = "Stoyan\ Mihaylovski";
$areanames{en}->{35953222} = "Markovo\,\ Shumen";
$areanames{en}->{35953223} = "Tsarkvitsa";
$areanames{en}->{3595323} = "Pliska";
$areanames{en}->{35953234} = "Zlatna\ niva";
$areanames{en}->{3595324} = "Harsovo\,\ Shumen";
$areanames{en}->{3595325} = "Voyvoda";
$areanames{en}->{3595326} = "Varbyane";
$areanames{en}->{3595327} = "Kaspichan\,\ Shumen";
$areanames{en}->{3595328} = "Nikola\ Kozlevo";
$areanames{en}->{3595329} = "Mirovtsi";
$areanames{en}->{3595330} = "Zlatar";
$areanames{en}->{3595332} = "Dragoevo";
$areanames{en}->{3595333} = "Han\ Krum";
$areanames{en}->{3595334} = "Osmar";
$areanames{en}->{3595335} = "Milanovo\,\ Shumen";
$areanames{en}->{3595336} = "Imrenchevo";
$areanames{en}->{3595337} = "Kochovo";
$areanames{en}->{3595338} = "Troitsa";
$areanames{en}->{3595340} = "Visoka\ polyana\,\ Shumen";
$areanames{en}->{3595341} = "Hitrino";
$areanames{en}->{3595342} = "Kapitan\ Petko";
$areanames{en}->{3595343} = "Venets\,\ Shumen";
$areanames{en}->{35953434} = "Yasenkovo";
$areanames{en}->{35953435} = "Izgrev\,\ Shumen";
$areanames{en}->{35953436} = "Chernoglavtsi";
$areanames{en}->{35953437} = "Gabritsa\,\ Shumen";
$areanames{en}->{3595344} = "Velino";
$areanames{en}->{3595345} = "Razvigorovo";
$areanames{en}->{3595346} = "Kamenyak\,\ Shumen";
$areanames{en}->{3595347} = "Zhivkovo\,\ Shumen";
$areanames{en}->{3595348} = "Trem";
$areanames{en}->{3595349} = "Studenitsa";
$areanames{en}->{3595351} = "Smyadovo";
$areanames{en}->{3595352} = "Yankovo";
$areanames{en}->{3595353} = "Veselinovo\,\ Shumen";
$areanames{en}->{3595354} = "Rish";
$areanames{en}->{3595361} = "Kaolinovo";
$areanames{en}->{3595362} = "Kliment\,\ Shumen";
$areanames{en}->{3595363} = "Gusla";
$areanames{en}->{3595365} = "Lyatno";
$areanames{en}->{3595366} = "Branichevo";
$areanames{en}->{3595367} = "Todor\ Ikonomovo";
$areanames{en}->{3595368} = "Takach";
$areanames{en}->{359537} = "Novi\ pazar\,\ Shumen";
$areanames{en}->{359538} = "Veliki\ Preslav";
$areanames{en}->{3595391} = "Varbitsa\,\ Shumen";
$areanames{en}->{3595392} = "Mengishevo";
$areanames{en}->{3595393} = "Ivanovo\,\ Shumen";
$areanames{en}->{3595394} = "Byala\ reka\,\ Shumen";
$areanames{en}->{3595395} = "Chernookovo\,\ Shumen";
$areanames{en}->{3595396} = "Lovets\,\ Shumen";
$areanames{en}->{3595397} = "Metodievo\,\ Shumen";
$areanames{en}->{35954} = "Shumen";
$areanames{en}->{359550} = "Sozopol";
$areanames{en}->{3595511} = "Lukoil\ Neftochim";
$areanames{en}->{3595513} = "Gabar";
$areanames{en}->{3595515} = "Kameno";
$areanames{en}->{3595516} = "Indzhe\ voyvoda";
$areanames{en}->{3595517} = "Ravnets\,\ Burgas";
$areanames{en}->{3595518} = "Rudnik\,\ Burgas";
$areanames{en}->{3595519} = "Zidarovo";
$areanames{en}->{3595520} = "Cherkovo";
$areanames{en}->{3595521} = "Venets\,\ Burgas";
$areanames{en}->{3595522} = "Iskra\,\ Burgas";
$areanames{en}->{3595523} = "Krumovo\ gradishte";
$areanames{en}->{3595524} = "Ekzarh\ Antimovo";
$areanames{en}->{3595525} = "Devetak";
$areanames{en}->{3595526} = "Klikach";
$areanames{en}->{3595527} = "Sokolovo\,\ Burgas";
$areanames{en}->{3595528} = "Nevestino\,\ Burgas";
$areanames{en}->{3595529} = "Krushovo\,\ Burgas";
$areanames{en}->{3595530} = "Peshtersko";
$areanames{en}->{3595532} = "Topolitsa";
$areanames{en}->{3595533} = "Pirne";
$areanames{en}->{3595534} = "Karageorgievo";
$areanames{en}->{3595535} = "Lyaskovo\,\ Burgas";
$areanames{en}->{3595536} = "Maglen";
$areanames{en}->{3595537} = "Sadievo\,\ Burgas";
$areanames{en}->{3595538} = "Karanovo\,\ Burgas";
$areanames{en}->{3595539} = "Chernograd";
$areanames{en}->{359554} = "Sunny\ Beach";
$areanames{en}->{35955502} = "Suhodol\,\ Burgas";
$areanames{en}->{35955504} = "Bogdanovo\,\ Burgas";
$areanames{en}->{35955505} = "Drachevo";
$areanames{en}->{3595551} = "Sredets\,\ Burgas";
$areanames{en}->{3595552} = "Dyulevo\,\ Burgas";
$areanames{en}->{3595553} = "Orlintsi";
$areanames{en}->{3595554} = "Momina\ tsarkva";
$areanames{en}->{3595555} = "Fakia";
$areanames{en}->{3595556} = "Golyamo\ Bukovo";
$areanames{en}->{3595557} = "Bistrets\,\ Burgas";
$areanames{en}->{3595558} = "Debelt";
$areanames{en}->{3595559} = "Kubadin";
$areanames{en}->{359556} = "Obzor";
$areanames{en}->{3595570} = "Manolich";
$areanames{en}->{3595571} = "Sungurlare";
$areanames{en}->{3595572} = "Beronovo";
$areanames{en}->{3595573} = "Vezenkovo";
$areanames{en}->{3595574} = "Saedinenie\,\ Burgas";
$areanames{en}->{3595575} = "Prilep\,\ Burgas";
$areanames{en}->{3595576} = "Lozarevo";
$areanames{en}->{3595577} = "Podvis\,\ Burgas";
$areanames{en}->{3595578} = "Terziysko\,\ Burgas";
$areanames{en}->{3595579} = "Vedrovo";
$areanames{en}->{359558} = "Aytos";
$areanames{en}->{3595580} = "Troyanovo\,\ Burgas";
$areanames{en}->{3595589} = "Vinarsko";
$areanames{en}->{359559} = "Karnobat";
$areanames{en}->{3595590} = "Zhitosvyat";
$areanames{en}->{3595599} = "Hadzhiite";
$areanames{en}->{35956} = "Burgas";
$areanames{en}->{359570} = "Kavarna";
$areanames{en}->{3595710} = "Pobeda\,\ Dobr\.";
$areanames{en}->{3595711} = "Ovcharovo\,\ Dobr\.";
$areanames{en}->{3595712} = "Stozher";
$areanames{en}->{3595713} = "Stefanovo\,\ Dobr\.";
$areanames{en}->{3595714} = "Karapelit";
$areanames{en}->{3595715} = "Popgrigorovo";
$areanames{en}->{3595716} = "Paskalevo";
$areanames{en}->{3595717} = "Vedrina";
$areanames{en}->{3595718} = "Smolnitsa";
$areanames{en}->{3595719} = "Donchevo";
$areanames{en}->{3595723} = "Gurkovo\,\ Dobr\.";
$areanames{en}->{3595724} = "Dropla\,\ Dobr\.";
$areanames{en}->{3595726} = "Tsarichino";
$areanames{en}->{3595727} = "Senokos\,\ Dobr\.";
$areanames{en}->{35957304} = "Dabovik";
$areanames{en}->{35957305} = "Rositsa\,\ Dobr\.";
$areanames{en}->{35957306} = "Izvorovo\,\ Dobr\.";
$areanames{en}->{35957307} = "Zhiten\,\ Dobr\.";
$areanames{en}->{35957308} = "Chernookovo\,\ Dobr\.";
$areanames{en}->{3595731} = "General\ Toshevo\,\ Dobr\.";
$areanames{en}->{3595732} = "Petleshkovo";
$areanames{en}->{3595733} = "Kardam\,\ Dobr\.";
$areanames{en}->{3595734} = "Preselentsi";
$areanames{en}->{3595735} = "Krasen\,\ Dobr\.";
$areanames{en}->{3595736} = "Vasilevo";
$areanames{en}->{3595737} = "Lyulyakovo\,\ Dobr\.";
$areanames{en}->{3595738} = "Spasovo\,\ Dobr\.";
$areanames{en}->{3595739} = "Pchelarovo\,\ Dobr\.";
$areanames{en}->{3595740} = "Gorichane";
$areanames{en}->{3595742} = "Rakovski\,\ Dobr\.";
$areanames{en}->{3595743} = "Shabla";
$areanames{en}->{3595745} = "Vranino";
$areanames{en}->{3595746} = "Belgun";
$areanames{en}->{3595747} = "Vaklino";
$areanames{en}->{3595748} = "Durankulak";
$areanames{en}->{3595749} = "Krapets\,\ Dobr\.";
$areanames{en}->{3595750} = "Kableshkovo\,\ Dobr\.";
$areanames{en}->{3595751} = "Tervel\,\ Dobr\.";
$areanames{en}->{3595752} = "Nova\ Kamena";
$areanames{en}->{3595753} = "Orlyak";
$areanames{en}->{3595754} = "Zarnevo";
$areanames{en}->{3595755} = "Kolartsi";
$areanames{en}->{3595756} = "Bozhan";
$areanames{en}->{3595757} = "Bezmer\,\ Dobr\.";
$areanames{en}->{3595758} = "Kladentsi";
$areanames{en}->{3595759} = "Kochmar";
$areanames{en}->{3595760} = "Bozhurovo\,\ Dobr\.";
$areanames{en}->{3595761} = "Batovo";
$areanames{en}->{3595762} = "Stefan\ Karadzha\,\ Dobr\.";
$areanames{en}->{3595763} = "Plachidol";
$areanames{en}->{3595764} = "Vladimirovo\,\ Dobr\.";
$areanames{en}->{3595765} = "Lovchantsi";
$areanames{en}->{3595766} = "Metodievo\,\ Dobr\.";
$areanames{en}->{3595767} = "Zhitnitsa\,\ Dobr\.";
$areanames{en}->{3595768} = "Odrintsi\,\ Dobr\.";
$areanames{en}->{3595769} = "Hitovo";
$areanames{en}->{3595771} = "Krushari";
$areanames{en}->{3595772} = "Telerig";
$areanames{en}->{3595773} = "Lozenets\,\ Dobr\.";
$areanames{en}->{3595774} = "Koriten";
$areanames{en}->{3595775} = "Polkovnik\ Dyakovo";
$areanames{en}->{3595776} = "Cherna\,\ Dobr\.";
$areanames{en}->{3595781} = "Svoboda\,\ Dobr\.";
$areanames{en}->{3595782} = "Benkovski\,\ Dobr\.";
$areanames{en}->{3595783} = "Kotlentsi";
$areanames{en}->{3595784} = "Vrachantsi";
$areanames{en}->{359579} = "Albena";
$areanames{en}->{35958} = "Dobrich";
$areanames{en}->{359590} = "Tsarevo";
$areanames{en}->{3595910} = "Cherni\ vrah\,\ Burgas";
$areanames{en}->{3595912} = "Polski\ izvor";
$areanames{en}->{3595913} = "Krushevets";
$areanames{en}->{3595914} = "Atia";
$areanames{en}->{3595915} = "Balgarovo";
$areanames{en}->{3595916} = "Rosen\,\ Burgas";
$areanames{en}->{3595917} = "Izvor\,\ Burgas";
$areanames{en}->{3595918} = "Rusokastro";
$areanames{en}->{3595919} = "Marinka";
$areanames{en}->{35959400} = "Daskotna";
$areanames{en}->{35959403} = "Rechitsa";
$areanames{en}->{35959404} = "Yasenovo\,\ Burgas";
$areanames{en}->{35959405} = "Zaychar";
$areanames{en}->{35959406} = "Razboyna\,\ Burgas";
$areanames{en}->{35959407} = "Sini\ rid";
$areanames{en}->{35959408} = "Razhitsa";
$areanames{en}->{35959409} = "Cheresha";
$areanames{en}->{3595941} = "Skalak\,\ Burgas";
$areanames{en}->{3595942} = "Lyulyakovo\,\ Burgas";
$areanames{en}->{3595943} = "Vresovo";
$areanames{en}->{3595944} = "Ruen\,\ Burgas";
$areanames{en}->{3595945} = "Dobromir";
$areanames{en}->{3595946} = "Tranak";
$areanames{en}->{3595947} = "Prosenik";
$areanames{en}->{3595948} = "Snyagovo\,\ Burgas";
$areanames{en}->{3595949} = "Planinitsa\,\ Burgas";
$areanames{en}->{3595952} = "Malko\ Tarnovo";
$areanames{en}->{3595958} = "Gramatikovo";
$areanames{en}->{3595959} = "Zvezdets";
$areanames{en}->{359596} = "Pomorie";
$areanames{en}->{3595967} = "Bata";
$areanames{en}->{3595968} = "Kableshkovo\,\ Burgas";
$areanames{en}->{3595969} = "Galabets\,\ Burgas";
$areanames{en}->{35959694} = "Gaberovo";
$areanames{en}->{3596001} = "Cherkovna\,\ Targ\.";
$areanames{en}->{3596002} = "Saedinenie\,\ Targ\.";
$areanames{en}->{3596003} = "Preselets";
$areanames{en}->{3596004} = "Makovo";
$areanames{en}->{3596006} = "Presian";
$areanames{en}->{3596007} = "Ralitsa";
$areanames{en}->{359601} = "Targovishte";
$areanames{en}->{3596020} = "Lilyak";
$areanames{en}->{3596021} = "Buhovtsi";
$areanames{en}->{3596022} = "Probuda\,\ Targ\.";
$areanames{en}->{3596023} = "Podgoritsa";
$areanames{en}->{3596024} = "Ruets";
$areanames{en}->{3596025} = "Alvanovo";
$areanames{en}->{3596026} = "Makariopolsko";
$areanames{en}->{3596027} = "Dralfa";
$areanames{en}->{3596028} = "Vardun";
$areanames{en}->{3596029} = "Nadarevo";
$areanames{en}->{3596030} = "Svetlen\,\ Targ\.";
$areanames{en}->{3596032} = "Zaraevo";
$areanames{en}->{3596033} = "Medovina";
$areanames{en}->{3596034} = "Slavyanovo\,\ Targ\.";
$areanames{en}->{3596035} = "Palamartsa";
$areanames{en}->{3596036} = "Sadina";
$areanames{en}->{35960370} = "Golyamo\ gradishte";
$areanames{en}->{35960372} = "Krepcha";
$areanames{en}->{35960373} = "Posabina";
$areanames{en}->{35960374} = "Gorsko\ Ablanovo";
$areanames{en}->{35960375} = "Garchinovo";
$areanames{en}->{35960376} = "Lyublen";
$areanames{en}->{35960377} = "Aprilovo\,\ Targ\.";
$areanames{en}->{35960378} = "Tsar\ Asen\,\ Targ\.";
$areanames{en}->{35960380} = "Drinovo";
$areanames{en}->{35960382} = "Kovachevets";
$areanames{en}->{35960383} = "Berkovski";
$areanames{en}->{35960384} = "Gagovo";
$areanames{en}->{35960385} = "Lomtsi";
$areanames{en}->{35960386} = "Voditsa\,\ Targ\.";
$areanames{en}->{35960387} = "Gloginka";
$areanames{en}->{35960388} = "Goritsa\,\ Targ\.";
$areanames{en}->{35960389} = "Kardam\,\ Targ\.";
$areanames{en}->{3596039} = "Opaka";
$areanames{en}->{3596042} = "Iliyno";
$areanames{en}->{3596043} = "Dolno\ Novkovo";
$areanames{en}->{3596044} = "Dolno\ Kozarevo";
$areanames{en}->{35960450} = "Dolna\ Hubavka";
$areanames{en}->{35960451} = "Obitel";
$areanames{en}->{35960453} = "Moravka";
$areanames{en}->{35960454} = "Zmeyno";
$areanames{en}->{35960458} = "Verentsi";
$areanames{en}->{3596046} = "Vrani\ kon";
$areanames{en}->{3596047} = "Zelena\ morava";
$areanames{en}->{3596048} = "Izvorovo\,\ Targ\.";
$areanames{en}->{3596049} = "Kamburovo";
$areanames{en}->{359605} = "Omurtag";
$areanames{en}->{3596060} = "Ovcharovo\,\ Targ\.";
$areanames{en}->{3596061} = "Golyamo\ Sokolovo";
$areanames{en}->{3596062} = "Strazha\,\ Targ\.";
$areanames{en}->{3596063} = "Bayachevo";
$areanames{en}->{3596064} = "Golyamo\ Novo";
$areanames{en}->{3596065} = "Bistra\,\ Targ\.";
$areanames{en}->{3596066} = "Buynovo\,\ Targ\.";
$areanames{en}->{3596067} = "Kralevo\,\ Targ\.";
$areanames{en}->{3596068} = "Bozhurka";
$areanames{en}->{3596069} = "Vasil\ Levski\,\ Targ\.";
$areanames{en}->{3596071} = "Antonovo";
$areanames{en}->{3596072} = "Dobrotitsa\,\ Targ\.";
$areanames{en}->{3596074} = "Lyubichevo";
$areanames{en}->{3596076} = "Taymishte";
$areanames{en}->{3596077} = "Stevrek";
$areanames{en}->{359608} = "Popovo\,\ Targ\.";
$areanames{en}->{359610} = "Pavlikeni\,\ V\.\ Tarnovo";
$areanames{en}->{35961101} = "Velchevo\,\ V\.\ Tarnovo";
$areanames{en}->{35961102} = "Pchelishte";
$areanames{en}->{35961103} = "Rusalya";
$areanames{en}->{35961104} = "Vodoley";
$areanames{en}->{35961105} = "Prisovo";
$areanames{en}->{35961106} = "Novo\ selo\,\ V\.\ Tarnovo";
$areanames{en}->{35961107} = "Momin\ sbor";
$areanames{en}->{35961108} = "Plakovo";
$areanames{en}->{35961109} = "Vaglevtsi";
$areanames{en}->{3596111} = "Kapinovo\,\ V\.\ Tarnovo";
$areanames{en}->{3596112} = "Samovodene";
$areanames{en}->{3596113} = "Balvan";
$areanames{en}->{3596114} = "Kilifarevo";
$areanames{en}->{3596115} = "Resen";
$areanames{en}->{3596116} = "Golemanite";
$areanames{en}->{3596117} = "Debelets\,\ V\.\ Tarnovo";
$areanames{en}->{3596118} = "Voneshta\ voda";
$areanames{en}->{3596119} = "Dichin";
$areanames{en}->{35961203} = "Emen";
$areanames{en}->{3596121} = "Nikyup";
$areanames{en}->{3596122} = "Belyakovets";
$areanames{en}->{3596123} = "Bukovets\,\ V\.\ Tarnovo";
$areanames{en}->{3596124} = "Ledenik";
$areanames{en}->{3596125} = "Pushevo";
$areanames{en}->{3596126} = "Tserova\ koria";
$areanames{en}->{3596128} = "Hotnitsa";
$areanames{en}->{3596129} = "Gabrovtsi";
$areanames{en}->{35961301} = "Byala\ reka\,\ V\.\ Tarnovo";
$areanames{en}->{35961302} = "Batak\,\ V\.\ Tarnovo";
$areanames{en}->{35961303} = "Gorna\ Lipnitsa";
$areanames{en}->{35961304} = "Dimcha";
$areanames{en}->{35961305} = "Lesicheri";
$areanames{en}->{35961306} = "Patresh";
$areanames{en}->{35961307} = "Stambolovo\,\ V\.\ Tarnovo";
$areanames{en}->{35961308} = "Vishovgrad";
$areanames{en}->{35961309} = "Gorsko\ Kalugerovo";
$areanames{en}->{3596132} = "Karaisen";
$areanames{en}->{3596133} = "Mihaltsi";
$areanames{en}->{3596134} = "Byala\ cherkva\,\ V\.\ Tarnovo";
$areanames{en}->{3596135} = "Varbovka";
$areanames{en}->{3596136} = "Suhindol";
$areanames{en}->{3596137} = "Butovo";
$areanames{en}->{3596138} = "Nedan";
$areanames{en}->{35961391} = "Slomer";
$areanames{en}->{35961393} = "Gorsko\ Kosovo";
$areanames{en}->{35961394} = "Daskot";
$areanames{en}->{35961395} = "Paskalevets";
$areanames{en}->{35961397} = "Musina";
$areanames{en}->{35961402} = "Stefan\ Stambolovo";
$areanames{en}->{35961403} = "Orlovets";
$areanames{en}->{35961405} = "Petko\ Karavelovo";
$areanames{en}->{35961406} = "Karantsi";
$areanames{en}->{3596141} = "Polski\ Trambesh";
$areanames{en}->{3596142} = "Obedinenie";
$areanames{en}->{3596143} = "Maslarevo";
$areanames{en}->{3596144} = "Dolna\ Lipnitsa";
$areanames{en}->{3596145} = "Strahilovo";
$areanames{en}->{3596146} = "Polski\ Senovets";
$areanames{en}->{3596147} = "Ivancha\,\ V\.\ Tarnovo";
$areanames{en}->{3596148} = "Pavel";
$areanames{en}->{3596149} = "Kutsina";
$areanames{en}->{3596150} = "Zlataritsa";
$areanames{en}->{35961502} = "Gorsko\ Novo\ Selo";
$areanames{en}->{35961503} = "Chakali";
$areanames{en}->{3596151} = "Elena\,\ V\.\ Tarnovo";
$areanames{en}->{3596152} = "Bebrovo";
$areanames{en}->{3596153} = "Zlataritsa";
$areanames{en}->{3596154} = "Buynovtsi";
$areanames{en}->{3596155} = "Konstantin";
$areanames{en}->{3596156} = "Rodina";
$areanames{en}->{3596157} = "Slivovitsa";
$areanames{en}->{3596158} = "Sredni\ kolibi";
$areanames{en}->{3596159} = "Zlataritsa";
$areanames{en}->{35961602} = "Tsarski\ izvor";
$areanames{en}->{35961603} = "Lozen\,\ V\.\ Tarnovo";
$areanames{en}->{35961604} = "Mirovo\,\ V\.\ Tarnovo";
$areanames{en}->{35961605} = "Novo\ gradishte";
$areanames{en}->{35961606} = "Vladislav";
$areanames{en}->{35961607} = "Balkantsi\,\ V\.\ Tarnovo";
$areanames{en}->{35961608} = "Gorski\ Senovets";
$areanames{en}->{3596161} = "Strazhitsa\,\ V\.\ Tarnovo";
$areanames{en}->{3596163} = "Kamen\,\ V\.\ Tarnovo";
$areanames{en}->{3596164} = "Bryagovitsa";
$areanames{en}->{3596165} = "Asenovo\,\ V\.\ Tarnovo";
$areanames{en}->{3596166} = "Vinograd";
$areanames{en}->{3596167} = "Kesarevo";
$areanames{en}->{3596168} = "Sushitsa\,\ V\.\ Tarnovo";
$areanames{en}->{3596169} = "Blagoevo\,\ V\.\ Tarnovo";
$areanames{en}->{35961703} = "Varbitsa\,\ V\.\ Tarnovo";
$areanames{en}->{35961704} = "Pravda\,\ V\.\ Tarnovo";
$areanames{en}->{35961705} = "Gorski\ dolen\ Trambesh";
$areanames{en}->{35961706} = "Pisarevo\,\ V\.\ Tarnovo";
$areanames{en}->{3596173} = "Dolna\ Oryahovitsa";
$areanames{en}->{3596174} = "Draganovo\,\ V\.\ Tarnovo";
$areanames{en}->{3596175} = "Parvomaytsi";
$areanames{en}->{3596176} = "Polikraishte";
$areanames{en}->{3596177} = "Yantra\,\ V\.\ Tarnovo";
$areanames{en}->{3596178} = "Strelets\,\ V\.\ Tarnovo";
$areanames{en}->{3596179} = "Krusheto";
$areanames{en}->{359618} = "Gorna\ Oryahovitsa";
$areanames{en}->{359619} = "Lyaskovets\,\ V\.\ Tarnovo";
$areanames{en}->{35962} = "Veliko\ Tarnovo";
$areanames{en}->{359631} = "Svishtov";
$areanames{en}->{35963202} = "Dragomirovo\,\ V\.\ Tarnovo";
$areanames{en}->{35963203} = "Hadzhidimitrovo\,\ V\.\ Tarnovo";
$areanames{en}->{35963204} = "Delyanovtsi";
$areanames{en}->{35963205} = "Chervena";
$areanames{en}->{3596321} = "Gorna\ Studena";
$areanames{en}->{3596322} = "Alekovo\,\ V\.\ Tarnovo";
$areanames{en}->{3596323} = "Balgarsko\ slivovo";
$areanames{en}->{3596324} = "Vardim";
$areanames{en}->{3596325} = "Kozlovets";
$areanames{en}->{3596326} = "Morava";
$areanames{en}->{3596327} = "Ovcha\ mogila";
$areanames{en}->{3596328} = "Oresh";
$areanames{en}->{3596329} = "Tsarevets\,\ V\.\ Tarnovo";
$areanames{en}->{3596352} = "Dolni\ Lukovit";
$areanames{en}->{35963560} = "Radishevo";
$areanames{en}->{35963561} = "Grivitsa";
$areanames{en}->{35963562} = "Komarevo\,\ Pleven";
$areanames{en}->{35963563} = "Borislav";
$areanames{en}->{35963564} = "Bivolare";
$areanames{en}->{35963565} = "Mechka\,\ Pleven";
$areanames{en}->{35963566} = "Brashlyanitsa";
$areanames{en}->{35963567} = "Gradina\,\ Pleven";
$areanames{en}->{35963568} = "Bukovlak";
$areanames{en}->{35963569} = "Kamenets\,\ Pleven";
$areanames{en}->{35963570} = "Staroseltsi";
$areanames{en}->{35963571} = "Brestovets";
$areanames{en}->{35963572} = "Yasen\,\ Pleven";
$areanames{en}->{35963573} = "Disevitsa";
$areanames{en}->{35963574} = "Todorovo\,\ Pleven";
$areanames{en}->{35963575} = "Bohot";
$areanames{en}->{35963576} = "Tuchenitsa";
$areanames{en}->{35963577} = "Pelishat";
$areanames{en}->{35963578} = "Opanets\,\ Pleven";
$areanames{en}->{35963579} = "Ralevo";
$areanames{en}->{3596359} = "Glava";
$areanames{en}->{35964} = "Pleven";
$areanames{en}->{359650} = "Levski\,\ Pleven";
$areanames{en}->{3596510} = "Totleben";
$areanames{en}->{3596511} = "Pobeda\,\ Pleven";
$areanames{en}->{3596512} = "Gorni\ Dabnik";
$areanames{en}->{3596513} = "Pordim";
$areanames{en}->{3596514} = "Dolni\ Dabnik";
$areanames{en}->{3596515} = "Slavyanovo\,\ Pleven";
$areanames{en}->{3596516} = "Iskar\,\ Pleven";
$areanames{en}->{35965165} = "Pisarovo\,\ Pleven";
$areanames{en}->{3596517} = "Podem";
$areanames{en}->{3596518} = "Riben";
$areanames{en}->{3596519} = "Beglezh";
$areanames{en}->{3596520} = "Nikolaevo\,\ Pleven";
$areanames{en}->{3596521} = "Sadovets";
$areanames{en}->{3596522} = "Zgalevo";
$areanames{en}->{3596523} = "Krushovitsa\,\ Pleven";
$areanames{en}->{3596524} = "Petarnitsa";
$areanames{en}->{3596525} = "Barkach";
$areanames{en}->{3596526} = "Varbitsa\,\ Pleven";
$areanames{en}->{3596527} = "Odarne";
$areanames{en}->{3596528} = "Valchitran";
$areanames{en}->{3596529} = "Koilovtsi";
$areanames{en}->{3596530} = "Tranchovitsa";
$areanames{en}->{3596531} = "Izgrev\,\ Pleven";
$areanames{en}->{3596532} = "Balgarene\,\ Pleven";
$areanames{en}->{3596533} = "Stezherovo";
$areanames{en}->{3596534} = "Malchika";
$areanames{en}->{3596535} = "Kozar\ Belene";
$areanames{en}->{3596536} = "Asparuhovo\,\ Pleven";
$areanames{en}->{3596537} = "Asenovtsi";
$areanames{en}->{3596538} = "Obnova";
$areanames{en}->{3596539} = "Gradishte\,\ Pleven";
$areanames{en}->{3596540} = "Asenovo\,\ Pleven";
$areanames{en}->{3596541} = "Nikopol";
$areanames{en}->{3596542} = "Vabel\,\ Pleven";
$areanames{en}->{3596543} = "Muselievo";
$areanames{en}->{3596544} = "Novachene\,\ Pleven";
$areanames{en}->{3596545} = "Lyubenovo\,\ Pleven";
$areanames{en}->{3596546} = "Lozitsa\,\ Pleven";
$areanames{en}->{3596547} = "Dragash\ voyvoda";
$areanames{en}->{3596548} = "Debovo";
$areanames{en}->{3596549} = "Sanadinovo";
$areanames{en}->{3596550} = "Stavertsi";
$areanames{en}->{3596551} = "Trastenik\,\ Pleven";
$areanames{en}->{3596552} = "Dolna\ Mitropolia";
$areanames{en}->{3596553} = "Oryahovitsa\,\ Pleven";
$areanames{en}->{3596554} = "Krushovene";
$areanames{en}->{3596555} = "Baykal";
$areanames{en}->{3596556} = "Gorna\ Mitropolia";
$areanames{en}->{3596557} = "Bregare";
$areanames{en}->{3596558} = "Slavovitsa\,\ Pleven";
$areanames{en}->{3596559} = "Gostilya";
$areanames{en}->{3596560} = "Kreta\,\ Pleven";
$areanames{en}->{3596561} = "Gulyantsi";
$areanames{en}->{35965617} = "Iskar\,\ Pleven";
$areanames{en}->{3596562} = "Gigen";
$areanames{en}->{3596563} = "Brest\,\ Pleven";
$areanames{en}->{3596564} = "Zagrazhden\,\ Pleven";
$areanames{en}->{3596565} = "Milkovitsa";
$areanames{en}->{3596566} = "Dolni\ Vit";
$areanames{en}->{3596567} = "Somovit";
$areanames{en}->{3596568} = "Dabovan";
$areanames{en}->{3596569} = "Lenkovo";
$areanames{en}->{3596570} = "Deventsi";
$areanames{en}->{3596571} = "Lepitsa";
$areanames{en}->{3596572} = "Suhache";
$areanames{en}->{3596573} = "Koynare";
$areanames{en}->{3596574} = "Chomakovtsi";
$areanames{en}->{3596575} = "Telish";
$areanames{en}->{3596576} = "Radomirtsi";
$areanames{en}->{3596577} = "Breste";
$areanames{en}->{3596578} = "Reselets";
$areanames{en}->{3596579} = "Ruptsi\,\ Pleven";
$areanames{en}->{3596580} = "Tatari";
$areanames{en}->{3596581} = "Byala\ voda\,\ Pleven";
$areanames{en}->{3596582} = "Belene";
$areanames{en}->{3596583} = "Belene";
$areanames{en}->{3596584} = "Belene";
$areanames{en}->{3596585} = "Belene";
$areanames{en}->{3596586} = "Belene";
$areanames{en}->{3596587} = "Petokladentsi";
$areanames{en}->{3596588} = "Dekov";
$areanames{en}->{3596589} = "Kulina\ voda";
$areanames{en}->{359659} = "Cherven\ bryag";
$areanames{en}->{3596590} = "Rakita\,\ Pleven";
$areanames{en}->{3596591} = "Gornik";
$areanames{en}->{35966} = "Gabrovo";
$areanames{en}->{359670} = "Troyan\,\ Lovech";
$areanames{en}->{3596710} = "Donino";
$areanames{en}->{3596711} = "Kozi\ rog";
$areanames{en}->{3596712} = "Gabene";
$areanames{en}->{3596713} = "Vranilovtsi";
$areanames{en}->{3596714} = "Popovtsi";
$areanames{en}->{3596716} = "Zhaltesh";
$areanames{en}->{3596717} = "Lesicharka";
$areanames{en}->{3596718} = "Draganovtsi";
$areanames{en}->{35967193} = "Kmetovtsi";
$areanames{en}->{35967194} = "Grablevtsi";
$areanames{en}->{3596720} = "Kereka";
$areanames{en}->{3596722} = "Sokolovo\,\ Gabr\.";
$areanames{en}->{3596723} = "Tsareva\ livada";
$areanames{en}->{3596724} = "Yantra\,\ Gabr\.";
$areanames{en}->{3596725} = "Gostilitsa";
$areanames{en}->{3596726} = "Skalsko";
$areanames{en}->{3596727} = "Ganchovets";
$areanames{en}->{3596728} = "Burya";
$areanames{en}->{35967301} = "Idilevo";
$areanames{en}->{35967302} = "Kravenik";
$areanames{en}->{35967303} = "Batoshevo";
$areanames{en}->{35967304} = "Kramolin";
$areanames{en}->{35967305} = "Stokite";
$areanames{en}->{35967306} = "Gradishte\,\ Gabr\.";
$areanames{en}->{35967307} = "Mlechevo";
$areanames{en}->{35967308} = "Lovnidol";
$areanames{en}->{35967309} = "Agatovo";
$areanames{en}->{3596732} = "Sennik";
$areanames{en}->{3596733} = "Kormyansko";
$areanames{en}->{3596734} = "Petko\ Slaveykov";
$areanames{en}->{3596736} = "Gradnitsa\,\ Gabr\.";
$areanames{en}->{3596737} = "Krushevo\,\ Gabr\.";
$areanames{en}->{3596738} = "Dobromirka";
$areanames{en}->{35967390} = "Shumata";
$areanames{en}->{35967391} = "Stolat";
$areanames{en}->{35967392} = "Yavorets";
$areanames{en}->{35967393} = "Dushevo";
$areanames{en}->{35967394} = "Bogatovo";
$areanames{en}->{35967395} = "Gorna\ Rositsa";
$areanames{en}->{35967396} = "Berievo";
$areanames{en}->{35967397} = "Ryahovtsite";
$areanames{en}->{35967398} = "Damyanovo";
$areanames{en}->{35967399} = "Malki\ Varshets";
$areanames{en}->{359675} = "Sevlievo";
$areanames{en}->{359676} = "Dryanovo\,\ Gabr\.";
$areanames{en}->{359677} = "Tryavna";
$areanames{en}->{3596770} = "Plachkovtsi";
$areanames{en}->{35967774} = "Belitsa\,\ Gabr\.";
$areanames{en}->{359678} = "Teteven";
$areanames{en}->{35968} = "Lovech";
$areanames{en}->{3596900} = "Vasilyovo";
$areanames{en}->{3596901} = "Glozhene\,\ Lovech";
$areanames{en}->{3596902} = "Ribaritsa\,\ Lovech";
$areanames{en}->{35969031} = "Galata";
$areanames{en}->{35969032} = "Balgarski\ izvor";
$areanames{en}->{3596905} = "Divchovoto";
$areanames{en}->{3596906} = "Cherni\ Vit";
$areanames{en}->{3596907} = "Gradezhnitsa";
$areanames{en}->{3596908} = "Glogovo";
$areanames{en}->{3596909} = "Malka\ Zhelyazna";
$areanames{en}->{3596910} = "Malinovo";
$areanames{en}->{3596911} = "Lisets\,\ Lovech";
$areanames{en}->{3596912} = "Bahovitsa";
$areanames{en}->{3596913} = "Slavyani";
$areanames{en}->{3596914} = "Slivek";
$areanames{en}->{3596915} = "Smochan";
$areanames{en}->{3596916} = "Brestovo\,\ Lovech";
$areanames{en}->{3596917} = "Balgarene\,\ Lovech";
$areanames{en}->{3596918} = "Drenov";
$areanames{en}->{3596919} = "Slatina\,\ Lovech";
$areanames{en}->{3596920} = "Lesidren";
$areanames{en}->{3596921} = "Ablanitsa\,\ Lovech";
$areanames{en}->{3596922} = "Leshnitsa\,\ Lovech";
$areanames{en}->{3596923} = "Goran";
$areanames{en}->{35969240} = "Hlevene";
$areanames{en}->{35969241} = "Yoglav";
$areanames{en}->{35969242} = "Presyaka";
$areanames{en}->{35969243} = "Kazachevo";
$areanames{en}->{35969244} = "Tepava";
$areanames{en}->{35969245} = "Devetaki";
$areanames{en}->{35969247} = "Gostinya";
$areanames{en}->{35969248} = "Skobelevo\,\ Lovech";
$areanames{en}->{35969249} = "Doyrentsi";
$areanames{en}->{3596925} = "Vladinya";
$areanames{en}->{3596926} = "Gorno\ Pavlikene";
$areanames{en}->{3596927} = "Umarevtsi";
$areanames{en}->{3596928} = "Kakrina";
$areanames{en}->{3596929} = "Radyuvene";
$areanames{en}->{3596930} = "Slavshtitsa";
$areanames{en}->{3596931} = "Ugarchin";
$areanames{en}->{3596932} = "Mikre";
$areanames{en}->{3596933} = "Golets";
$areanames{en}->{3596934} = "Katunets";
$areanames{en}->{3596935} = "Sopot\,\ Lovech";
$areanames{en}->{3596937} = "Sokolovo\,\ Lovech";
$areanames{en}->{3596938} = "Kalenik\,\ Lovech";
$areanames{en}->{3596939} = "Dragana";
$areanames{en}->{3596941} = "Letnitsa";
$areanames{en}->{3596942} = "Aleksandrovo\,\ Lovech";
$areanames{en}->{3596943} = "Gorsko\ Slivovo";
$areanames{en}->{3596944} = "Krushuna";
$areanames{en}->{3596946} = "Chavdartsi";
$areanames{en}->{3596948} = "Karpachevo";
$areanames{en}->{3596950} = "Gumoshtnik";
$areanames{en}->{3596952} = "Oreshak\,\ Lovech";
$areanames{en}->{3596953} = "Borima";
$areanames{en}->{3596954} = "Vrabevo";
$areanames{en}->{3596955} = "Dalbok\ dol";
$areanames{en}->{3596956} = "Lomets\,\ Lovech";
$areanames{en}->{3596957} = "Golyama\ Zhelyazna";
$areanames{en}->{3596958} = "Apriltsi\,\ Lovech";
$areanames{en}->{3596959} = "Debnevo";
$areanames{en}->{3596960} = "Belish";
$areanames{en}->{35969612} = "Terziysko\,\ Lovech";
$areanames{en}->{35969613} = "Chiflik\,\ Lovech";
$areanames{en}->{35969614} = "Gorno\ trape";
$areanames{en}->{35969615} = "Balabansko";
$areanames{en}->{35969616} = "Staro\ selo\,\ Lovech";
$areanames{en}->{3596962} = "Cherni\ Osam";
$areanames{en}->{3596963} = "Balkanets";
$areanames{en}->{3596964} = "Velchevo\,\ Lovech";
$areanames{en}->{3596965} = "Beli\ Osam";
$areanames{en}->{3596966} = "Shipkovo";
$areanames{en}->{3596967} = "Kaleytsa";
$areanames{en}->{3596968} = "Dobrodan";
$areanames{en}->{3596969} = "Beklemeto";
$areanames{en}->{359697} = "Lukovit";
$areanames{en}->{3596980} = "Belentsi";
$areanames{en}->{3596981} = "Petrevene";
$areanames{en}->{3596982} = "aglen";
$areanames{en}->{3596983} = "Dermantsi";
$areanames{en}->{3596984} = "Bezhanovo\,\ Lovech";
$areanames{en}->{3596985} = "Rumyantsevo";
$areanames{en}->{3596986} = "Daben";
$areanames{en}->{3596987} = "Karlukovo";
$areanames{en}->{3596988} = "Peshterna";
$areanames{en}->{3596989} = "Toros";
$areanames{en}->{3596990} = "Malak\ izvor\,\ Lovech";
$areanames{en}->{3596991} = "Yablanitsa";
$areanames{en}->{3596992} = "Zlatna\ Panega";
$areanames{en}->{3596994} = "Brestnitsa\,\ Lovech";
$areanames{en}->{3596997} = "Dobrevtsi\,\ Lovech";
$areanames{en}->{3596998} = "Golyam\ izvor\,\ Lovech";
$areanames{en}->{359701} = "Dupnitsa";
$areanames{en}->{359702} = "Bobov\ dol";
$areanames{en}->{3597030} = "Resilovo";
$areanames{en}->{3597031} = "Gorna\ Koznitsa";
$areanames{en}->{3597032} = "Yahinovo";
$areanames{en}->{3597033} = "Kraynitsi";
$areanames{en}->{3597034} = "Dzherman";
$areanames{en}->{3597035} = "Cherven\ breg";
$areanames{en}->{3597036} = "Balanovo";
$areanames{en}->{3597039} = "Samoranovo";
$areanames{en}->{3597041} = "Shatrovo";
$areanames{en}->{3597042} = "Korkina";
$areanames{en}->{3597043} = "Golemo\ selo";
$areanames{en}->{3597044} = "Babino";
$areanames{en}->{3597045} = "Golem\ Varbovnik";
$areanames{en}->{3597046} = "Boboshevo";
$areanames{en}->{3597047} = "Usoyka";
$areanames{en}->{3597048} = "Blazhievo";
$areanames{en}->{3597052} = "Pastra";
$areanames{en}->{3597053} = "Kocherinovo";
$areanames{en}->{3597054} = "Rila";
$areanames{en}->{3597056} = "Mursalevo";
$areanames{en}->{3597057} = "Malo\ selo";
$areanames{en}->{3597058} = "Stob";
$areanames{en}->{359707} = "Sapareva\ banya";
$areanames{en}->{3597102} = "Lopyan";
$areanames{en}->{3597103} = "Brusen\,\ Sofia";
$areanames{en}->{3597104} = "Laga";
$areanames{en}->{3597105} = "Malki\ Iskar";
$areanames{en}->{3597106} = "Yamna";
$areanames{en}->{3597110} = "Opitsvet";
$areanames{en}->{3597116} = "Petarch";
$areanames{en}->{3597117} = "Gradets\,\ Sofia";
$areanames{en}->{3597118} = "Dragovishtitsa\,\ Sofia";
$areanames{en}->{3597119} = "Dramsha";
$areanames{en}->{3597120} = "Dolna\ banya";
$areanames{en}->{35971220} = "Gutsal";
$areanames{en}->{35971221} = "Yarlovo";
$areanames{en}->{35971224} = "Shipochane";
$areanames{en}->{35971225} = "Novo\ selo\,\ Sofia";
$areanames{en}->{35971227} = "Beli\ Iskar";
$areanames{en}->{35971228} = "Maritsa";
$areanames{en}->{3597123} = "Kovachevtsi\,\ Sofia";
$areanames{en}->{3597124} = "Belchinski\ bani";
$areanames{en}->{3597125} = "Govedartsi";
$areanames{en}->{3597126} = "Gorni\ Okol";
$areanames{en}->{3597127} = "Shiroki\ dol";
$areanames{en}->{3597129} = "Raduil";
$areanames{en}->{35971302} = "Bozhenitsa";
$areanames{en}->{35971304} = "Lipnitsa\,\ Sofia";
$areanames{en}->{35971306} = "Rashkovo";
$areanames{en}->{3597132} = "Radotina";
$areanames{en}->{3597133} = "Pravets";
$areanames{en}->{35971337} = "Kalugerovo\,\ Sofia";
$areanames{en}->{35971338} = "Osikovska\ Lakavitsa";
$areanames{en}->{3597134} = "Vrachesh";
$areanames{en}->{3597135} = "Trudovets";
$areanames{en}->{3597136} = "Novachene\,\ Sofia";
$areanames{en}->{3597137} = "Skravena";
$areanames{en}->{3597138} = "Litakovo";
$areanames{en}->{3597139} = "Dzhurovo";
$areanames{en}->{35971398} = "Osikovitsa";
$areanames{en}->{3597142} = "Kostenets";
$areanames{en}->{3597143} = "Vakarel";
$areanames{en}->{3597144} = "Kostenets";
$areanames{en}->{3597145} = "Mirovo\,\ Sofia";
$areanames{en}->{3597146} = "Chernyovo";
$areanames{en}->{3597147} = "Pchelin\,\ Sofia";
$areanames{en}->{35971471} = "Ochusha";
$areanames{en}->{3597148} = "Muhovo";
$areanames{en}->{3597149} = "Zhivkovo\,\ Sofia";
$areanames{en}->{35971502} = "Eleshnitsa\,\ Sofia";
$areanames{en}->{35971503} = "Dolno\ Kamartsi";
$areanames{en}->{35971504} = "Belopoptsi";
$areanames{en}->{35971505} = "Churek";
$areanames{en}->{35971506} = "Gabra";
$areanames{en}->{3597152} = "Gorna\ Malina";
$areanames{en}->{3597154} = "Stolnik";
$areanames{en}->{3597155} = "Lesnovo";
$areanames{en}->{3597156} = "Ravno\ pole";
$areanames{en}->{3597157} = "Sarantsi";
$areanames{en}->{3597158} = "Doganovo";
$areanames{en}->{35971587} = "Golema\ Rakovitsa";
$areanames{en}->{3597159} = "Aprilovo\,\ Sofia";
$areanames{en}->{3597162} = "Lakatnik";
$areanames{en}->{3597163} = "Iskrets";
$areanames{en}->{3597164} = "Rebrovo";
$areanames{en}->{3597165} = "Milanovo\,\ Sofia";
$areanames{en}->{3597166} = "Vlado\ Trichkov";
$areanames{en}->{3597167} = "Tserovo\,\ Sofia";
$areanames{en}->{3597168} = "Bov";
$areanames{en}->{3597169} = "Tompsan";
$areanames{en}->{3597172} = "Dragoman";
$areanames{en}->{3597174} = "Kalotina";
$areanames{en}->{3597175} = "Gaber";
$areanames{en}->{3597176} = "Hrabarsko";
$areanames{en}->{3597177} = "Aldomirovtsi";
$areanames{en}->{3597178} = "Prolesha";
$areanames{en}->{3597179} = "Golemo\ Malovo";
$areanames{en}->{35971798} = "Vasilovtsi\,Sof\.";
$areanames{en}->{3597181} = "Pirdop";
$areanames{en}->{3597182} = "Mirkovo";
$areanames{en}->{3597183} = "Dushantsi";
$areanames{en}->{3597184} = "Koprivshtitsa";
$areanames{en}->{3597185} = "Chelopech";
$areanames{en}->{3597186} = "Anton";
$areanames{en}->{3597187} = "Bunovo\,\ Sofia";
$areanames{en}->{3597188} = "Petrich\,\ Sofia";
$areanames{en}->{3597189} = "Chavdar\,\ Sofia";
$areanames{en}->{3597192} = "Gintsi";
$areanames{en}->{3597193} = "Golesh\,\ Sofia";
$areanames{en}->{359720} = "Etropole";
$areanames{en}->{359721} = "Kostinbrod";
$areanames{en}->{359722} = "Samokov";
$areanames{en}->{359723} = "Botevgrad";
$areanames{en}->{359724} = "Ihtiman";
$areanames{en}->{359725} = "Elin\ Pelin";
$areanames{en}->{359726} = "Svoge";
$areanames{en}->{359727} = "Slivnitsa\,\ Sofia";
$areanames{en}->{359728} = "Zlatitsa";
$areanames{en}->{359729} = "Godech";
$areanames{en}->{35973} = "Blagoevgrad";
$areanames{en}->{3597415} = "Selishte\,\ Blag\.";
$areanames{en}->{35974201} = "Kapatovo";
$areanames{en}->{35974202} = "Klyuch";
$areanames{en}->{35974203} = "Rupite";
$areanames{en}->{35974204} = "Gega";
$areanames{en}->{35974207} = "General\ Todorov";
$areanames{en}->{3597422} = "Topolnitsa\,\ Blag\.";
$areanames{en}->{3597423} = "Kolarovo\,\ Blag\.";
$areanames{en}->{3597424} = "Karnalovo";
$areanames{en}->{3597425} = "Kulata";
$areanames{en}->{3597426} = "Marikostinovo";
$areanames{en}->{3597427} = "Parvomay\,\ Blag\.";
$areanames{en}->{3597428} = "Gabrene";
$areanames{en}->{3597430} = "Damyanitsa";
$areanames{en}->{35974321} = "Harsovo\,\ Blag\.";
$areanames{en}->{35974322} = "Petrovo\,\ Blag\.";
$areanames{en}->{35974323} = "Lozenitsa";
$areanames{en}->{35974324} = "Struma";
$areanames{en}->{35974325} = "Lilyanovo";
$areanames{en}->{35974327} = "Novo\ Delchevo";
$areanames{en}->{3597433} = "Kresna";
$areanames{en}->{3597434} = "Strumyani";
$areanames{en}->{35974346} = "Tsaparevo";
$areanames{en}->{35974347} = "Razdol";
$areanames{en}->{35974348} = "Igralishte";
$areanames{en}->{3597435} = "Sklave";
$areanames{en}->{3597436} = "Levunovo";
$areanames{en}->{3597437} = "Melnik";
$areanames{en}->{3597438} = "Katuntsi";
$areanames{en}->{35974386} = "Pirin";
$areanames{en}->{35974388} = "Gorno\ Spanchevo";
$areanames{en}->{3597439} = "Ploski";
$areanames{en}->{35974401} = "Gorno\ Draglishte";
$areanames{en}->{35974402} = "Godlevo";
$areanames{en}->{35974403} = "Dolno\ Draglishte";
$areanames{en}->{35974404} = "Babyak";
$areanames{en}->{35974405} = "Kraishte\,\ Blag\.";
$areanames{en}->{35974406} = "Dobarsko";
$areanames{en}->{35974407} = "Kremen\,\ Blag\.";
$areanames{en}->{35974408} = "Obidim";
$areanames{en}->{35974409} = "Mesta";
$areanames{en}->{3597442} = "Yakoruda";
$areanames{en}->{3597444} = "Belitsa\,\ Blag\.";
$areanames{en}->{3597445} = "Banya\,\ Blag\.";
$areanames{en}->{3597446} = "Eleshnitsa\,\ Blag\.";
$areanames{en}->{3597447} = "Dobrinishte";
$areanames{en}->{3597448} = "Bachevo";
$areanames{en}->{35974495} = "Yurukovo";
$areanames{en}->{35974496} = "Filipovo\,\ Blag\.";
$areanames{en}->{359745} = "Petrich\,\ Blag\.";
$areanames{en}->{359746} = "Sandanski";
$areanames{en}->{359747} = "Razlog";
$areanames{en}->{359748} = "Simitli";
$areanames{en}->{359749} = "Bansko";
$areanames{en}->{359750} = "Borovets\,\ Sofia";
$areanames{en}->{359751} = "Gotse\ Delchev";
$areanames{en}->{3597520} = "Kornitsa";
$areanames{en}->{3597521} = "Koprivlen";
$areanames{en}->{35975214} = "Gaytaninovo";
$areanames{en}->{35975215} = "Teshovo";
$areanames{en}->{3597522} = "Dabnitsa";
$areanames{en}->{3597523} = "Garmen";
$areanames{en}->{3597524} = "Ablanitsa\,\ Blag\.";
$areanames{en}->{3597525} = "Banichan";
$areanames{en}->{3597526} = "Ribnovo";
$areanames{en}->{3597527} = "Gorno\ Dryanovo";
$areanames{en}->{3597528} = "Hadzhidimovo";
$areanames{en}->{3597529} = "Breznitsa";
$areanames{en}->{3597531} = "Dolno\ Dryanovo";
$areanames{en}->{3597532} = "Bukovo\,\ Blag\.";
$areanames{en}->{3597533} = "Osikovo\,\ Blag\.";
$areanames{en}->{3597541} = "Satovcha";
$areanames{en}->{3597544} = "Osina";
$areanames{en}->{3597545} = "Kochan";
$areanames{en}->{3597546} = "Slashten";
$areanames{en}->{3597547} = "Valkosel";
$areanames{en}->{3597548} = "Godeshevo";
$areanames{en}->{3597549} = "Dolen\,\ Blag\.";
$areanames{en}->{35976} = "Pernik";
$areanames{en}->{3597711} = "Kladnitsa";
$areanames{en}->{3597712} = "Batanovtsi";
$areanames{en}->{3597713} = "Rudartsi";
$areanames{en}->{3597714} = "Meshtitsa";
$areanames{en}->{3597715} = "Studena\,\ Pernik";
$areanames{en}->{3597717} = "Divotino";
$areanames{en}->{3597718} = "Dragichevo";
$areanames{en}->{3597719} = "Yardzhilovtsi";
$areanames{en}->{3597720} = "Priboy";
$areanames{en}->{35977221} = "Kondofrey";
$areanames{en}->{35977222} = "Gorna\ Dikanya";
$areanames{en}->{35977226} = "Debeli\ lag";
$areanames{en}->{35977229} = "Galabnik";
$areanames{en}->{3597723} = "Dolni\ Rakovets";
$areanames{en}->{3597724} = "Izvor\,\ Pernik";
$areanames{en}->{3597725} = "Klenovik";
$areanames{en}->{3597726} = "Dren";
$areanames{en}->{3597727} = "Kovachevtsi\,\ Pernik";
$areanames{en}->{3597728} = "Drugan";
$areanames{en}->{3597729} = "Dolna\ Dikanya";
$areanames{en}->{3597731} = "Tran";
$areanames{en}->{3597732} = "Vukan";
$areanames{en}->{3597733} = "Filipovtsi";
$areanames{en}->{3597734} = "Glavanovtsi\,\ Pernik";
$areanames{en}->{3597735} = "Leva\ reka";
$areanames{en}->{3597741} = "Zemen";
$areanames{en}->{3597742} = "Kalishte";
$areanames{en}->{3597743} = "Divlya";
$areanames{en}->{3597744} = "Elovdol\,\ Pernik";
$areanames{en}->{3597745} = "Egalnitsa";
$areanames{en}->{3597751} = "Breznik";
$areanames{en}->{3597752} = "Rezhantsi";
$areanames{en}->{3597753} = "Noevtsi";
$areanames{en}->{3597754} = "Kosharevo";
$areanames{en}->{3597755} = "Velkovtsi\,\ Pernik";
$areanames{en}->{359777} = "Radomir";
$areanames{en}->{35978} = "Kyustendil";
$areanames{en}->{3597910} = "Bersin";
$areanames{en}->{3597911} = "Granitsa";
$areanames{en}->{3597912} = "Gorna\ Grashtitsa";
$areanames{en}->{3597913} = "Rashka\ Grashtitsa";
$areanames{en}->{3597914} = "Vaksevo";
$areanames{en}->{3597915} = "Nevestino\,\ Kyust\.";
$areanames{en}->{3597916} = "Bagrentsi";
$areanames{en}->{3597917} = "Tavalichevo";
$areanames{en}->{3597918} = "Yabalkovo\,\ Kyust\.";
$areanames{en}->{3597920} = "Skrinyano";
$areanames{en}->{3597921} = "Zhilentsi";
$areanames{en}->{3597922} = "Dragovishtitsa\,\ Kyust\.";
$areanames{en}->{3597923} = "Vrattsa";
$areanames{en}->{3597924} = "Shishkovtsi";
$areanames{en}->{3597925} = "Gyueshevo";
$areanames{en}->{3597926} = "Konyavo";
$areanames{en}->{3597927} = "Treklyano";
$areanames{en}->{3597928} = "Garlyano";
$areanames{en}->{3597929} = "Sovolyano";
$areanames{en}->{3597930} = "Eremia";
$areanames{en}->{3597932} = "Shipochano";
$areanames{en}->{3597933} = "Gramazhdano";
$areanames{en}->{3597934} = "Bunovo\,\ Kyust\.";
$areanames{en}->{3597935} = "Dolno\ selo";
$areanames{en}->{3597936} = "Slokoshtitsa";
$areanames{en}->{3597937} = "Razhdavitsa";
$areanames{en}->{3597938} = "Dolno\ Uyno";
$areanames{en}->{3597939} = "Tsarvaritsa";
$areanames{en}->{3598111} = "Shtraklevo";
$areanames{en}->{3598113} = "Novo\ selo\,\ Ruse";
$areanames{en}->{3598114} = "Pirgovo";
$areanames{en}->{3598115} = "Chervena\ voda";
$areanames{en}->{3598116} = "Ivanovo\,\ Ruse";
$areanames{en}->{3598117} = "Marten";
$areanames{en}->{3598118} = "Nikolovo\,\ Ruse";
$areanames{en}->{3598122} = "Tsenovo\,\ Ruse";
$areanames{en}->{3598123} = "Bosilkovtsi";
$areanames{en}->{3598124} = "Novgrad";
$areanames{en}->{3598125} = "Koprivets";
$areanames{en}->{35981262} = "Bistrentsi";
$areanames{en}->{35981264} = "Piperkovo";
$areanames{en}->{35981266} = "Starmen\,\ Ruse";
$areanames{en}->{35981268} = "Krivina\,\ Ruse";
$areanames{en}->{3598127} = "Karamanovo";
$areanames{en}->{3598128} = "Polsko\ Kosovo";
$areanames{en}->{3598129} = "Lom\ Cherkovna";
$areanames{en}->{3598131} = "Borisovo\,\ Ruse";
$areanames{en}->{3598132} = "Yudelnik";
$areanames{en}->{3598133} = "Ryahovo";
$areanames{en}->{3598134} = "Malko\ Vranovo";
$areanames{en}->{3598135} = "Babovo";
$areanames{en}->{3598136} = "Stambolovo\,\ Ruse";
$areanames{en}->{3598137} = "Golyamo\ Vranovo";
$areanames{en}->{3598138} = "Brashlen";
$areanames{en}->{3598140} = "Borovo\,\ Ruse";
$areanames{en}->{3598141} = "Dve\ mogili";
$areanames{en}->{3598142} = "Bazovets\,\ Ruse";
$areanames{en}->{3598143} = "Obretenik";
$areanames{en}->{3598144} = "Batishnitsa";
$areanames{en}->{3598145} = "Trastenik\,\ Ruse";
$areanames{en}->{35981461} = "Karan\ Varbovka";
$areanames{en}->{35981462} = "Volovo";
$areanames{en}->{35981463} = "Mogilino";
$areanames{en}->{35981464} = "Ostritsa\,\ Ruse";
$areanames{en}->{35981465} = "Batin";
$areanames{en}->{35981466} = "Pomen";
$areanames{en}->{3598147} = "Baniska";
$areanames{en}->{3598148} = "Gorno\ Ablanovo";
$areanames{en}->{3598149} = "Katselovo";
$areanames{en}->{3598150} = "Semerdzhievo";
$areanames{en}->{3598151} = "Prosena";
$areanames{en}->{3598152} = "Krasen\,\ Ruse";
$areanames{en}->{3598156} = "Cherven\,\ Ruse";
$areanames{en}->{3598158} = "Mechka\,\ Ruse";
$areanames{en}->{3598159} = "Koshov";
$areanames{en}->{3598161} = "Vetovo";
$areanames{en}->{3598163} = "Bazan";
$areanames{en}->{3598164} = "Pisanets";
$areanames{en}->{3598165} = "Smirnenski\,\ Ruse";
$areanames{en}->{3598166} = "Svalenik";
$areanames{en}->{3598167} = "Tserovets";
$areanames{en}->{359817} = "Byala\,\ Ruse";
$areanames{en}->{3598184} = "Glodzhevo";
$areanames{en}->{3598185} = "Senovo";
$areanames{en}->{3598187} = "Tetovo";
$areanames{en}->{35981886} = "Chereshovo\,\ Ruse";
$areanames{en}->{3598192} = "Hotantsa";
$areanames{en}->{3598194} = "Sandrovo";
$areanames{en}->{3598196} = "Nisovo";
$areanames{en}->{35982} = "Ruse";
$areanames{en}->{35984} = "Razgrad";
$areanames{en}->{3598424} = "Tsar\ Kaloyan\,\ Razgrad";
$areanames{en}->{35984266} = "Prostorno";
$areanames{en}->{35984269} = "Nedoklan";
$areanames{en}->{3598431} = "Isperih";
$areanames{en}->{35984392} = "Belintsi";
$areanames{en}->{35984393} = "Vazovo";
$areanames{en}->{35984394} = "Duhovets";
$areanames{en}->{3598442} = "Zavet\,\ Razgrad";
$areanames{en}->{3598445} = "Yuper";
$areanames{en}->{35984462} = "Ostrovo";
$areanames{en}->{35984463} = "Prelez";
$areanames{en}->{35984464} = "Veselets\,\ Razgrad";
$areanames{en}->{35984465} = "Savin";
$areanames{en}->{35984466} = "Zvanartsi";
$areanames{en}->{35984467} = "Seslav";
$areanames{en}->{35984469} = "Bozhurovo\,\ Razgrad";
$areanames{en}->{3598448} = "Terter";
$areanames{en}->{35984710} = "Osenets";
$areanames{en}->{35984711} = "Mortagonovo";
$areanames{en}->{35984712} = "Kostandenets";
$areanames{en}->{35984713} = "Blagoevo\,\ Razgrad";
$areanames{en}->{35984717} = "Pobit\ kamak\,\ Razgrad";
$areanames{en}->{35984718} = "Dryanovets\,\ Razgrad";
$areanames{en}->{35984719} = "Balkanski";
$areanames{en}->{35984720} = "Topchii";
$areanames{en}->{35984721} = "Lipnik";
$areanames{en}->{35984722} = "Yasenovets";
$areanames{en}->{35984723} = "Dyankovo";
$areanames{en}->{35984725} = "Kichenitsa";
$areanames{en}->{35984726} = "Ushintsi";
$areanames{en}->{35984727} = "Kamenovo\,\ Razgrad";
$areanames{en}->{35984728} = "Rakovski\,\ Razgrad";
$areanames{en}->{35984729} = "Ezerche";
$areanames{en}->{35984730} = "Golyam\ Porovets";
$areanames{en}->{35984732} = "Yonkovo";
$areanames{en}->{35984733} = "Ludogortsi";
$areanames{en}->{35984734} = "Todorovo\,\ Razgrad";
$areanames{en}->{35984735} = "Sveshtari";
$areanames{en}->{35984736} = "Podayva";
$areanames{en}->{35984737} = "Raynino";
$areanames{en}->{35984738} = "Kitanchevo";
$areanames{en}->{35984740} = "Bisertsi";
$areanames{en}->{35984743} = "Brestovene";
$areanames{en}->{35984744} = "Belovets";
$areanames{en}->{35984745} = "Vladimirovtsi";
$areanames{en}->{35984749} = "Sevar";
$areanames{en}->{3598475} = "Loznitsa\,\ Razgrad";
$areanames{en}->{35984760} = "Trapishte";
$areanames{en}->{35984761} = "Gradina\,\ Razgrad";
$areanames{en}->{35984763} = "Beli\ Lom";
$areanames{en}->{35984764} = "Seydol";
$areanames{en}->{35984765} = "Veselina";
$areanames{en}->{35984766} = "Kamenar\,\ Razgrad";
$areanames{en}->{35984768} = "Sinya\ voda";
$areanames{en}->{35984769} = "Gorotsvet";
$areanames{en}->{3598477} = "Samuil";
$areanames{en}->{35984774} = "Golyam\ izvor\,\ Razgrad";
$areanames{en}->{35984776} = "Harsovo\,\ Razgrad";
$areanames{en}->{35984778} = "Bogdantsi\,\ Razgrad";
$areanames{en}->{35984779} = "Zdravets\,\ Razgrad";
$areanames{en}->{359848} = "Kubrat";
$areanames{en}->{359860} = "Silistra";
$areanames{en}->{359861} = "Silistra";
$areanames{en}->{3598620} = "Silistra";
$areanames{en}->{3598621} = "Silistra";
$areanames{en}->{3598622} = "Alekovo\,\ Silistra";
$areanames{en}->{3598623} = "Golesh\,\ Silistra";
$areanames{en}->{3598624} = "Kalipetrovo";
$areanames{en}->{3598625} = "Oven";
$areanames{en}->{3598626} = "Sredishte\,\ Silistra";
$areanames{en}->{3598627} = "Babuk";
$areanames{en}->{3598628} = "Tsar\ Asen\,\ Silistra";
$areanames{en}->{3598629} = "Smilets\,\ Silistra";
$areanames{en}->{3598630} = "Silistra";
$areanames{en}->{3598631} = "Silistra";
$areanames{en}->{3598632} = "Zafirovo";
$areanames{en}->{3598633} = "Staro\ selo\,\ Silistra";
$areanames{en}->{3598634} = "Nova\ Cherna";
$areanames{en}->{3598635} = "Tsar\ Samuil";
$areanames{en}->{3598636} = "Glavinitsa\,\ Silistra";
$areanames{en}->{3598637} = "Malak\ Preslavets";
$areanames{en}->{3598638} = "Bogdantsi\,\ Silistra";
$areanames{en}->{3598639} = "Kolarovo\,\ Silistra";
$areanames{en}->{3598640} = "Pravda\,\ Silistra";
$areanames{en}->{3598641} = "Okorsh";
$areanames{en}->{3598642} = "Dulovo";
$areanames{en}->{3598643} = "Zlatoklas";
$areanames{en}->{3598644} = "Chernolik";
$areanames{en}->{3598645} = "Mezhden";
$areanames{en}->{3598646} = "Vokil";
$areanames{en}->{3598647} = "Paisievo";
$areanames{en}->{3598648} = "Sekulovo";
$areanames{en}->{3598649} = "Yarebitsa";
$areanames{en}->{359865} = "Silistra";
$areanames{en}->{3598660} = "Tutrakan";
$areanames{en}->{3598661} = "Tutrakan";
$areanames{en}->{3598662} = "Dobrotitsa\,\ Silistra";
$areanames{en}->{3598663} = "Sitovo\,\ Silistra";
$areanames{en}->{3598664} = "Polyana\,\ Silistra";
$areanames{en}->{3598665} = "Iskra\,\ Silistra";
$areanames{en}->{3598666} = "Tutrakan";
$areanames{en}->{3598667} = "Belitsa\,\ Silistra";
$areanames{en}->{3598668} = "Popina";
$areanames{en}->{3598669} = "Garvan\,\ Silistra";
$areanames{en}->{3598670} = "Silistra";
$areanames{en}->{3598671} = "Silistra";
$areanames{en}->{3598672} = "Bradvari";
$areanames{en}->{3598673} = "Alfatar";
$areanames{en}->{3598674} = "Profesor\ Ishirkovo";
$areanames{en}->{3598675} = "Aydemir";
$areanames{en}->{3598676} = "Vetren\,\ Silistra";
$areanames{en}->{3598677} = "Srebarna";
$areanames{en}->{3598678} = "Sratsimir\,\ Silistra";
$areanames{en}->{3598679} = "Kaynardzha";
$areanames{en}->{359868} = "Silistra";
$areanames{en}->{3598690} = "Silistra";
$areanames{en}->{3598691} = "Silistra";
$areanames{en}->{3598692} = "Stefan\ Karadzha\,\ Silistra";
$areanames{en}->{3598693} = "Zvenimir";
$areanames{en}->{3598694} = "Zebil";
$areanames{en}->{3598695} = "Nozharevo";
$areanames{en}->{3598696} = "Suhodol\,\ Silistra";
$areanames{en}->{3598697} = "Sokol\,\ Silistra";
$areanames{en}->{3598698} = "Shumentsi";
$areanames{en}->{3598699} = "Tarnovtsi\,\ Silistra";
$areanames{en}->{359910} = "Mezdra";
$areanames{en}->{3599110} = "Virovsko";
$areanames{en}->{3599111} = "Chelopek";
$areanames{en}->{3599112} = "Banitsa";
$areanames{en}->{3599113} = "Mramoren";
$areanames{en}->{3599115} = "Chiren";
$areanames{en}->{3599116} = "Kostelevo";
$areanames{en}->{3599117} = "Krivodol";
$areanames{en}->{35991180} = "Lesura";
$areanames{en}->{35991182} = "Osen\,\ Vratsa";
$areanames{en}->{35991183} = "Furen";
$areanames{en}->{35991184} = "Rakevo";
$areanames{en}->{35991185} = "Pudria";
$areanames{en}->{35991186} = "Baurene";
$areanames{en}->{35991188} = "Galatin";
$areanames{en}->{35991189} = "Tri\ kladentsi";
$areanames{en}->{3599119} = "Tishevitsa";
$areanames{en}->{35991201} = "Lyuti\ brod";
$areanames{en}->{35991202} = "Kunino";
$areanames{en}->{35991203} = "Lik";
$areanames{en}->{3599121} = "Tsarevets\,\ Vratsa";
$areanames{en}->{3599122} = "Zverino";
$areanames{en}->{3599123} = "Roman";
$areanames{en}->{3599124} = "Tipchenitsa";
$areanames{en}->{3599125} = "Gorna\ Beshovitsa";
$areanames{en}->{3599126} = "Kameno\ pole";
$areanames{en}->{3599127} = "Lyutidol";
$areanames{en}->{3599128} = "Eliseyna";
$areanames{en}->{3599129} = "Sinyo\ bardo";
$areanames{en}->{3599130} = "Tlachene";
$areanames{en}->{3599131} = "Dobrolevo";
$areanames{en}->{3599132} = "Knezha";
$areanames{en}->{3599133} = "Komarevo\,\ Vratsa";
$areanames{en}->{3599134} = "Tarnak";
$areanames{en}->{3599135} = "Bardarski\ geran";
$areanames{en}->{3599136} = "Galiche";
$areanames{en}->{3599137} = "Popitsa";
$areanames{en}->{3599138} = "Altimir";
$areanames{en}->{3599139} = "Tarnava\,\ Vratsa";
$areanames{en}->{3599140} = "Gabare";
$areanames{en}->{35991401} = "Vranyak";
$areanames{en}->{3599141} = "Malorad";
$areanames{en}->{3599142} = "Lazarovo";
$areanames{en}->{3599143} = "Enitsa";
$areanames{en}->{3599144} = "Nivyanin";
$areanames{en}->{3599145} = "Brenitsa\,\ Vratsa";
$areanames{en}->{3599146} = "Sokolare";
$areanames{en}->{3599147} = "Borovan";
$areanames{en}->{3599148} = "Barkachevo";
$areanames{en}->{3599149} = "Bukovets\,\ Vratsa";
$areanames{en}->{359915} = "Byala\ Slatina";
$areanames{en}->{3599160} = "Glozhene\,\ Vratsa";
$areanames{en}->{3599161} = "Mizia";
$areanames{en}->{3599162} = "Mihaylovo\,\ Vratsa";
$areanames{en}->{3599163} = "Harlets";
$areanames{en}->{3599164} = "Krushovitsa\,\ Vratsa";
$areanames{en}->{3599165} = "Sofronievo";
$areanames{en}->{3599166} = "Hayredin";
$areanames{en}->{35991668} = "Manastirishte";
$areanames{en}->{3599167} = "Lipnitsa\,\ Vratsa";
$areanames{en}->{3599168} = "Butan";
$areanames{en}->{3599169} = "Rogozen";
$areanames{en}->{3599171} = "Oryahovo\,\ Vratsa";
$areanames{en}->{3599172} = "Selanovtsi";
$areanames{en}->{3599173} = "Galovo";
$areanames{en}->{3599174} = "Gorni\ Vadin";
$areanames{en}->{3599175} = "Ostrov";
$areanames{en}->{3599176} = "Leskovets\,\ Vratsa";
$areanames{en}->{3599180} = "Golyamo\ Peshtene";
$areanames{en}->{3599181} = "Kravoder";
$areanames{en}->{3599182} = "Devene";
$areanames{en}->{3599183} = "Lilyache";
$areanames{en}->{3599184} = "Ohoden";
$areanames{en}->{3599185} = "Beli\ Izvor";
$areanames{en}->{3599186} = "Zgorigrad";
$areanames{en}->{3599187} = "Lyutadzhik";
$areanames{en}->{3599188} = "Gorno\ Peshtene";
$areanames{en}->{35991888} = "Veslets\,\ Vratsa";
$areanames{en}->{3599189} = "Pavolche";
$areanames{en}->{35992} = "Vratsa";
$areanames{en}->{3599311} = "Kutovo";
$areanames{en}->{3599312} = "Bregovo\,\ Vidin";
$areanames{en}->{3599313} = "Kapitanovtsi";
$areanames{en}->{3599314} = "Dunavtsi\,\ Vidin";
$areanames{en}->{3599315} = "Gradets\,\ Vidin";
$areanames{en}->{3599316} = "Novo\ selo\,\ Vidin";
$areanames{en}->{3599317} = "Archar";
$areanames{en}->{3599318} = "Bukovets\,\ Vidin";
$areanames{en}->{3599319} = "Gamzovo";
$areanames{en}->{3599320} = "Stakevtsi";
$areanames{en}->{35993212} = "Karbintsi";
$areanames{en}->{3599322} = "Oreshets\,\ Vidin";
$areanames{en}->{3599323} = "Drenovets";
$areanames{en}->{3599324} = "Ruzhintsi";
$areanames{en}->{3599325} = "Belo\ pole\,\ Vidin";
$areanames{en}->{3599326} = "Gorni\ Lom";
$areanames{en}->{3599327} = "Chuprene";
$areanames{en}->{3599328} = "Dolni\ Lom";
$areanames{en}->{3599329} = "Rabisha";
$areanames{en}->{3599330} = "Rabrovo";
$areanames{en}->{3599332} = "Rakovitsa";
$areanames{en}->{3599333} = "Boynitsa";
$areanames{en}->{35993342} = "Kireevo";
$areanames{en}->{3599335} = "Tsar\ Petrovo";
$areanames{en}->{3599336} = "Staropatitsa";
$areanames{en}->{3599337} = "Gramada";
$areanames{en}->{3599338} = "Shishentsi";
$areanames{en}->{3599339} = "Makresh";
$areanames{en}->{3599340} = "Septemvriytsi\,\ Vidin";
$areanames{en}->{3599341} = "Dimovo\,\ Vidin";
$areanames{en}->{3599342} = "Inovo";
$areanames{en}->{3599343} = "Gomotartsi";
$areanames{en}->{3599344} = "Vrav";
$areanames{en}->{3599345} = "Vinarovo\,\ Vidin";
$areanames{en}->{3599346} = "Sinagovtsi";
$areanames{en}->{3599347} = "Bela\ Rada";
$areanames{en}->{3599348} = "Negovanovtsi";
$areanames{en}->{3599349} = "Slanotran";
$areanames{en}->{3599351} = "Izvor\,\ Vidin";
$areanames{en}->{3599352} = "Druzhba";
$areanames{en}->{3599353} = "Koshava";
$areanames{en}->{3599354} = "Antimovo\,\ Vidin";
$areanames{en}->{3599355} = "Kosovo\,\ Vidin";
$areanames{en}->{3599356} = "Kalenik\,\ Vidin";
$areanames{en}->{359936} = "Belogradchik";
$areanames{en}->{359938} = "Kula";
$areanames{en}->{35994} = "Vidin";
$areanames{en}->{3599512} = "Beli\ breg";
$areanames{en}->{3599513} = "Boychinovtsi";
$areanames{en}->{3599514} = "Vladimirovo\,\ Mont\.";
$areanames{en}->{3599515} = "Madan\,\ Mont\.";
$areanames{en}->{3599516} = "Lehchevo";
$areanames{en}->{3599517} = "Kobilyak";
$areanames{en}->{3599518} = "Marchevo";
$areanames{en}->{3599520} = "Gorno\ Ozirovo";
$areanames{en}->{3599521} = "Zamfirovo";
$areanames{en}->{3599522} = "Kotenovtsi";
$areanames{en}->{3599523} = "Barzia";
$areanames{en}->{3599524} = "Yagodovo\,\ Mont\.";
$areanames{en}->{3599525} = "Dolno\ Ozirovo";
$areanames{en}->{3599526} = "Slatina\,\ Mont\.";
$areanames{en}->{3599527} = "Varshets";
$areanames{en}->{35995276} = "Draganitsa";
$areanames{en}->{35995277} = "Cherkaski";
$areanames{en}->{3599528} = "Gaganitsa";
$areanames{en}->{3599529} = "Borovtsi";
$areanames{en}->{359953} = "Berkovitsa";
$areanames{en}->{3599540} = "Belotintsi";
$areanames{en}->{3599541} = "Doktor\ Yosifovo";
$areanames{en}->{3599542} = "Smolyanovtsi";
$areanames{en}->{3599544} = "Studeno\ buche";
$areanames{en}->{3599545} = "Gabrovnitsa";
$areanames{en}->{3599546} = "Slavotin";
$areanames{en}->{3599547} = "Vinishte";
$areanames{en}->{3599548} = "Krapchene";
$areanames{en}->{3599549} = "Dolna\ Riksa";
$areanames{en}->{3599550} = "Mitrovtsi";
$areanames{en}->{3599551} = "Georgi\ Damyanovo";
$areanames{en}->{3599552} = "Belimel";
$areanames{en}->{3599553} = "Prevala";
$areanames{en}->{3599554} = "Chiprovtsi";
$areanames{en}->{3599555} = "Kopilovtsi\,\ Mont\.";
$areanames{en}->{3599556} = "Govezhda";
$areanames{en}->{3599557} = "Gorno\ Tserovene";
$areanames{en}->{3599558} = "Gavril\ Genovo";
$areanames{en}->{3599559} = "Gorna\ Kovachitsa";
$areanames{en}->{3599560} = "Bezdenitsa";
$areanames{en}->{3599561} = "Sumer";
$areanames{en}->{3599564} = "Stubel";
$areanames{en}->{3599567} = "Dolna\ Verenitsa";
$areanames{en}->{3599568} = "Blagovo\,\ Mont\.";
$areanames{en}->{3599569} = "Lipen";
$areanames{en}->{35996} = "Montana";
$areanames{en}->{359971} = "Lom";
$areanames{en}->{3599719} = "Asparuhovo\,\ Mont\.";
$areanames{en}->{3599720} = "Kovachitsa";
$areanames{en}->{3599721} = "Dolno\ Tserovene";
$areanames{en}->{3599722} = "Staliyska\ mahala";
$areanames{en}->{3599723} = "Traykovo";
$areanames{en}->{3599724} = "Stanevo";
$areanames{en}->{3599725} = "Komoshtitsa";
$areanames{en}->{3599726} = "Zamfir";
$areanames{en}->{3599727} = "Medkovets";
$areanames{en}->{3599728} = "Slivata";
$areanames{en}->{3599729} = "Rasovo";
$areanames{en}->{359973} = "Kozloduy";
$areanames{en}->{3599740} = "Septemvriytsi\,\ Mont\.";
$areanames{en}->{3599741} = "Dolni\ Tsibar";
$areanames{en}->{3599742} = "Yakimovo";
$areanames{en}->{3599744} = "Valchedram";
$areanames{en}->{3599745} = "Zlatia\,\ Mont\.";
$areanames{en}->{3599746} = "Razgrad\,\ Mont\.";
$areanames{en}->{3599747} = "Mokresh\,\ Mont\.";
$areanames{en}->{3599748} = "Dalgodeltsi";
$areanames{en}->{3599749} = "Cherni\ vrah\,\ Mont\.";
$areanames{en}->{3599782} = "Bukovets\,\ Mont\.";
$areanames{en}->{3599783} = "Brusartsi";
$areanames{en}->{3599784} = "Kiselevo";
$areanames{en}->{3599785} = "Vasilovtsi\,\ Mont\.";
$areanames{en}->{3599787} = "Smirnenski\,\ Mont\.";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+359|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;